@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 
 /**
  * \file block_subs.h
- * \brief Code included into the three blockm*_func.c files 
+ * \brief Code included into the three blockm*_func.c files
  *
  * This code is included into the three blockm*_func.c files which each
  * will define their names (e.g., BLOCKMEAN).  That definition controls
@@ -87,6 +87,33 @@ struct BLOCK_CTRL {
 	} W;
 };
 
+static struct GMT_KEYWORD_DICTIONARY module_kw[] = { /* Local options for all the block* modules */
+	/* separator, short-option, long-option, short-directives, long-directives, short-modifiers, long-modifiers */
+	{ 0, 'A', "fields", "", "", "", "" },
+	{ 0, 'C', "center", "", "", "", "" },
+#if defined(BLOCKMODE)	/* Only blockmode has a -D option */
+	{ 0, 'D', "bin-width", "", "", "a,c,h,l", "average,center,high,low" },
+#endif
+#if defined(BLOCKMEAN)
+	{ 0, 'E', "extend", "", "", "P,p", "prop-simple,prop-weighted" },
+#elif defined(BLOCKMODE)
+	{ 0, 'E', "extend", "r,s", "record,source", "l,h", "lower,higher" },
+#else
+	{ 0, 'E', "extend", "b,r,s", "box-whisker,record,source", "l,h", "lower,higher" },
+#endif
+	{ 0, 'G', "gridfile", "", "", "", "" },
+	{ '/', 'I', "increment", "", "", "e,n", "exact,number" },
+#if !defined(BLOCKMEAN)		/* Only blockmedian & blockmode have a -Q option */
+	{ 0, 'Q', "quicker", "", "", "", "" },
+#endif
+	{ 0, 'S', "select", "m,n,s,w", "mean,count,sum,weight", "", "" },
+#if defined(BLOCKMEDIAN)	/* Only blockmedian has a -T option */
+	{ 0, 'T', "quantile", "", "", "", "" },
+#endif
+	{ 0, 'W', "weights", "i,o", "in,out", "s", "sigma" },
+	{ 0, '\0', "", "", "", "", ""}	/* End of list marked with empty option and strings */
+};
+
 #if 0
 enum GMT_grdval_blks {	/* mode for selected item for gridding */
 	BLK_ITEM_MEAN = 0,
@@ -175,11 +202,11 @@ struct BLK_DATA {
 /* Declaring the standard functions to allocate and free the program Ctrl structure */
 
 /*! Allocate and initialize a new control structure */
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {
+static void *New_Ctrl (struct GMT_CTRL *GMT) {
 	struct BLOCK_CTRL *C;
-	
+
 	C = gmt_M_memory (GMT, NULL, 1, struct  BLOCK_CTRL);
-	
+
 	/* Initialize values whose defaults are not 0/false/NULL */
 #if defined(BLOCKMODE)	/* Only used by blockmode */
 	C->D.mode = BLOCKMODE_LOW;
@@ -191,12 +218,20 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {
 }
 
 /*! Deallocate control structure */
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct  BLOCK_CTRL *C) {
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct  BLOCK_CTRL *C) {
 	unsigned int k;
 	if (!C) return;
 	for (k = 0; k < C->G.n; k++)
-		gmt_M_str_free (C->G.file[k]);	
-	gmt_M_free (GMT, C);	
+		gmt_M_str_free (C->G.file[k]);
+	gmt_M_free (GMT, C);
+}
+
+static void strip_commas (const char *in, char out[]) {
+	/* Remove the commas in the input and return the remaining characters via out */
+	size_t i, o = 0;
+	for (i = 0; in[i]; i++)
+		if (in[i] != ',') out[o++] = in[i];
+	out[o] = '\0';	/* Terminate string */
 }
 
 #if !defined(BLOCKMEAN)	/* Not used by blockmean */
@@ -211,7 +246,7 @@ enum GMT_enum_blockcases {BLK_CASE_X = 0,
 	BLK_CASE_Z	= 2};
 
 /*! Sort on index, then the specified item a[0,1,2] = x, y, z */
-GMT_LOCAL int BLK_compare_sub (const void *point_1, const void *point_2, int item) {
+static int BLK_compare_sub (const void *point_1, const void *point_2, int item) {
 	const struct BLK_DATA *p1 = point_1, *p2 = point_2;
 
 	/* First sort on bin index ij */
@@ -225,17 +260,17 @@ GMT_LOCAL int BLK_compare_sub (const void *point_1, const void *point_2, int ite
 }
 
 /*! Sort on index, then x */
-GMT_LOCAL int BLK_compare_x (const void *point_1, const void *point_2) {
+static int BLK_compare_x (const void *point_1, const void *point_2) {
 	return (BLK_compare_sub (point_1, point_2, BLK_CASE_X));
 }
 
 /* Sort on index, then y */
-GMT_LOCAL int BLK_compare_y (const void *point_1, const void *point_2) {
+static int BLK_compare_y (const void *point_1, const void *point_2) {
 	return (BLK_compare_sub (point_1, point_2, BLK_CASE_Y));
 }
 
 /*! Sort on index, then z */
-GMT_LOCAL int BLK_compare_index_z (const void *point_1, const void *point_2) {
+static int BLK_compare_index_z (const void *point_1, const void *point_2) {
 	return (BLK_compare_sub (point_1, point_2, BLK_CASE_Z));
 }
 
