@@ -1,5 +1,5 @@
 /*
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -79,52 +79,52 @@ struct DIMFILTER_INFO {
 };
 
 struct DIMFILTER_CTRL {
-	struct In {
+	struct DIMFILTER_In {
 		bool active;
 		char *file;
 	} In;
-	struct C {	/* -C */
+	struct DIMFILTER_C {	/* -C */
 		bool active;
 	} C;
-	struct D {	/* -D<distflag> */
+	struct DIMFILTER_D {	/* -D<distflag> */
 		bool active;
 		int mode;
 	} D;
-	struct E {	/* -E */
+	struct DIMFILTER_E {	/* -E */
 		bool active;
 	} E;
-	struct F {	/* <type><filter_width>*/
+	struct DIMFILTER_F {	/* <type><filter_width>*/
 		bool active;
 		int filter;	/* Id for the filter */
 		double width;
 		int mode;
 	} F;
-	struct G {	/* -G<file> */
+	struct DIMFILTER_G {	/* -G<file> */
 		bool active;
 		char *file;
 	} G;
-	struct L {	/* -L */
+	struct DIMFILTER_L {	/* -L */
 		bool active;
 	} L;
-	struct N {	/* -N */
+	struct DIMFILTER_N {	/* -N */
 		bool active;
 		unsigned int n_sectors;
 		int filter;	/* Id for the filter */
 		int mode;
 	} N;
-	struct Q {	/* -Q */
+	struct DIMFILTER_Q {	/* -Q */
 		bool active;
 	} Q;
-	struct S {	/* -S<file> */
+	struct DIMFILTER_S {	/* -S<file> */
 		bool active;
 		char *file;
 	} S;
-	struct T {	/* -T */
+	struct DIMFILTER_T {	/* -T */
 		bool active;
 	} T;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct DIMFILTER_CTRL *C;
 
 	C = gmt_M_memory (GMT, NULL, 1, struct DIMFILTER_CTRL);
@@ -136,7 +136,7 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_M_str_free (C->In.file);
 	gmt_M_str_free (C->G.file);
@@ -144,7 +144,7 @@ GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *C) {	/* D
 	gmt_M_free (GMT, C);
 }
 
-static char *dimtemplate = 
+static char *dimtemplate =
 	"#!/usr/bin/env bash\n"
 	"#\n"
 	"#\n"
@@ -207,7 +207,7 @@ static char *dimtemplate =
 	"		gmt grdfilter /tmp/$$.dim.nc -G$orsout/dim.${width}.nc -F${dim_smooth_type}${dim_smooth_width} -D${dim_dist} # smoothing\n"
 	"\n"
 	"		gmt grdmath /tmp/$$.t.nc $orsout/dim.${width}.nc SUB = /tmp/$$.sd.nc # residual from DiM\n"
-	"		gmt grdvolume /tmp/$$.sd.nc -Sk -C$level -Vl | awk \'{print r,$2,$3,$4}\' r=${width} >> $ors  # ORS from DiM\n"
+	"		gmt grdvolume /tmp/$$.sd.nc -Sk -C$level -Vi | awk \'{print r,$2,$3,$4}\' r=${width} >> $ors  # ORS from DiM\n"
 	"	done\n"
 	"\n"
 	"fi\n"
@@ -257,7 +257,7 @@ static char *dimtemplate =
 	"\n"
 	"fi\n";
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s <ingrid> -D<distance_flag> -F<type><filter_width>[<modifier>] -G<outgrid> -N<type><n_sectors>[<modifier>]\n", name);
@@ -306,7 +306,27 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct GMT_OPTION *options) {
+GMT_LOCAL double dimfilter_get_filter_width (struct GMT_CTRL *GMT, char *text) {
+	/* Most filter setups expect a constant filter width, but some may pass a grid.  if so
+	   then we must read the grid and find the largest filter and return that value. */
+	double width = 0.0, scl = 1.0;
+	size_t L = strlen (text);
+	char c = 0;
+	gmt_M_unused (GMT);
+
+	if (L && strchr ("ms", text[L-1])) {	/* Appended m or s for arc units */
+		L--;
+		if (text[L] == 'm') scl = GMT_MIN2DEG;		/* Got width in arc minutes */
+		else scl = GMT_SEC2DEG;	/* Got width in arc seconds */
+		c = text[L];
+		text[L] = '\0';	/* Chop off unit */
+	}
+	width = atof (text) * scl;
+	if (c) text[L] = c;	/* Restore m|s */
+	return (width);
+}
+
+static int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to dimfilter and sets parameters in Ctrl.
 	 * Note Ctrl has already been initialized and non-zero default values set.
 	 * Any GMT common options will override values set previously by other commands.
@@ -326,10 +346,11 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct G
 		switch (opt->option) {
 			case '<':	/* Input file (only one is accepted) */
 				if (n_files++ > 0) break;
-				if ((Ctrl->In.active = gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_GRID)) != 0)
-					Ctrl->In.file = strdup (opt->arg);
-				else
+				if (opt->arg[0]) Ctrl->In.file = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_GRID, GMT_IN, GMT_FILE_REMOTE, &(Ctrl->In.file)))
 					n_errors++;
+				else
+					Ctrl->In.active = true;
 				set++;
 				break;
 
@@ -342,7 +363,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct G
 			case 'D':
 				Ctrl->D.active = true;
 				k = atoi (opt->arg);
-				n_errors += gmt_M_check_condition (GMT, k < 0 || k > 4, "Syntax error -D option: Choose from the range 0-4\n");
+				n_errors += gmt_M_check_condition (GMT, k < 0 || k > 4, "Option -D: Choose from the range 0-4\n");
 				Ctrl->D.mode = k;
 				set++;
 				break;
@@ -376,14 +397,13 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct G
 						n_errors++;
 						break;
 				}
-				Ctrl->F.width = atof (&opt->arg[1]);
+				Ctrl->F.width = dimfilter_get_filter_width (GMT, &opt->arg[1]);
 				set++;
 				break;
 			case 'G':
-				if ((Ctrl->G.active = gmt_check_filearg (GMT, 'G', opt->arg, GMT_OUT, GMT_IS_GRID)) != 0)
-					Ctrl->G.file = strdup (opt->arg);
-				else
-					n_errors++;
+				Ctrl->G.active = true;
+				if (opt->arg[0]) Ctrl->G.file = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_GRID, GMT_OUT, GMT_FILE_LOCAL, &(Ctrl->G.file))) n_errors++;
 				set++;
 				break;
 			case 'I':
@@ -418,7 +438,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct G
 						break;
 				}
 				k = atoi (&opt->arg[1]);	/* Number of sections to split filter into */
-				n_errors += gmt_M_check_condition (GMT, k <= 0, "Syntax error -N option: Correct syntax: -Nx<nsectors>[<modifier>], with x one of l|u|a|m|p, <nsectors> is number of sectors\n");
+				n_errors += gmt_M_check_condition (GMT, k <= 0, "Option -N: Correct syntax: -Nx<nsectors>[<modifier>], with x one of l|u|a|m|p, <nsectors> is number of sectors\n");
 				Ctrl->N.n_sectors = k;	/* Number of sections to split filter into */
 				set++;
 				break;
@@ -445,27 +465,27 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct DIMFILTER_CTRL *Ctrl, struct G
 	}
 
 	if (Ctrl->L.active)
-		n_errors += gmt_M_check_condition (GMT, set, "Syntax error: -L can only be used by itself.\n");
+		n_errors += gmt_M_check_condition (GMT, set, "Option -L can only be used by itself.\n");
 	else if (!Ctrl->Q.active) {
-		n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Syntax error: Must specify input file\n");
-		n_errors += gmt_M_check_condition (GMT, GMT->common.R.active[ISET] && (GMT->common.R.inc[GMT_X] <= 0.0 || GMT->common.R.inc[GMT_Y] <= 0.0), "Syntax error -I option: Must specify positive increment(s)\n");
-		n_errors += gmt_M_check_condition (GMT, !Ctrl->G.file, "Syntax error -G option: Must specify output file\n");
-		n_errors += gmt_M_check_condition (GMT, Ctrl->F.width <= 0.0, "Syntax error -F option: Correct syntax: -FX<width>, with X one of bcgmp, width is filter fullwidth\n");
-		n_errors += gmt_M_check_condition (GMT, Ctrl->N.n_sectors == 0, "Syntax error -N option: Correct syntax: -NX<nsectors>, with X one of luamp, nsectors is number of sectors\n");
+		n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Must specify input file\n");
+		n_errors += gmt_M_check_condition (GMT, GMT->common.R.active[ISET] && (GMT->common.R.inc[GMT_X] <= 0.0 || GMT->common.R.inc[GMT_Y] <= 0.0), "Option -I: Must specify positive increment(s)\n");
+		n_errors += gmt_M_check_condition (GMT, !Ctrl->G.file, "Option -G: Must specify output file\n");
+		n_errors += gmt_M_check_condition (GMT, Ctrl->F.width <= 0.0, "Option -F: Correct syntax: -FX<width>, with X one of bcgmp, width is filter fullwidth\n");
+		n_errors += gmt_M_check_condition (GMT, Ctrl->N.n_sectors == 0, "Option -N: Correct syntax: -NX<nsectors>, with X one of luamp, nsectors is number of sectors\n");
 #ifdef OBSOLETE
 		slow = (Ctrl->F.filter == DIMFILTER_MEDIAN || Ctrl->F.filter == DIMFILTER_MODE);		/* Will require sorting etc */
-		n_errors += gmt_M_check_condition (GMT, Ctrl->E.active && !slow, "Syntax error -E option: Only valid for robust filters -Fm|p.\n");
+		n_errors += gmt_M_check_condition (GMT, Ctrl->E.active && !slow, "Option -E: Only valid for robust filters -Fm|p.\n");
 #endif
 	}
 	else {
-		n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Syntax error: Must specify input file\n");
-		n_errors += gmt_M_check_condition (GMT, !Ctrl->Q.active, "Syntax error: Must use -Q to specify total # of columns in the input file.\n");
+		n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Must specify input file\n");
+		n_errors += gmt_M_check_condition (GMT, !Ctrl->Q.active, "Must use -Q to specify total # of columns in the input file.\n");
 	}
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-GMT_LOCAL void set_weight_matrix_dim (struct DIMFILTER_INFO *F, struct GMT_GRID_HEADER *h, double y_0, int fast) {
+GMT_LOCAL void dimfilter_set_weight_matrix (struct DIMFILTER_INFO *F, struct GMT_GRID_HEADER *h, double y_0, int fast) {
 /* Last two gives offset between output node and 'origin' input node for this window (0,0 for integral grids) */
 /* true when input/output grids are offset by integer values in dx/dy */
 
@@ -536,7 +556,7 @@ GMT_LOCAL void set_weight_matrix_dim (struct DIMFILTER_INFO *F, struct GMT_GRID_
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_dimfilter (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_dimfilter (void *V_API, int mode, void *args) {
 	unsigned short int **sector = NULL;
 
 	unsigned int *n_in_median, wsize = 0, one_or_zero = 1, effort_level, n_sectors_2 = 0, col_in, row_in;
@@ -584,7 +604,7 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error);	/* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error);	/* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
@@ -630,7 +650,7 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 		if (wesn[YHI] > Gin->header->wesn[YHI]) error = true;
 
 		if (error) {
-			GMT_Report (API, GMT_MSG_NORMAL, "New WESN incompatible with old.\n");
+			GMT_Report (API, GMT_MSG_ERROR, "New WESN incompatible with old.\n");
 			Return (GMT_RUNTIME_ERROR);
 		}
 
@@ -646,11 +666,11 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 		fast_way = (fabs (fmod (Gout->header->inc[GMT_X] / Gin->header->inc[GMT_X], 1.0)) < GMT_CONV4_LIMIT && fabs (fmod (Gout->header->inc[GMT_Y] / Gin->header->inc[GMT_Y], 1.0)) < GMT_CONV4_LIMIT);
 
 		if (!fast_way) {
-			GMT_Report (API, GMT_MSG_VERBOSE, "Your output grid spacing is such that filter-weights must\n");
-			GMT_Report (API, GMT_MSG_VERBOSE, "be recomputed for every output node, so expect this run to be slow.  Calculations\n");
-			GMT_Report (API, GMT_MSG_VERBOSE, "can be speeded up significantly if output grid spacing is chosen to be a multiple\n");
-			GMT_Report (API, GMT_MSG_VERBOSE, "of the input grid spacing.  If the odd output grid is necessary, consider using\n");
-			GMT_Report (API, GMT_MSG_VERBOSE, "a \'fast\' grid for filtering and then resample onto your desired grid with grdsample.\n");
+			GMT_Report (API, GMT_MSG_WARNING, "Your output grid spacing is such that filter-weights must\n");
+			GMT_Report (API, GMT_MSG_WARNING, "be recomputed for every output node, so expect this run to be slow.  Calculations\n");
+			GMT_Report (API, GMT_MSG_WARNING, "can be speeded up significantly if output grid spacing is chosen to be a multiple\n");
+			GMT_Report (API, GMT_MSG_WARNING, "of the input grid spacing.  If the odd output grid is necessary, consider using\n");
+			GMT_Report (API, GMT_MSG_WARNING, "a \'fast\' grid for filtering and then resample onto your desired grid with grdsample.\n");
 		}
 
 #ifdef OBSOLETE
@@ -717,9 +737,9 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 			}
 		}
 
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Input n_columns,n_rows = (%d %d), output n_columns,n_rows = (%d %d), filter n_columns,n_rows = (%d %d)\n",
+		GMT_Report (API, GMT_MSG_INFORMATION, "Input n_columns,n_rows = (%d %d), output n_columns,n_rows = (%d %d), filter n_columns,n_rows = (%d %d)\n",
 			Gin->header->n_columns, Gin->header->n_rows, Gout->header->n_columns, Gout->header->n_rows, F.n_columns, F.n_rows);
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Filter type is %s.\n", filter_name[Ctrl->F.filter]);
+		GMT_Report (API, GMT_MSG_INFORMATION, "Filter type is %s.\n", filter_name[Ctrl->F.filter]);
 
 		/* Compute nearest xoutput i-indices and shifts once */
 
@@ -744,7 +764,7 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 		else
 			effort_level = 3;
 
-		if (effort_level == 1) set_weight_matrix_dim (&F, Gout->header, 0.0, shift);	/* Only need this once */
+		if (effort_level == 1) dimfilter_set_weight_matrix (&F, Gout->header, 0.0, shift);	/* Only need this once */
 
 		if (Ctrl->C.active) {	/* Use fixed-width diagonal corridors instead of bow-ties */
 			n_sectors_2 = Ctrl->N.n_sectors / 2;
@@ -777,19 +797,22 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 
 		for (row_out = 0; row_out < Gout->header->n_rows; row_out++) {
 
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Processing output line %d\r", row_out);
+			GMT_Report (API, GMT_MSG_INFORMATION, "Processing output line %d\r", row_out);
 			y_out = gmt_M_grd_row_to_y (GMT, row_out, Gout->header);
 			j_origin = (int)gmt_M_grd_y_to_row (GMT, y_out, Gin->header);
-			if (effort_level == 2) set_weight_matrix_dim (&F, Gout->header, y_out, shift);
+			if (effort_level == 2) dimfilter_set_weight_matrix (&F, Gout->header, y_out, shift);
 
 			for (col_out = 0; col_out < Gout->header->n_columns; col_out++) {
 
-				if (effort_level == 3) set_weight_matrix_dim (&F, Gout->header, y_out, shift);
+				if (effort_level == 3) dimfilter_set_weight_matrix (&F, Gout->header, y_out, shift);
 				gmt_M_memset (n_in_median, Ctrl->N.n_sectors, unsigned int);
 				gmt_M_memset (value, Ctrl->N.n_sectors, double);
 				gmt_M_memset (wt_sum, Ctrl->N.n_sectors, double);
 #ifdef OBSOLETE
-				if (Ctrl->E.active) S = 0, Sx = Sy = Sz = Sxx = Syy = Sxy = Sxz = Syz = Sxx = Sw = 0.0;
+				if (Ctrl->E.active) {
+					S = 0;
+					Sx = Sy = Sz = Sxx = Syy = Sxy = Sxz = Syz = Sxx = Sw = 0.0;
+				}
 				n = 0;
 #endif
 
@@ -969,7 +992,7 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 					}
 					for (s = k = 0; s < Ctrl->N.n_sectors; s++) {
 						if (n_in_median[s]) {
-							if (n_in_median[s] >= wsize) GMT_Report (API, GMT_MSG_VERBOSE, "Exceed array size (%d > %d)!\n", n_in_median[s], wsize);
+							if (n_in_median[s] >= wsize) GMT_Report (API, GMT_MSG_WARNING, "Exceed array size (%d > %d)!\n", n_in_median[s], wsize);
 #ifdef OBSOLETE
 							if (Ctrl->E.active) {
 								z_min = DBL_MAX;
@@ -1073,24 +1096,24 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 #endif
 			}
 		}
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "\n");
+		GMT_Report (API, GMT_MSG_INFORMATION, "\n");
 
 		/* At last, that's it!  Output: */
 
-		if (n_nan) GMT_Report (API, GMT_MSG_VERBOSE, "Unable to estimate value at %" PRIu64 " nodes, set to NaN\n", n_nan);
+		if (n_nan) GMT_Report (API, GMT_MSG_WARNING, "Unable to estimate value at %" PRIu64 " nodes, set to NaN\n", n_nan);
 #ifdef OBSOLETE
-		if (Ctrl->E.active && n_bad_planes) GMT_Report (API, GMT_MSG_VERBOSE, "Unable to detrend data at %" PRIu64 " nodes\n", n_bad_planes);
+		if (Ctrl->E.active && n_bad_planes) GMT_Report (API, GMT_MSG_WARNING, "Unable to detrend data at %" PRIu64 " nodes\n", n_bad_planes);
 #endif
-		if (GMT_n_multiples > 0) GMT_Report (API, GMT_MSG_VERBOSE, "%d multiple modes found\n", GMT_n_multiples);
+		if (GMT_n_multiples > 0) GMT_Report (API, GMT_MSG_INFORMATION, "%d separate modes found by the mode filter\n", GMT_n_multiples);
 
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Write filtered grid\n");
+		GMT_Report (API, GMT_MSG_INFORMATION, "Write filtered grid\n");
 		if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_OPTION | GMT_COMMENT_IS_COMMAND, options, Gout)) Return (API->error);
 		if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_CONTAINER_AND_DATA, NULL, Ctrl->G.file, Gout) != GMT_NOERROR) {
 			Return (API->error);
 		}
 #ifdef OBSOLETE
 		if (Ctrl->S.active) {
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Write scale grid\n");
+			GMT_Report (API, GMT_MSG_INFORMATION, "Write scale grid\n");
 			if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_OPTION | GMT_COMMENT_IS_COMMAND, options, Sout)) Return (API->error);
 			if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_CONTAINER_AND_DATA, NULL, Ctrl->S.file, Sout) != GMT_NOERROR) {
 				Return (API->error);
@@ -1137,11 +1160,11 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 		if ((D = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_POINT, GMT_READ_NORMAL, NULL, Ctrl->In.file, NULL)) == NULL) {
 			Return (API->error);
 		}
-		
+
 		if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_POINT, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Registers default output destination, unless already set */
 			Return (API->error);
 		}
-		
+
 		if ((error = GMT_Set_Columns (API, GMT_OUT, 3, GMT_COL_FIX_NO_TEXT)) != GMT_NOERROR) Return (error);
 		if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_OUT, GMT_HEADER_ON) != GMT_NOERROR) {	/* Enables data output and sets access mode */
 			Return (API->error);
@@ -1151,9 +1174,9 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 		}
 		gmt_set_cartesian (GMT, GMT_OUT);	/* No coordinates here */
 		Out = gmt_new_record (GMT, out, NULL);	/* Since we only need to worry about numerics in this module */
-		err_workarray = gmt_M_memory (GMT, NULL, S->n_columns, double);
 
 		S = D->table[0]->segment[0];	/* A Single-segment data file */
+		err_workarray = gmt_M_memory (GMT, NULL, S->n_columns, double);
 		for (row = 0; row < S->n_rows; row++) {
 			/* Store data into array and find sum/min/max, starting with col 0 */
 			err_sum = err_workarray[0] = err_min = err_max = S->data[0][row];
@@ -1163,7 +1186,7 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 				if (S->data[col][row] < err_min) err_min = S->data[col][row];
 				if (S->data[col][row] > err_max) err_max = S->data[col][row];
 			}
-			
+
 			/* calculate MEDIAN and MAD for each row */
 			gmt_median (GMT, err_workarray, S->n_columns, err_min, err_max, err_null_median, &err_median);
 			err_workarray[0] = err_min = err_max = fabs (err_workarray[0] - err_median);
@@ -1188,7 +1211,7 @@ int GMT_dimfilter (void *V_API, int mode, void *args) {
 
 		gmt_M_free (GMT, Out);
 		gmt_M_free (GMT, err_workarray);
-		
+
 		if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) {
 			Return (API->error);	/* Disables further data output */
 		}
