@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -83,12 +83,12 @@ int gmt_nc_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_
  *-----------------------------------------------------------*/
 
 int gmt_dummy_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
-	if (header) GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Unknown grid format.\n");
+	if (header) GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unknown grid format.\n");
 	return (GMT_GRDIO_UNKNOWN_FORMAT);
 }
 
 int gmt_dummy_grd_read (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_grdfloat *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
-	if (header && grid && wesn && pad && complex_mode < 1024) GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Unknown grid format.\n");
+	if (header && grid && wesn && pad && complex_mode < 1024) GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unknown grid format.\n");
 	return (GMT_GRDIO_UNKNOWN_FORMAT);
 }
 
@@ -116,7 +116,7 @@ int gmt_dummy_grd_read (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gm
 
 #define	RAS_MAGIC	0x59a66a95
 
-GMT_LOCAL int customio_read_rasheader (FILE *fp, struct rasterfile *h) {
+GMT_LOCAL int gmtcustomio_read_rasheader (FILE *fp, struct rasterfile *h) {
 	/* Reads the header of a Sun rasterfile byte by byte
 	   since the format is defined as the byte order on the
 	   PDP-11.
@@ -149,7 +149,7 @@ GMT_LOCAL int customio_read_rasheader (FILE *fp, struct rasterfile *h) {
 	return (GMT_NOERROR);
 }
 
-GMT_LOCAL int customio_write_rasheader (FILE *fp, struct rasterfile *h) {
+GMT_LOCAL int gmtcustomio_write_rasheader (FILE *fp, struct rasterfile *h) {
 	/* Writes the header of a Sun rasterfile byte by byte
 	   since the format is defined as the byte order on the
 	   PDP-11.
@@ -188,7 +188,7 @@ GMT_LOCAL int customio_write_rasheader (FILE *fp, struct rasterfile *h) {
 	return (GMT_NOERROR);
 }
 
-int gmt_is_ras_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
+int gmtlib_is_ras_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	/* Determine if file is a Sun rasterfile */
 	FILE *fp = NULL;
 	struct rasterfile h;
@@ -198,7 +198,7 @@ int gmt_is_ras_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	if ((fp = gmt_fopen (GMT, HH->name, "rb")) == NULL)
 		return (GMT_GRDIO_OPEN_FAILED);
 	gmt_M_memset (&h, 1, struct rasterfile);
-	if (customio_read_rasheader (fp, &h)) {
+	if (gmtcustomio_read_rasheader (fp, &h)) {
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
@@ -232,7 +232,7 @@ int gmt_ras_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header)
 		return (GMT_GRDIO_OPEN_FAILED);
 
 	gmt_M_memset (&h, 1, struct rasterfile);
-	if (customio_read_rasheader (fp, &h)) {
+	if (gmtcustomio_read_rasheader (fp, &h)) {
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
@@ -262,7 +262,7 @@ int gmt_ras_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header)
 	header->registration = GMT_GRID_PIXEL_REG;	/* Always pixel format */
 	header->z_scale_factor = 1.0;	header->z_add_offset = 0.0;
 	HH->orig_datatype = GMT_CHAR;
-	
+
 	return (GMT_NOERROR);
 }
 
@@ -288,7 +288,7 @@ int gmt_ras_write_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header
 	h.type = 1;
 	h.maptype = h.maplength = 0;
 
-	if (customio_write_rasheader (fp, &h))  {
+	if (gmtcustomio_write_rasheader (fp, &h))  {
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_WRITE_FAILED);
 	}
@@ -326,7 +326,7 @@ int gmt_ras_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_
 		piping = true;
 	}
 	else if ((fp = gmt_fopen (GMT, HH->name, "rb")) != NULL) {	/* Skip header */
-		if (customio_read_rasheader (fp, &h)) {
+		if (gmtcustomio_read_rasheader (fp, &h)) {
 			gmt_fclose (GMT, fp);
 			return (GMT_GRDIO_READ_FAILED);
 		}
@@ -470,7 +470,7 @@ int gmt_ras_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 
 	/* store header information and array */
 
-	if (customio_write_rasheader (fp, &h)) {
+	if (gmtcustomio_write_rasheader (fp, &h)) {
 		gmt_fclose (GMT, fp);
 		gmt_M_free (GMT, actual_col);
 		gmt_M_free (GMT, tmp);
@@ -526,11 +526,11 @@ int gmt_ras_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 /* sizeof the complete native header */
 #define SIZEOF_NATIVE_GRD_HDR  892 /* SIZEOF_NATIVE_GRD_HDR1 + SIZEOF_NATIVE_GRD_HD */
 
-GMT_LOCAL int customio_native_read_grd_header (FILE *fp, struct GMT_GRID_HEADER *header) {
+GMT_LOCAL int gmtcustomio_native_read_grd_header (FILE *fp, struct GMT_GRID_HEADER *header) {
 	int err = GMT_NOERROR;
 	/* Because GMT_GRID_HEADER is not 64-bit aligned we must read it in parts */
 	if (gmt_M_fread (&header->n_columns, SIZEOF_NATIVE_GRD_HDR1, 1U, fp) != 1 ||
-			gmt_M_fread (header->wesn, SIZEOF_NATIVE_GRD_HDR2, 1U, fp) != 1)
+			gmt_M_fread (&header->wesn[0], SIZEOF_NATIVE_GRD_HDR2, 1U, fp) != 1)
 	err = GMT_GRDIO_READ_FAILED;
 	return (err);
 }
@@ -552,14 +552,14 @@ int gmt_native_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *head
 	else if ((fp = gmt_fopen (GMT, HH->name, "rb")) == NULL)
 		return (GMT_GRDIO_OPEN_FAILED);
 
-	status = customio_native_read_grd_header (fp, header);
+	status = gmtcustomio_native_read_grd_header (fp, header);
 	gmt_fclose (GMT, fp);
 	return status;
 }
 
 #define free_and_return(code) { gmt_free_header(GMT, &t_head); return (code); }
 
-int gmt_is_native_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
+int gmtlib_is_native_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	uint64_t mx, status, size;
 	off_t nm;
 	double item_size;
@@ -630,8 +630,8 @@ int gmt_is_native_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 				}
 			}
 			else {
-				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Cannot determine if a native 4-byte grid is float or int without more information.\n");
-				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "You must append =bf (float) or =bi (integer) to avoid this situation.\n");
+				GMT_Report (GMT->parent, GMT_MSG_ERROR, "Cannot determine if a native 4-byte grid is float or int without more information.\n");
+				GMT_Report (GMT->parent, GMT_MSG_ERROR, "You must append =bf (float) or =bi (integer) to avoid this situation.\n");
 				free_and_return (GMT_GRDIO_NONUNIQUE_FORMAT);
 			}
 			break;
@@ -646,17 +646,17 @@ int gmt_is_native_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	free_and_return (GMT_NOERROR);
 }
 
-GMT_LOCAL int customio_native_write_grd_header (FILE *fp, struct GMT_GRID_HEADER *header) {
+GMT_LOCAL int gmtcustomio_native_write_grd_header (FILE *fp, struct GMT_GRID_HEADER *header) {
 	int err = GMT_NOERROR;
 	/* Because GMT_GRID_HEADER is not 64-bit aligned we must write it in parts */
 
 	if (gmt_M_fwrite (&header->n_columns, SIZEOF_NATIVE_GRD_HDR1, 1U, fp) != 1 ||
-			gmt_M_fwrite (header->wesn, SIZEOF_NATIVE_GRD_HDR2, 1U, fp) != 1)
+			gmt_M_fwrite (&header->wesn[0], SIZEOF_NATIVE_GRD_HDR2, 1U, fp) != 1)
 		err = GMT_GRDIO_WRITE_FAILED;
 	return (err);
 }
 
-GMT_LOCAL int customio_native_skip_grd_header (FILE *fp, struct GMT_GRID_HEADER *header) {
+GMT_LOCAL int gmtcustomio_native_skip_grd_header (FILE *fp, struct GMT_GRID_HEADER *header) {
 	int err = GMT_NOERROR;
 	gmt_M_unused(header);
 	/* Because GMT_GRID_HEADER is not 64-bit aligned we must estimate the # of bytes in parts */
@@ -693,7 +693,7 @@ int gmt_bit_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_
 		piping = true;
 	}
 	else if ((fp = gmt_fopen (GMT, HH->name, "rb")) != NULL) {	/* Skip header */
-		gmt_M_err_trap (customio_native_skip_grd_header (fp, header));
+		gmt_M_err_trap (gmtcustomio_native_skip_grd_header (fp, header));
 	}
 	else
 		return (GMT_GRDIO_OPEN_FAILED);
@@ -838,7 +838,7 @@ int gmt_bit_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 	/* Store header information and array */
 
 	if (do_header) {
-		if ((err = customio_native_write_grd_header (fp, header))) {
+		if ((err = gmtcustomio_native_write_grd_header (fp, header))) {
 			gmt_fclose (GMT, fp);
 			gmt_M_free (GMT, actual_col);
 			return err;
@@ -926,7 +926,7 @@ int gmt_native_write_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *hea
 	else if ((fp = gmt_fopen (GMT, HH->name, "rb+")) == NULL && (fp = gmt_fopen (GMT, HH->name, "wb")) == NULL)
 		return (GMT_GRDIO_CREATE_FAILED);
 
-	err = customio_native_write_grd_header (fp, header);
+	err = gmtcustomio_native_write_grd_header (fp, header);
 	gmt_fclose (GMT, fp);
 
 	if (err)
@@ -955,8 +955,8 @@ int gmt_native_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, g
 	unsigned int *k = NULL;		/* Array with indices */
 	unsigned int width_in;		/* Number of items in one row of the subregion */
 	uint64_t kk, ij, j2, width_out, imag_offset;	/* Width of row as return (may include padding) */
-	size_t size;			/* Length of data type */ 
-	size_t n_expected;		/* Length of row to read */ 
+	size_t size;			/* Length of data type */
+	size_t n_expected;		/* Length of row to read */
 	FILE *fp = NULL;		/* File pointer to data or pipe */
 	void *tmp = NULL;		/* Array pointer for reading in rows of data */
 	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
@@ -969,13 +969,13 @@ int gmt_native_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, g
 		piping = true;
 	}
 	else if ((fp = gmt_fopen (GMT, HH->name, "rb")) != NULL)	{	/* Skip header */
-		gmt_M_err_trap (customio_native_skip_grd_header (fp, header));
+		gmt_M_err_trap (gmtcustomio_native_skip_grd_header (fp, header));
 	}
 	else
 		return (GMT_GRDIO_OPEN_FAILED);
 
 	type = GMT->session.grdformat[header->type][1];
-	size = gmt_grd_data_size (GMT, header->type, &header->nan_value);
+	size = gmtlib_grd_data_size (GMT, header->type, &header->nan_value);
 	check = !isnan (header->nan_value);
 
 	(void)gmtlib_init_complex (header, complex_mode, &imag_offset);	/* Set offset for imaginary complex component */
@@ -1077,7 +1077,7 @@ int gmt_native_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header,
 	unsigned int *k = NULL;		/* Array with indices */
 	uint64_t ij, width_in, imag_offset, j2;
 	size_t size;			/* Length of data type */
-	size_t n_expected;		/* Length of row to read */ 
+	size_t n_expected;		/* Length of row to read */
 	FILE *fp = NULL;		/* File pointer to data or pipe */
 	void *tmp = NULL;		/* Array pointer for writing in rows of data */
 	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
@@ -1092,7 +1092,7 @@ int gmt_native_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header,
 		return (GMT_GRDIO_CREATE_FAILED);
 
 	type = GMT->session.grdformat[header->type][1];
-	size = gmt_grd_data_size (GMT, header->type, &header->nan_value);
+	size = gmtlib_grd_data_size (GMT, header->type, &header->nan_value);
 	check = !isnan (header->nan_value);
 
 	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_out, &height_out, &first_col, &last_col, &first_row, &last_row, &k), HH->name);
@@ -1132,7 +1132,7 @@ int gmt_native_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header,
 	/* Store header information and array */
 
 	if (do_header) {
-		if ((err = customio_native_write_grd_header (fp, header)) != 0) {
+		if ((err = gmtcustomio_native_write_grd_header (fp, header)) != 0) {
 			gmt_M_free (GMT, k);	gmt_fclose (GMT, fp);
 			return err;
 		}
@@ -1183,7 +1183,7 @@ void gmtlib_encode (struct GMT_CTRL *GMT, void *vptr, uint64_t k, gmt_grdfloat z
 			((double *)vptr)[k] = (double)z;
 			break;
 		default:
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "GMT: Bad call to gmtlib_encode\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "GMT: Bad call to gmtlib_encode\n");
 			break;
 	}
 }
@@ -1210,7 +1210,7 @@ gmt_grdfloat gmtlib_decode (struct GMT_CTRL *GMT, void *vptr, uint64_t k, unsign
 			fval = (gmt_grdfloat)(((double *)vptr)[k]);
 			break;
 		default:
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "GMT: Bad call to gmtlib_decode\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "GMT: Bad call to gmtlib_decode\n");
 			fval = GMT->session.f_NaN;
 			break;
 	}
@@ -1259,7 +1259,7 @@ struct srf_header6 {	/* Surfer 6 file header structure */
    grid format we are dealing with, I removed them from the header definition (and jump
    12 bytes before reading the header). As a result the header has now one 4 byte char +
    trhee 4-bytes ints followed by 8-bytes doubles. With this organization the header is
-   read correctly by customio_read_srfheader7. Needless to say that I don't understand why the
+   read correctly by gmtcustomio_read_srfheader7. Needless to say that I don't understand why the
    even number of 4-bytes variables before the 8-bytes caused that the doubles we incorrectly read.
 
    Joaquim Luis 08-2005. */
@@ -1284,7 +1284,7 @@ struct srf_header7 {	/* Surfer 7 file header structure */
 	int len_d;		/* Length in bytes of the DATA section */
 };
 
-int gmt_is_srf_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
+int gmtlib_is_srf_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	FILE *fp = NULL;
 	char id[5];
 	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
@@ -1306,7 +1306,7 @@ int gmt_is_srf_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	return GMT_NOERROR;
 }
 
-GMT_LOCAL int customio_read_srfheader6 (FILE *fp, struct srf_header6 *h) {
+GMT_LOCAL int gmtcustomio_read_srfheader6 (FILE *fp, struct srf_header6 *h) {
 	/* Reads the header of a Surfer 6 gridfile */
 	/* if (gmt_M_fread (h, sizeof (struct srf_header6), 1U, fp) < 1U) return (GMT_GRDIO_READ_FAILED); */
 
@@ -1323,7 +1323,7 @@ GMT_LOCAL int customio_read_srfheader6 (FILE *fp, struct srf_header6 *h) {
 	return GMT_NOERROR;
 }
 
-GMT_LOCAL int customio_read_srfheader7 (FILE *fp, struct srf_header7 *h) {
+GMT_LOCAL int gmtcustomio_read_srfheader7 (FILE *fp, struct srf_header7 *h) {
 	/* Reads the header of a Surfer 7 gridfile */
 
 	if (fseek (fp, (off_t)(3*sizeof(int)), SEEK_SET))
@@ -1345,7 +1345,7 @@ GMT_LOCAL int customio_read_srfheader7 (FILE *fp, struct srf_header7 *h) {
 	return GMT_NOERROR;
 }
 
-GMT_LOCAL int customio_write_srfheader (FILE *fp, struct srf_header6 *h) {
+GMT_LOCAL int gmtcustomio_write_srfheader (FILE *fp, struct srf_header6 *h) {
 	/* if (gmt_M_fwrite (h, sizeof (struct srf_header6), 1U, fp) < 1U) return (GMT_GRDIO_WRITE_FAILED); */
 	/* UPDATE: Because srf_header6 is not 64-bit aligned we must write it in parts */
 	if (gmt_M_fwrite (h->id, 4*sizeof (char), 1U, fp) != 1)
@@ -1391,12 +1391,12 @@ int gmt_srf_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header)
 	gmt_M_memset (&h6, 1, struct srf_header6);
 	gmt_M_memset (&h7, 1, struct srf_header7);
 	if (!strncmp (id, "DSBB", 4U)) {		/* Version 6 format */
-		if (customio_read_srfheader6 (fp, &h6)) return (GMT_GRDIO_READ_FAILED);
+		if (gmtcustomio_read_srfheader6 (fp, &h6)) return (GMT_GRDIO_READ_FAILED);
 		header->type = GMT_GRID_IS_SF;
 		HH->orig_datatype = GMT_FLOAT;
 	}
 	else {					/* Version 7 format */
-		if (customio_read_srfheader7 (fp, &h7))  return (GMT_GRDIO_READ_FAILED);
+		if (gmtcustomio_read_srfheader7 (fp, &h7))  return (GMT_GRDIO_READ_FAILED);
 		if (h7.len_d != h7.n_columns * h7.n_rows * 8 || !strcmp (h7.id2, "GRID")) return (GMT_GRDIO_SURF7_UNSUPPORTED);
 		header->type = GMT_GRID_IS_SD;
 		HH->orig_datatype = GMT_DOUBLE;
@@ -1454,7 +1454,7 @@ int gmt_srf_write_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header
 		gmt_M_memcpy (h.wesn, header->wesn, 4, double);
 	h.z_min = header->z_min;	 h.z_max = header->z_max;
 
-	if (customio_write_srfheader (fp, &h)) {
+	if (gmtcustomio_write_srfheader (fp, &h)) {
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_WRITE_FAILED);
 	}
@@ -1510,7 +1510,7 @@ int gmt_srf_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_
 		return (GMT_GRDIO_OPEN_FAILED);
 
 	type = GMT->session.grdformat[header->type][1];
-	size = gmt_grd_data_size (GMT, header->type, &header->nan_value);
+	size = gmtlib_grd_data_size (GMT, header->type, &header->nan_value);
 
 	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_in, &height_in, &first_col, &last_col, &first_row, &last_row, &k), HH->name);
 	(void)gmtlib_init_complex (header, complex_mode, &imag_offset);	/* Set offset for imaginary complex component */
@@ -1624,10 +1624,10 @@ int gmt_srf_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 
 	if (GMT->session.grdformat[header->type][1] == 'd') {
 #ifdef HAVE_GDAL
-		GMT_Message(GMT->parent, GMT_TIME_NONE,
+		GMT_Report(GMT->parent, GMT_MSG_INFORMATION,
 			"Surfer 7 format in GMT is read-only but you can do it via GDAL by appending '=gd:GS7BG' to the file name\n");
 #else
-		GMT_Message(GMT->parent, GMT_TIME_NONE,
+		GMT_Report(GMT->parent, GMT_MSG_INFORMATION,
 			"As mentioned in the manual, Surfer 7 format in GMT is read-only\n");
 #endif
 		return (GMT_NOERROR);
@@ -1645,7 +1645,7 @@ int gmt_srf_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 		return (GMT_GRDIO_CREATE_FAILED);
 
 	type = GMT->session.grdformat[header->type][1];
-	size = gmt_grd_data_size (GMT, header->type, &header->nan_value);
+	size = gmtlib_grd_data_size (GMT, header->type, &header->nan_value);
 
 	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_out, &height_out, &first_col, &last_col, &first_row, &last_row, &k), HH->name);
 	(void)gmtlib_init_complex (header, complex_mode, &imag_offset);	/* Set offset for imaginary complex component */
@@ -1739,7 +1739,7 @@ int gmt_srf_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
  *		gmt_gdal_write_grd_info, gmt_gdal_read_grd, gmt_gdal_write_grd
  *-----------------------------------------------------------*/
 
-static inline void free_from_gdalread (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_CTRL *from_gdalread) {
+static inline void gmtcustomio_free_from_gdalread (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_CTRL *from_gdalread) {
 	int i;
 	gmt_M_free (GMT, from_gdalread->ColorMap);
 	for (i = 0; i < from_gdalread->RasterCount; i++)
@@ -1755,7 +1755,7 @@ int gmt_gdal_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header
 	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
 	if (!strcmp (HH->name, "=")) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Pipes cannot be used within the GDAL interface.\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Pipes cannot be used within the GDAL interface.\n");
 		return (GMT_GRDIO_OPEN_FAILED);
 	}
 
@@ -1770,9 +1770,9 @@ int gmt_gdal_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header
 	}
 
 	if (gmt_gdalread (GMT, HH->name, to_gdalread, from_gdalread)) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "ERROR reading file (metadata) with gdalread.\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "ERROR reading file (metadata) with gdalread.\n");
 		gmt_M_free (GMT, to_gdalread);
-		free_from_gdalread (GMT, from_gdalread);
+		gmtcustomio_free_from_gdalread (GMT, from_gdalread);
 		gmt_M_free (GMT, from_gdalread);
 		return (GMT_GRDIO_OPEN_FAILED);
 	}
@@ -1824,7 +1824,7 @@ int gmt_gdal_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header
 		header->ProjRefWKT   = strdup (from_gdalread->ProjRefWKT);
 
 	gmt_M_free (GMT, to_gdalread);
-	free_from_gdalread (GMT, from_gdalread);
+	gmtcustomio_free_from_gdalread (GMT, from_gdalread);
 	gmt_M_free (GMT, from_gdalread);
 
 	return (GMT_NOERROR);
@@ -1928,12 +1928,12 @@ int gmt_gdal_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 	/* Tell gmt_gdalread that we already have the memory allocated and send in the *grid pointer */
 	to_gdalread->f_ptr.active = true;
 	to_gdalread->f_ptr.grd = grid;
-	
+
 	/* If header->nan_value != NaN tell gdalread to replace nan_value by NaN (in floats only) */
 	to_gdalread->N.nan_value = header->nan_value;
 
 	if (gmt_gdalread (GMT, HH->name, to_gdalread, from_gdalread)) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "ERROR reading file with gdalread.\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "ERROR reading file with gdalread.\n");
 		gmt_M_free (GMT, to_gdalread);	gmt_M_free (GMT, from_gdalread);
 		return (GMT_GRDIO_OPEN_FAILED);
 	}
@@ -1976,9 +1976,9 @@ int gmt_gdal_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 			for (j = 0; j < header->size; j++)
 				grid[j] = (gmt_grdfloat)from_gdalread->Int32.data[j+i];
 		else {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "ERROR data type not supported with gdalread in gmt_customio.\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "ERROR data type not supported with gdalread in gmt_customio.\n");
 			gmt_M_free (GMT, to_gdalread);
-			free_from_gdalread (GMT, from_gdalread);
+			gmtcustomio_free_from_gdalread (GMT, from_gdalread);
 			gmt_M_free (GMT, from_gdalread);
 			return (GMT_GRDIO_OPEN_FAILED);
 		}
@@ -2027,7 +2027,7 @@ int gmt_gdal_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt
 		gmt_M_free (GMT, from_gdalread->Int32.data);
 
 	gmt_M_free (GMT, to_gdalread);
-	free_from_gdalread (GMT, from_gdalread);
+	gmtcustomio_free_from_gdalread (GMT, from_gdalread);
 	gmt_M_free (GMT, from_gdalread);
 
 	return (GMT_NOERROR);
@@ -2054,7 +2054,7 @@ int gmt_gdal_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gm
 	type[0] = '\0';
 
 	if (HH->pocket == NULL) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Cannot write with GDAL without knowing which driver to use.\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Cannot write with GDAL without knowing which driver to use.\n");
 		return (GMT_NOERROR);
 	}
 
@@ -2091,7 +2091,7 @@ int gmt_gdal_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gm
 	to_GDALW->command = header->command;
 	to_GDALW->orig_type = HH->orig_datatype;
 
-	/* Lazy implementation of nodata value update as it doesn't check and apply on a eventual sub-region on output only */
+	/* Lazy implementation of nodata value update as it doesn't check and apply on an eventual sub-region on output only */
 	if (!isnan (header->nan_value)) {
 		for (ij = 0; ij < header->size; ij++)
 			if (isnan (grid[ij]))
@@ -2157,7 +2157,7 @@ int gmt_gdal_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gm
 		to_GDALW->type = strdup("uint32");
 	}
 	else {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Unknown or unsupported data type code in gmt_customio for writing file with GDAL.\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unknown or unsupported data type code in gmt_customio for writing file with GDAL.\n");
 		gmt_M_free (GMT, k);			gmt_M_free (GMT, to_GDALW->data);		gmt_M_str_free (to_GDALW->driver);
 		gmt_M_str_free (to_GDALW->type);	gmt_M_free (GMT, to_GDALW);
 		return (GMT_GRDIO_OPEN_FAILED);
@@ -2186,7 +2186,7 @@ int gmt_gdal_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gm
 /* 23: ESRI Arc/Info ASCII interchange format */
 #include "gmt_esri_io.c"
 
-void gmt_grdio_init (struct GMT_CTRL *GMT) {
+void gmtlib_grdio_init (struct GMT_CTRL *GMT) {
 	unsigned int id;
 
 	/* First element is empty */
@@ -2453,14 +2453,14 @@ void gmt_grdio_init (struct GMT_CTRL *GMT) {
 }
 
 /* Comparator for qsort in gmt_grdformats_sorted() */
-GMT_LOCAL int customio_compare_grd_fmt_strings(const void* a, const void* b) {
+GMT_LOCAL int gmtcustomio_compare_grd_fmt_strings (const void* a, const void* b) {
 	const char **ia = (const char **)a;
 	const char **ib = (const char **)b;
 	return strncmp(*ia, *ib, 2);
 }
 
 /* This function sorts the grid formats alphabetically by their type id */
-char **gmt_grdformats_sorted (struct GMT_CTRL *Ctrl) {
+char ** gmt_grdformats_sorted (struct GMT_CTRL *Ctrl) {
 	static char *formats_sorted[GMT_N_GRD_FORMATS];
 	static bool sorted = false;
 
@@ -2470,7 +2470,7 @@ char **gmt_grdformats_sorted (struct GMT_CTRL *Ctrl) {
 	/* copy array with char pointers to type id strings: */
 	memcpy (formats_sorted, Ctrl->session.grdformat, GMT_N_GRD_FORMATS * sizeof(char*));
 	/* sort pointers beginning from the 2nd element: */
-	qsort (formats_sorted + 1, GMT_N_GRD_FORMATS - 1, sizeof(char*), &customio_compare_grd_fmt_strings);
+	qsort (formats_sorted + 1, GMT_N_GRD_FORMATS - 1, sizeof(char*), &gmtcustomio_compare_grd_fmt_strings);
 	sorted = true;
 
 	return formats_sorted;
