@@ -1,7 +1,6 @@
 /*--------------------------------------------------------------------
- *	$Id$
  *
- *	Copyright (c) 1991-2019 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -13,13 +12,13 @@
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU Lesser General Public License for more details.
  *
- *	Contact info: gmt.soest.hawaii.edu
+ *	Contact info: www.generic-mapping-tools.org
  *--------------------------------------------------------------------*/
 /* gmt_decorate.h - structures and variables needed for decorating lines.
 
    Author:	Paul Wessel
    Date:	1 OCT 2015
-   Version:	5 API
+   Version:	6 API
 
    This include file defines structures and functions used.
 */
@@ -29,8 +28,8 @@
  * \brief Structures and variables needed for decorating lines.
  */
 
-#ifndef _GMT_DECORATE_H
-#define _GMT_DECORATE_H
+#ifndef GMT_DECORATE_H
+#define GMT_DECORATE_H
 
 /*! Various settings for symbol placements along lines */
 enum GMT_enum_decorate {
@@ -64,13 +63,14 @@ struct GMT_DECORATE {
 	bool do_interpolate;		/* true if we must resample the crossing lines */
 	bool fixed;			/* true if we chose fixed positions */
 	bool debug;			/* true of we want to draw helper lines/points */
-	char line_name[16];		/* Name of line: contour or line */
-	char file[GMT_BUFSIZ];		/* File with crossing lines, if specified */
+	bool invisible;			/* true if we do not want to draw the line itself */
+	char line_name[16];		/* Name of line: "contour" or "line" */
+	char file[PATH_MAX];		/* File with crossing lines, if specified */
 	char option[GMT_BUFSIZ];	/* Copy of the option string */
 	char size[GMT_LEN64];		/* The symbol size */
 	char fill[GMT_LEN64];		/* The symbol fill */
 	char pen[GMT_LEN64];		/* The symbol outline pen */
-	char symbol_code[2];		/* The symbol code only as a null-terminated string */
+	char symbol_code[GMT_LEN64];	/* The symbol code only as a null-terminated string */
 	char flag;			/* Char for the option key */
 	struct GMT_DATASET *X;		/* Dataset with list of structures with crossing-line coordinates */
 	struct GMT_XSEGMENT *ylist_XP;	/* Sorted y-segments for crossing-lines */
@@ -78,4 +78,4 @@ struct GMT_DECORATE {
 	struct GMT_XOVER XC;		/* Structure with resulting crossovers */
 };
 
-#endif /* _GMT_DECORATE_H */
+#endif /* GMT_DECORATE_H */
