@@ -1,7 +1,6 @@
 /*--------------------------------------------------------------------
- *	$Id$
  *
- *	Copyright (c) 1991-2019 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -13,7 +12,7 @@
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU Lesser General Public License for more details.
  *
- *	Contact info: gmt.soest.hawaii.edu
+ *	Contact info: www.generic-mapping-tools.org
  *--------------------------------------------------------------------*/
  /* Contains the read/write functions needed to handle ERSI Arc/Info ASCII Exchange grids.
   * Based on previous code in grd2xyz and xyz2grd.  A few limitations of the format:
@@ -29,55 +28,56 @@
   * Joaquim Luis, Mars 2011.
   */
 
-#include "common_byteswap.h"
+#include "gmt_common_byteswap.h"
 
 /* Private function visible only in this file */
 
-GMT_LOCAL int esri_write_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HEADER *header) {
+GMT_LOCAL int gmtesriio_write_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HEADER *header) {
 	/* Note: fp is an open file pointer passed in; it will be closed upstream and not here */
 	char record[GMT_BUFSIZ] = {""}, item[GMT_LEN64] = {""};
 
-	sprintf (record, "ncols %d\nnrows %d\n", header->n_columns, header->n_rows);
+	snprintf (record, GMT_BUFSIZ, "ncols %d\nnrows %d\n", header->n_columns, header->n_rows);
 	gmt_M_fputs (record, fp);		/* Write a text record */
 	if (header->registration == GMT_GRID_PIXEL_REG) {	/* Pixel format */
 		sprintf (record, "xllcorner ");
-		sprintf (item, GMT->current.setting.format_float_out, header->wesn[XLO]);
+		snprintf (item, GMT_LEN64, GMT->current.setting.format_float_out, header->wesn[XLO]);
 		strcat  (record, item);	strcat  (record, "\n");
 		gmt_M_fputs (record, fp);		/* Write a text record */
 		sprintf (record, "yllcorner ");
-		sprintf (item, GMT->current.setting.format_float_out, header->wesn[YLO]);
+		snprintf (item, GMT_LEN64, GMT->current.setting.format_float_out, header->wesn[YLO]);
 		strcat  (record, item);	strcat  (record, "\n");
 		gmt_M_fputs (record, fp);		/* Write a text record */
 	}
 	else {	/* Gridline format */
 		sprintf (record, "xllcenter ");
-		sprintf (item, GMT->current.setting.format_float_out, header->wesn[XLO]);
+		snprintf (item, GMT_LEN64, GMT->current.setting.format_float_out, header->wesn[XLO]);
 		strcat  (record, item);	strcat  (record, "\n");
 		gmt_M_fputs (record, fp);		/* Write a text record */
 		sprintf (record, "yllcenter ");
-		sprintf (item, GMT->current.setting.format_float_out, header->wesn[YLO]);
+		snprintf (item, GMT_LEN64, GMT->current.setting.format_float_out, header->wesn[YLO]);
 		strcat  (record, item);	strcat  (record, "\n");
 		gmt_M_fputs (record, fp);		/* Write a text record */
 	}
 	sprintf (record, "cellsize ");
-	sprintf (item, GMT->current.setting.format_float_out, header->inc[GMT_X]);
+	snprintf (item, GMT_LEN64, GMT->current.setting.format_float_out, header->inc[GMT_X]);
 	strcat  (record, item);	strcat  (record, "\n");
 	gmt_M_fputs (record, fp);		/* Write a text record */
 	if (isnan (header->nan_value)) {
-		GMT_Report (GMT->parent, GMT_MSG_VERBOSE, "Warning: ESRI Arc/Info ASCII Interchange file must use proxy for NaN; default to -9999\n");
+		GMT_Report (GMT->parent, GMT_MSG_WARNING, "ESRI Arc/Info ASCII Interchange file must use proxy for NaN; default to -9999\n");
 		header->nan_value = -9999.0f;
 	}
-	sprintf (record, "nodata_value %ld\n", lrintf (header->nan_value));
+	snprintf (record, GMT_BUFSIZ, "nodata_value %ld\n", lrintf (header->nan_value));
 	gmt_M_fputs (record, fp);		/* Write a text record */
 
 	return (GMT_NOERROR);
 }
 
-GMT_LOCAL int esri_read_info_hdr (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
+GMT_LOCAL int gmtesriio_read_info_hdr (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	/* Parse the contents of a .HDR file */
-	int nB;
+	int nB, error;
 	char record[GMT_BUFSIZ];
 	FILE *fp = NULL;
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
 	if ((fp = gmt_fopen (GMT, header->title, "r")) == NULL) return (GMT_GRDIO_OPEN_FAILED);
 
@@ -85,156 +85,165 @@ GMT_LOCAL int esri_read_info_hdr (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *
 	header->z_scale_factor = 1.0;
 	header->z_add_offset   = 0.0;
 
-	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* BYTEORDER */ 
+	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* BYTEORDER */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* LAYOUT */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %d", &header->n_rows) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding NROWS record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding NROWS record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %d", &header->n_columns) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding NCOLS record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding NCOLS record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %d", &nB) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding NBANDS record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding NBANDS record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	if (nB != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Cannot read file with number of Bands != 1 \n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Cannot read file with number of Bands != 1 \n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %d", &header->bits) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding NBITS record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding NBITS record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	if ( header->bits != 16 && header->bits != 32 ) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: This data type (%d bits) is not supported\n", header->bits);
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: This data type (%d bits) is not supported\n", header->bits);
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
-	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* BANDROWBYTES  */ 
+	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* BANDROWBYTES  */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* TOTALROWBYTES */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);		/* BANDGAPBYTES  */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	while (strncmp (record, "NODATA", 6) )		/* Keep reading till find this keyword */
 		gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
+#ifdef DOUBLE_PRECISION_GRID
+	if (sscanf (record, "%*s %lf", &header->nan_value) != 1) {
+#else
 	if (sscanf (record, "%*s %f", &header->nan_value) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding nan_value_value record\n");
+#endif
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding nan_value_value record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->wesn[XLO]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding ULXMAP record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding ULXMAP record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->wesn[YHI]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding ULYMAP record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding ULYMAP record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->inc[GMT_X]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding XDIM record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding XDIM record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->inc[GMT_Y]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding YDIM record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding YDIM record\n");
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
-			
+
 	gmt_fclose (GMT, fp);
+	HH->orig_datatype = (header->bits == 16) ? GMT_SHORT : GMT_INT;
 
 	header->wesn[XHI] = header->wesn[XLO] + (header->n_columns - 1 + header->registration) * header->inc[GMT_X];
 	header->wesn[YLO] = header->wesn[YHI] - (header->n_rows - 1 + header->registration) * header->inc[GMT_Y];
 
-	gmt_M_err_fail (GMT, gmt_grd_RI_verify (GMT, header, 1), header->name);
+	if ((error = gmt_M_err_fail (GMT, gmt_grd_RI_verify (GMT, header, 1), HH->name)))
+		return error;
 
 	return (GMT_NOERROR);
 }
 
-GMT_LOCAL int esri_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HEADER *header) {
+GMT_LOCAL int gmtesriio_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HEADER *header) {
 	/* Note: fp is an open file pointer passed in; it will be closed upstream and not here */
-	int c;
+	int c, error;
 	char record[GMT_BUFSIZ];
 	FILE *fp2 = NULL, *fpBAK = NULL;
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
 	header->registration = GMT_GRID_NODE_REG;
 	header->z_scale_factor = 1.0;
 	header->z_add_offset   = 0.0;
 
-	if (header->flags[0] == 'M' || header->flags[0] == 'I') {	/* We are dealing with a ESRI .hdr file */
+	if (HH->flags[0] == 'M' || HH->flags[0] == 'I') {	/* We are dealing with a ESRI .hdr file */
 		int error;
-		if ((error = esri_read_info_hdr (GMT, header)) != 0) 		/* Continue the work someplace else */
+		if ((error = gmtesriio_read_info_hdr (GMT, header)) != 0) 		/* Continue the work someplace else */
 			return (error);
 		else
 			return (GMT_NOERROR);
 	}
-	else if (header->flags[0] == 'B' && header->flags[1] == '0') {	/* A GTOPO30 or SRTM30 file */
+	else if (HH->flags[0] == 'B' && HH->flags[1] == '0') {	/* A GTOPO30 or SRTM30 file */
 		size_t len = strlen (header->title);
 
 		header->inc[GMT_X] = header->inc[GMT_Y] = 30.0 * GMT_SEC2DEG;	/* 30 arc seconds */
 		header->wesn[YHI] = atof (&header->title[len-2]);
-		if ( header->title[len-3] == 'S' || header->title[len-3] == 's' ) header->wesn[YHI] *= -1; 
+		if ( header->title[len-3] == 'S' || header->title[len-3] == 's' ) header->wesn[YHI] *= -1;
 		c = header->title[len-3];
 		header->title[len-3] = '\0';
 		header->wesn[XLO] = atof (&header->title[len-6]);
 		header->title[len-3] = (char)c;		/* Reset because this function is called at least twice */
-		if ( header->title[len-7] == 'W' || header->title[len-7] == 'w' ) header->wesn[XLO] *= -1; 
+		if ( header->title[len-7] == 'W' || header->title[len-7] == 'w' ) header->wesn[XLO] *= -1;
 		if (header->wesn[YHI] > -60) {
-			header->wesn[YLO] = header->wesn[YHI] - 50; 
-			header->wesn[XHI] = header->wesn[XLO] + 40; 
+			header->wesn[YLO] = header->wesn[YHI] - 50;
+			header->wesn[XHI] = header->wesn[XLO] + 40;
 			header->n_columns = 4800;
 			header->n_rows = 6000;
 		}
 		else {	/* Antarctica tiles cover 30 degrees of latitude and 60 degrees of longitude each have 3,600 rows and 7,200 columns */
-			header->wesn[YLO] = -90; 
-			header->wesn[XHI] = header->wesn[XLO] + 60; 
+			header->wesn[YLO] = -90;
+			header->wesn[XHI] = header->wesn[XLO] + 60;
 			header->n_columns = 7200;
 			header->n_rows = 3600;
 		}
 		header->registration = GMT_GRID_PIXEL_REG;
 		gmt_set_geographic (GMT, GMT_IN);
 		gmtlib_grd_set_units (GMT, header);
-		
+
 		/* Different sign of NaN value between GTOPO30 and SRTM30 grids */
-		if (strstr (header->name, ".DEM") || strstr (header->name, ".dem"))
+		if (strstr (HH->name, ".DEM") || strstr (HH->name, ".dem"))
 			header->nan_value = -9999.0f;
 		else
 			header->nan_value = 9999.0f;
 		header->bits = 16;		/* Temp pocket to store number of bits */
+		HH->orig_datatype = GMT_SHORT;
 		return (GMT_NOERROR);
 	}
-	else if (header->flags[0] == 'B' && header->flags[1] == '1') {	/* A SRTM3 or SRTM1 file */
+	else if (HH->flags[0] == 'B' && HH->flags[1] == '1') {	/* A SRTM3 or SRTM1 file */
 		size_t len = strlen (header->title);
 		struct stat F;
 
 		header->wesn[XLO] = atof (&header->title[len-3]);
-		if ( header->title[len-4] == 'W' || header->title[len-4] == 'w' ) header->wesn[XLO] *= -1; 
+		if ( header->title[len-4] == 'W' || header->title[len-4] == 'w' ) header->wesn[XLO] *= -1;
 		c = header->title[len-4];
 		header->title[len-4] = '\0';
 		header->wesn[YLO] = atof (&header->title[len-6]);
 		header->title[len-4] = (char)c;		/* Reset because this function is called at least twice */
-		if ( header->title[len-7] == 'S' || header->title[len-7] == 's' ) header->wesn[YLO] *= -1; 
-		header->wesn[YHI] = header->wesn[YLO] + 1; 
-		header->wesn[XHI] = header->wesn[XLO] + 1; 
+		if ( header->title[len-7] == 'S' || header->title[len-7] == 's' ) header->wesn[YLO] *= -1;
+		header->wesn[YHI] = header->wesn[YLO] + 1;
+		header->wesn[XHI] = header->wesn[XLO] + 1;
 		header->nan_value = -32768.0f;
 		header->bits = 16;		/* Temp pocket to store number of bits */
-		if (stat (header->name, &F))	/* Must finally find out if it is a 1 or 3 arcseconds file */
+		HH->orig_datatype = GMT_SHORT;
+		if (stat (HH->name, &F))	/* Must finally find out if it is a 1 or 3 arcseconds file */
 			return (GMT_GRDIO_STAT_FAILED);			/* Inquiry about file failed somehow */
 		if (F.st_size < 3e6) {		/* Actually the true size is 2884802 */
 			header->inc[GMT_X] = header->inc[GMT_Y] = 3.0 * GMT_SEC2DEG;	/* 3 arc seconds */
@@ -248,7 +257,7 @@ GMT_LOCAL int esri_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HE
 		gmtlib_grd_set_units (GMT, header);
 		return (GMT_NOERROR);
 	}
-	else if ((header->flags[0] == 'L' || header->flags[0] == 'B') && header->flags[1] == '2') {	/* A Arc/Info BINARY file */
+	else if ((HH->flags[0] == 'L' || HH->flags[0] == 'B') && HH->flags[1] == '2') {	/* A Arc/Info BINARY file */
 		if ((fp2 = gmt_fopen (GMT, header->title, "r")) == NULL) {
 			gmt_fclose (GMT, fp);
 			return (GMT_GRDIO_OPEN_FAILED);
@@ -261,39 +270,39 @@ GMT_LOCAL int esri_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HE
 
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %d", &header->n_columns) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding ncols record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding ncols record\n");
 		if (fpBAK) gmt_fclose (GMT, fp2);
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %d", &header->n_rows) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding nrows record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding nrows record\n");
 		if (fpBAK) gmt_fclose (GMT, fp2);
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->wesn[XLO]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding xll record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding xll record\n");
 		if (fpBAK) gmt_fclose (GMT, fp2);
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
-	gmtlib_str_tolower (record);
+	gmt_str_tolower (record);
 	if (!strncmp (record, "xllcorner", 9U)) header->registration = GMT_GRID_PIXEL_REG;	/* Pixel grid */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->wesn[YLO]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding yll record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding yll record\n");
 		if (fpBAK) gmt_fclose (GMT, fp2);
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
 	}
-	gmtlib_str_tolower (record);
+	gmt_str_tolower (record);
 	if (!strncmp (record, "yllcorner", 9U)) header->registration = GMT_GRID_PIXEL_REG;	/* Pixel grid */
 	gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 	if (sscanf (record, "%*s %lf", &header->inc[GMT_X]) != 1) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding cellsize record\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding cellsize record\n");
 		if (fpBAK) gmt_fclose (GMT, fp2);
 		gmt_fclose (GMT, fp);
 		return (GMT_GRDIO_READ_FAILED);
@@ -303,8 +312,12 @@ GMT_LOCAL int esri_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HE
 	ungetc (c, fp);	/* ...and put it back where it came from */
 	if (c == 'n' || c == 'N') {	/*	Assume this is a nodata_value record since we found an 'n|N' */
 		gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
+#ifdef DOUBLE_PRECISION_GRID
+		if (sscanf (record, "%*s %lf", &header->nan_value) != 1) {
+#else
 		if (sscanf (record, "%*s %f", &header->nan_value) != 1) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info ASCII Grid: Error decoding nan_value_value record\n");
+#endif
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info ASCII Grid: Error decoding nan_value_value record\n");
 			if (fpBAK) gmt_fclose (GMT, fp2);
 			gmt_fclose (GMT, fp);
 			return (GMT_GRDIO_READ_FAILED);
@@ -314,20 +327,22 @@ GMT_LOCAL int esri_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HE
 	header->wesn[XHI] = header->wesn[XLO] + (header->n_columns - 1 + header->registration) * header->inc[GMT_X];
 	header->wesn[YHI] = header->wesn[YLO] + (header->n_rows - 1 + header->registration) * header->inc[GMT_Y];
 
-	gmt_M_err_fail (GMT, gmt_grd_RI_verify (GMT, header, 1), header->name);
+	if ((error = gmt_M_err_fail (GMT, gmt_grd_RI_verify (GMT, header, 1), HH->name)))
+		return error;
 
 	if (fpBAK) {		/* Case of Arc/Info binary file with a separate header file. We still have things to do. */
 		char tmp[16];
 		/* Read an extra record containing the endianness info */
 		gmt_fgets (GMT, record, GMT_BUFSIZ, fp);
 		if (sscanf (record, "%*s %s", tmp) != 1) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Arc/Info BINARY Grid: Error decoding endianness record\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Arc/Info BINARY Grid: Error decoding endianness record\n");
 			gmt_fclose (GMT, fp2);
 			return (GMT_GRDIO_READ_FAILED);
 		}
-		header->flags[0] = (tmp[0] == 'L') ? 'L' : 'B';
+		HH->flags[0] = (tmp[0] == 'L') ? 'L' : 'B';
 
 		header->bits = 32;	/* Those float binary files */
+		HH->orig_datatype = GMT_FLOAT;
 		/* Ok, now as mentioned above undo the file pointer swapping (point again to data file) */
 		gmt_fclose (GMT, fp);
 		fp = fpBAK;
@@ -338,14 +353,15 @@ GMT_LOCAL int esri_read_info (struct GMT_CTRL *GMT, FILE *fp, struct GMT_GRID_HE
 	return (GMT_NOERROR);
 }
 
-int gmt_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
+int gmtlib_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	/* Determine if file is an ESRI Interchange ASCII file */
 	FILE *fp = NULL;
 	char record[GMT_BUFSIZ];
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
-	if (!strcmp (header->name, "="))
+	if (!strcmp (HH->name, "="))
 		return (GMT_GRDIO_PIPE_CODECHECK);	/* Cannot check on pipes */
-	if ((fp = gmt_fopen (GMT, header->name, "r")) == NULL)
+	if ((fp = gmt_fopen (GMT, HH->name, "r")) == NULL)
 		return (GMT_GRDIO_OPEN_FAILED);
 
 	if (fgets (record, GMT_BUFSIZ, fp) == NULL) {	/* Just get first line. Not using gmt_fgets since we may be reading a binary file */
@@ -358,10 +374,11 @@ int gmt_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 		char *file = NULL;
 		size_t name_len;
 
+		HH->orig_datatype = GMT_SHORT;	/* May be overridden below */
 		/* If it got here, see if a companion .hdr file exists (must test upper & lower cases names) */
-		file = strdup (header->name);
+		file = strdup (HH->name);
 		gmt_chop_ext (file);
-		name_len = strlen (header->name);
+		name_len = strlen (HH->name);
 		if (name_len < strlen(file) + 4) {
 			/* The file extension had less than 3 chars, which means that 1) it's not an esri file.
 			   2) would corrupt the heap with the later strcat (file, ".hdr");
@@ -369,7 +386,7 @@ int gmt_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 			gmt_M_str_free (file);
 			return (-1);
 		}
-		if (isupper ((unsigned char) header->name[name_len - 1]))
+		if (isupper ((unsigned char) HH->name[name_len - 1]))
 			strcat (file, ".HDR");
 		else
 			strcat (file, ".hdr");
@@ -381,13 +398,14 @@ int gmt_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 			gmt_fclose (GMT, fp);
 
 			if (!strncmp (record, "BYTEORDER", 9) ) {
-				sscanf (record, "%*s %c", &header->flags[0]);	/* Store the endianness flag here */
+				sscanf (record, "%*s %c", &HH->flags[0]);	/* Store the endianness flag here */
 				strncpy (header->title, file, GMT_GRID_TITLE_LEN80-1);
 			}
 			else if (!strncmp (record, "ncols ", 6) ) {	/* Ah. A Arc/Info float binary file with a separate .hdr */
 				strncpy (header->title, file, GMT_GRID_TITLE_LEN80-1);
-				header->flags[0] = 'L';	/* If is truly 'L' or 'B' we'll find only when parsing the whole header */
-				header->flags[1] = '2';	/* Flag to let us know the file type */
+				HH->flags[0] = 'L';	/* If is truly 'L' or 'B' we'll find only when parsing the whole header */
+				HH->flags[1] = '2';	/* Flag to let us know the file type */
+				HH->orig_datatype = GMT_FLOAT;
 			}
 			else {	/* Cannot do anything with this data */
 				gmt_M_str_free (file);
@@ -407,22 +425,24 @@ int gmt_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 				(file[len-7] == 'W' || file[len-7] == 'w' || file[len-7] == 'E' || file[len-7] == 'e')) {
 				/* It is a GTOPO30 or SRTM30 source file without a .hdr companion. */
 				/* see http://dds.cr.usgs.gov/srtm/version1/SRTM30/GTOPO30_Documentation */
-				header->flags[0] = 'B';		/* GTOPO30 & SRTM30 are Big Endians */
-				header->flags[1] = '0';		/* Flag to let us know the file type */
+				HH->flags[0] = 'B';		/* GTOPO30 & SRTM30 are Big Endians */
+				HH->flags[1] = '0';		/* Flag to let us know the file type */
 				/* Store the file name with all extensions removed.
 				 * We'll use this to create header from file name info */
 				strncpy (header->title, file, GMT_GRID_TITLE_LEN80-1);
 				strcpy  (header->remark, "Assumed to be a GTOPO30 or SRTM30 tile");
+				HH->orig_datatype = GMT_SHORT;
 			}
-			else if (name_len > 3 && !(strncmp (&header->name[name_len-4], ".hgt", 4) && strncmp (&header->name[name_len-4], ".HGT", 4))) {
-				/* Probably a SRTM1|3 file. In esri_read_info we'll check further if it is a 1 or 3 sec */
+			else if (name_len > 3 && !(strncmp (&HH->name[name_len-4], ".hgt", 4) && strncmp (&HH->name[name_len-4], ".HGT", 4))) {
+				/* Probably a SRTM1|3 file. In gmtesriio_read_info we'll check further if it is a 1 or 3 sec */
 				if ((file[len-4] == 'E' || file[len-4] == 'e' || file[len-4] == 'W' || file[len-4] == 'w') &&
 					(file[len-7] == 'N' || file[len-7] == 'n' || file[len-7] == 'S' || file[len-7] == 's')) {
-					header->flags[0] = 'B';	/* SRTM1|3 are Big Endians */
-					header->flags[1] = '1';	/* Flag to let us know the file type */
+					HH->flags[0] = 'B';	/* SRTM1|3 are Big Endians */
+					HH->flags[1] = '1';	/* Flag to let us know the file type */
 					/* Store the file name with all extensions removed.
 					 * We'll use this to create header from file name info */
 					strncpy (header->title, file, GMT_GRID_TITLE_LEN80-1);
+					HH->orig_datatype = GMT_SHORT;
 				}
 			}
 			else {
@@ -440,38 +460,40 @@ int gmt_is_esri_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 int gmt_esri_read_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	int error;
 	FILE *fp = NULL;
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
-	if (!strcmp (header->name, "="))	/* Pipe in from stdin */
+	if (!strcmp (HH->name, "="))	/* Pipe in from stdin */
 		fp = GMT->session.std[GMT_IN];
-	else if ((fp = gmt_fopen (GMT, header->name, "r")) == NULL)
+	else if ((fp = gmt_fopen (GMT, HH->name, "r")) == NULL)
 		return (GMT_GRDIO_OPEN_FAILED);
 
-	if ((error = esri_read_info (GMT, fp, header)) != 0) {
+	if ((error = gmtesriio_read_info (GMT, fp, header)) != 0) {
 		gmt_fclose (GMT, fp);
 		return (error);
 	}
 
 	gmt_fclose (GMT, fp);
-		
+
 	return (GMT_NOERROR);
 }
 
 int gmt_esri_write_grd_info (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	FILE *fp = NULL;
-	
-	if (!strcmp (header->name, "="))	/* Write to stdout */
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
+
+	if (!strcmp (HH->name, "="))	/* Write to stdout */
 		fp = GMT->session.std[GMT_OUT];
-	else if ((fp = gmt_fopen (GMT, header->name, "w")) == NULL)
+	else if ((fp = gmt_fopen (GMT, HH->name, "w")) == NULL)
 		return (GMT_GRDIO_CREATE_FAILED);
-	
-	esri_write_info (GMT, fp, header);
+
+	gmtesriio_write_info (GMT, fp, header);
 
 	gmt_fclose (GMT, fp);
-	
+
 	return (GMT_NOERROR);
 }
 
-int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, float *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
+int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_grdfloat *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
 	int error;
 	bool check, is_binary = false, swap = false;
 	unsigned int col, height_in, ii, in_nx;
@@ -482,13 +504,14 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 	size_t n_expected;
 	char *r_mode = NULL;
 	int16_t *tmp16 = NULL;
-	float value, *tmp = NULL;
+	gmt_grdfloat value, *tmp = NULL;
 	FILE *fp = NULL;
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
-	if (header->flags[0]) {	/* We are dealing with a ESRI .hdr file or GTOPO30, SRTM30, SRTM1|3 */
+	if (HH->flags[0]) {	/* We are dealing with a ESRI .hdr file or GTOPO30, SRTM30, SRTM1|3 */
 		r_mode = "rb";
-		if (((header->flags[0] == 'M' || header->flags[0] == 'B') && !GMT_BIGENDIAN) ||
-			(header->flags[0] == 'L' && GMT_BIGENDIAN)) 
+		if (((HH->flags[0] == 'M' || HH->flags[0] == 'B') && !GMT_BIGENDIAN) ||
+			(HH->flags[0] == 'L' && GMT_BIGENDIAN))
 			swap = true;
 		nBits = header->bits;
 		is_binary = true;
@@ -496,18 +519,18 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 	else
 		r_mode = GMT->current.io.r_mode;
 
-	if (!strcmp (header->name, "="))	/* Read from pipe */
+	if (!strcmp (HH->name, "="))	/* Read from pipe */
 		fp = GMT->session.std[GMT_IN];
-	else if ((fp = gmt_fopen (GMT, header->name, r_mode)) != NULL) {
-		if ((error = esri_read_info (GMT, fp, header)) != 0) {
+	else if ((fp = gmt_fopen (GMT, HH->name, r_mode)) != NULL) {
+		if ((error = gmtesriio_read_info (GMT, fp, header)) != 0) {
 			gmt_fclose (GMT, fp);
 			return (error);
 		}
 	}
 	else
 		return (GMT_GRDIO_OPEN_FAILED);
-	
-	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_in, &height_in, &first_col, &last_col, &first_row, &last_row, &actual_col), header->name);
+
+	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_in, &height_in, &first_col, &last_col, &first_row, &last_row, &actual_col), HH->name);
 	(void)gmtlib_init_complex (header, complex_mode, &imag_offset);	/* Set offset for imaginary complex component */
 
 	width_out = width_in;		/* Width of output array */
@@ -521,7 +544,7 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 		tmp16 = gmt_M_memory (GMT, NULL, n_expected, int16_t);
 
 	header->z_min = DBL_MAX;	header->z_max = -DBL_MAX;
-	header->has_NaNs = GMT_GRID_NO_NANS;	/* We are about to check for NaNs and if none are found we retain 1, else 2 */
+	HH->has_NaNs = GMT_GRID_NO_NANS;	/* We are about to check for NaNs and if none are found we retain 1, else 2 */
 	if (is_binary) {
 		int n_rows = header->n_rows;
 		if (last_row - first_row + 1 != n_rows)		/* We have a sub-region */
@@ -571,7 +594,7 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 					grid[kk] = tmp16[actual_col[col]];
 				}
 				if (grid[kk] == header->nan_value) {
-					header->has_NaNs = GMT_GRID_HAS_NANS;
+					HH->has_NaNs = GMT_GRID_HAS_NANS;
 					grid[kk] = GMT->session.f_NaN;
 				}
 				else {		 /* Update z_min, z_max */
@@ -592,7 +615,11 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 		check = !isnan (header->nan_value);
 		in_nx = header->n_columns;
 		header->n_columns = width_in;	/* Needed to be set here due to gmt_M_ijp below */
+#ifdef DOUBLE_PRECISION_GRID
+		while (fscanf (fp, "%lf", &value) == 1 && n_left) {	/* We read all values and skip those not inside our w/e/s/n */
+#else
 		while (fscanf (fp, "%f", &value) == 1 && n_left) {	/* We read all values and skip those not inside our w/e/s/n */
+#endif
 			tmp[col] = value;	/* Build up a single input row */
 			col++;
 			if (col == in_nx) {	/* End of input row */
@@ -602,7 +629,7 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 						kk = ij + ii;
 						grid[kk] = (check && tmp[actual_col[ii]] == header->nan_value) ? GMT->session.f_NaN : tmp[actual_col[ii]];
 						if (gmt_M_is_fnan (grid[kk])) {
-							header->has_NaNs = GMT_GRID_HAS_NANS;
+							HH->has_NaNs = GMT_GRID_HAS_NANS;
 							continue;
 						}
 						/* Update z_min, z_max */
@@ -616,6 +643,8 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 			n_left--;
 		}
 	}
+	if (header->z_min == DBL_MAX && header->z_max == -DBL_MAX) /* No valid data values in the grid */
+		header->z_min = header->z_max = NAN;
 
 	gmt_fclose (GMT, fp);
 	gmt_M_free (GMT, actual_col);
@@ -623,7 +652,7 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 	if (nBits != 32) gmt_M_free (GMT, tmp16);
 
 	if (n_left) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Expected % "PRIu64 " points, found only % "PRIu64 "\n", header->nm, header->nm - n_left);
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Expected % "PRIu64 " points, found only % "PRIu64 "\n", header->nm, header->nm - n_left);
 		return (GMT_GRDIO_READ_FAILED);
 	}
 
@@ -634,24 +663,25 @@ int gmt_esri_read_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, flo
 	return (GMT_NOERROR);
 }
 
-int gmt_esri_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, float *grid, double wesn[], unsigned int *pad, unsigned int complex_mode, bool floating) {
+int gmt_esri_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_grdfloat *grid, double wesn[], unsigned int *pad, unsigned int complex_mode, bool floating) {
 	unsigned int i2, j, j2, width_out, height_out, last;
 	int first_col, last_col, first_row, last_row;
 	unsigned int i, *actual_col = NULL;
 	uint64_t ij, width_in, kk, imag_offset;
 	char item[GMT_LEN64], c[2] = {0, 0};
 	FILE *fp = NULL;
+	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
 
 	if (fabs (header->inc[GMT_X] / header->inc[GMT_Y] - 1.0) > GMT_CONV8_LIMIT)
 		return (GMT_GRDIO_ESRI_NONSQUARE);	/* Only square pixels allowed */
-	if (!strcmp (header->name, "="))	/* Write to pipe */
+	if (!strcmp (HH->name, "="))	/* Write to pipe */
 		fp = GMT->session.std[GMT_OUT];
-	else if ((fp = gmt_fopen (GMT, header->name, GMT->current.io.w_mode)) == NULL)
+	else if ((fp = gmt_fopen (GMT, HH->name, GMT->current.io.w_mode)) == NULL)
 		return (GMT_GRDIO_CREATE_FAILED);
 	else
-		esri_write_info (GMT, fp, header);
+		gmtesriio_write_info (GMT, fp, header);
 
-	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_out, &height_out, &first_col, &last_col, &first_row, &last_row, &actual_col), header->name);
+	gmt_M_err_pass (GMT, gmt_grd_prep_io (GMT, header, wesn, &width_out, &height_out, &first_col, &last_col, &first_row, &last_row, &actual_col), HH->name);
 	(void)gmtlib_init_complex (header, complex_mode, &imag_offset);	/* Set offset for imaginary complex component */
 
 	width_in = width_out;		/* Physical width of input array */
@@ -671,13 +701,13 @@ int gmt_esri_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, fl
 			if (i == last) c[0] = '\n';
 			kk = ij+actual_col[i];
 			if (gmt_M_is_fnan (grid[kk]))
-				sprintf (item, "%ld%c", lrintf (header->nan_value), c[0]);
+				snprintf (item, GMT_LEN64, "%ld%c", lrintf (header->nan_value), c[0]);
 			else if (floating) {
-				sprintf (item, GMT->current.setting.format_float_out, grid[kk]);
+				snprintf (item, GMT_LEN64-1, GMT->current.setting.format_float_out, grid[kk]);
 				strcat (item, c);
 			}
 			else
-				sprintf (item, "%ld%c", lrint ((double)grid[kk]), c[0]);
+				snprintf (item, GMT_LEN64, "%ld%c", lrint ((double)grid[kk]), c[0]);
 			gmt_M_fputs (item, fp);
 		}
 	}
@@ -688,12 +718,12 @@ int gmt_esri_write_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, fl
 	return (GMT_NOERROR);
 }
 
-int gmt_esri_writei_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, float *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
+int gmt_esri_writei_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_grdfloat *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
 	/* Standard integer values on output only */
 	return (gmt_esri_write_grd (GMT, header, grid, wesn, pad, complex_mode, false));
 }
 
-int gmt_esri_writef_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, float *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
+int gmt_esri_writef_grd (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header, gmt_grdfloat *grid, double wesn[], unsigned int *pad, unsigned int complex_mode) {
 	/* Write floating point on output */
 	return (gmt_esri_write_grd (GMT, header, grid, wesn, pad, complex_mode, true));
 }
