@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
  * The API presently consists of 52 documented functions.  For a full
  * description of the API, see the GMT_API documentation.
  * These functions have Fortran bindings as well, provided you add
- * -DFORTRAN_API to the C preprocessor flags [in ConfigUser.cmake].
+ * -DFORTRAN_API to the C preprocessor flags [in ConfigUserAdvanced.cmake].
  *
  * Here lie the 13 public functions used for GMT API command parsing:
  *
@@ -32,7 +32,7 @@
  * GMT_Destroy_Options  : Delete the linked option list
  * GMT_Create_Args      : Convert a struct option list back to an array of text args
  * GMT_Destroy_Args     : Delete the array of text args
- * GMT_Create_Cmd       : Convert a struct option list to a single command text. 
+ * GMT_Create_Cmd       : Convert a struct option list to a single command text.
  * GMT_Destroy_Cmd      : Delete the command string
  * GMT_Make_Option      : Create a single option structure given arguments
  * GMT_Find_Option      : Find a specified option in the linked option list
@@ -56,7 +56,7 @@
  * \file gmt_parse.c
  * \brief Public function prototypes for GMT API option parsing.
  */
- 
+
 #include "gmt_dev.h"
 #include "gmt_internals.h"
 
@@ -64,20 +64,18 @@ static char *GMT_unique_option[GMT_N_UNIQUE] = {	/* The common GMT command-line
 #include "gmt_unique.h"
 };
 
-EXTERN_MSC int gmtapi_report_error	(void *C, int error);	/* Lives in gmt_api.c */
-
 /* Some private macros and inline function used in this file */
-#define ptr_return(API,err,ptr)   { gmtapi_report_error(API,err); return (ptr);}
-#define return_null(API,err)      { gmtapi_report_error(API,err); return (NULL);}
-#define return_error(API,err)     { gmtapi_report_error(API,err); return (err);}
-#define return_value(API,err,val) { gmtapi_report_error(API,err); return (val);}
+#define ptr_return(API,err,ptr)   { gmtlib_report_error(API,err); return (ptr);}
+#define return_null(API,err)      { gmtlib_report_error(API,err); return (NULL);}
+#define return_error(API,err)     { gmtlib_report_error(API,err); return (err);}
+#define return_value(API,err,val) { gmtlib_report_error(API,err); return (val);}
 
-static inline struct GMTAPI_CTRL * parse_get_api_ptr (struct GMTAPI_CTRL *ptr) {return (ptr);}
+static inline struct GMTAPI_CTRL *gmtparse_get_api_ptr (struct GMTAPI_CTRL *ptr) {return (ptr);}
 
 /* Local functions */
 
 /*! . */
-GMT_LOCAL int parse_B_arg_inspector (struct GMT_CTRL *GMT, char *in) {
+GMT_LOCAL int gmtparse_B_arg_inspector (struct GMT_CTRL *GMT, char *in) {
 	/* Determines if the -B option indicates old GMT4-style switches and flags
 	 * or if it follows the GMT 5 specification.  This is only called when
 	 * compatibility mode has been selected; otherwise we only check GMT 5
@@ -90,7 +88,7 @@ GMT_LOCAL int parse_B_arg_inspector (struct GMT_CTRL *GMT, char *in) {
 	bool ignore5 = false;	/* true if label, title, prefix, suffix */
 	bool custom = false;	/* True if -B[p|s][x|y|z]c<filename> was given; then we relax checing for .c (old second) */
 	char mod = 0;
-	
+
 	if (!in || in[0] == 0) return (9);	/* Just a safety precaution, 9 means "either" syntax but it is an empty string */
 	last = strlen (in);
 	for (k = 0; k < last; k++) {	/* Count digits.  If none then it is GMT5 and we can return */
@@ -155,29 +153,29 @@ GMT_LOCAL int parse_B_arg_inspector (struct GMT_CTRL *GMT, char *in) {
 	if (n_colons && (n_colons % 2) == 0) gmt4++;	/* Presumably :labels: in GMT4 style as any +mod would have kicked in above */
 	if (!custom && n_slashes) gmt4++;		/* Presumably / to separate axis in GMT4 style */
 	if (colon_text) gmt4++;				/* Gave title, suffix, prefix in GMT4 style */
-	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "parse_B_arg_inspector: GMT4 = %d vs. GMT = %d\n", gmt4, gmt5);
+	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "gmtparse_B_arg_inspector: GMT4 = %d vs. GMT = %d\n", gmt4, gmt5);
 	if (gmt5 && !gmt4) {
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "parse_B_arg_inspector: Detected GMT >=5 style elements in -B option\n");
+		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "gmtparse_B_arg_inspector: Detected GMT >=5 style elements in -B option\n");
 		return (5);
 	}
 	else if (gmt4 && !gmt5) {
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "parse_B_arg_inspector: Detected GMT 4 style elements in -B option\n");
+		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "gmtparse_B_arg_inspector: Detected GMT 4 style elements in -B option\n");
 		return (4);
 	}
 	else if (gmt4 && gmt5) {	/* Mixed case is never allowed */
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "parse_B_arg_inspector: Detected both GMT 4 and >= style elements in -B option. Unable to parse.\n");
-		if (n_slashes) GMT_Report (GMT->parent, GMT_MSG_NORMAL, "parse_B_arg_inspector: Slashes no longer separate axis specifications, use -B[xyz] and repeat\n");
-		if (colon_text || n_colons) GMT_Report (GMT->parent, GMT_MSG_NORMAL, "parse_B_arg_inspector: Colons no longer used for titles, labels, prefix, and suffix; see +t, +l, +p, +s\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "gmtparse_B_arg_inspector: Detected both GMT 4 and >= style elements in -B option. Unable to parse.\n");
+		if (n_slashes) GMT_Report (GMT->parent, GMT_MSG_ERROR, "gmtparse_B_arg_inspector: Slashes no longer separate axis specifications, use -B[xyz] and repeat\n");
+		if (colon_text || n_colons) GMT_Report (GMT->parent, GMT_MSG_ERROR, "gmtparse_B_arg_inspector: Colons no longer used for titles, labels, prefix, and suffix; see +t, +l, +p, +s\n");
 		return (-1);
 	}
 	else {
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "parse_B_arg_inspector: Assume new GMT style format in -B option\n");
+		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "gmtparse_B_arg_inspector: Assume new GMT style format in -B option\n");
 		return (9);
 	}
 }
 
 /*! . */
-GMT_LOCAL int parse_check_b_options (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
+GMT_LOCAL int gmtparse_check_b_options (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
 	/* Determine how many -B options were given and if it is clear we are
 	 * dealing with GMT4 or GMT5 syntax just by looking at this information.
 	 * We also examine each argument for clues to version compatibility.
@@ -188,13 +186,13 @@ GMT_LOCAL int parse_check_b_options (struct GMT_CTRL *GMT, struct GMT_OPTION *op
 	struct GMT_OPTION *opt = NULL;
 	unsigned int n4_expected = 0, n_B = 0, gmt4 = 0, gmt5 = 0, k;
 	int verdict;
-	
+
 	for (opt = options; opt; opt = opt->next) {	/* Loop over all given options */
 		if (opt->option != 'B') continue;	/* Skip anything but -B options */
 		n_B++;					/* Count how many (max 2 in GMT4 if -Bp|s given) */
 		k = (opt->arg[0] == 'p' || opt->arg[0] == 's') ? 1 : 0;	/* Step over any p|s designation */
 		if (k == 1) n4_expected++;		/* Count how many -Bp or -Bs were given */
-		verdict = parse_B_arg_inspector (GMT, opt->arg);	/* Check this argument, return 5, 4, 1 (undetermined) or 0 (mixing) */
+		verdict = gmtparse_B_arg_inspector (GMT, opt->arg);	/* Check this argument, return 5, 4, 1 (undetermined) or 0 (mixing) */
 		if (verdict == 4) gmt4++;
 		if (verdict == 5) gmt5++;
 		if (verdict == -1) gmt4++, gmt5++;	/* This is bad and will lead to a syntax error */
@@ -207,26 +205,26 @@ GMT_LOCAL int parse_check_b_options (struct GMT_CTRL *GMT, struct GMT_OPTION *op
 	return (-1);				/* Error: Cannot be both */
 }
 
-GMT_LOCAL unsigned int count_slashes (char *txt) {
+GMT_LOCAL unsigned int gmtparse_count_slashes (char *txt) {
 	unsigned int i, n;
 	for (i = n = 0; txt[i]; i++) if (txt[i] == '/') n++;
 	return (n);
 }
 
 /*! . */
-GMT_LOCAL unsigned int parse_check_extended_R (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
+GMT_LOCAL unsigned int gmtparse_check_extended_R (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
 	/* In order to use -R[L|C|R][B|M|T]<lon0>/<lat0>/<n_columns>/<ny> we need access
 	 * to grid increments dx/dy, usually given via a -I option.  Hence, we here
 	 * make sure that if such a -R option is given we first process -I */
-	
+
 	struct GMT_OPTION *opt = NULL;
 	bool got_extended_R = false;
 	for (opt = options; opt; opt = opt->next) {
-		if (opt->option == 'R' && count_slashes (opt->arg) == 3 && strchr ("LCRlcr", opt->arg[0]) && strchr ("TMBtmb", opt->arg[1]))
+		if (opt->option == 'R' && gmtparse_count_slashes (opt->arg) == 3 && strchr ("LCRlcr", opt->arg[0]) && strchr ("TMBtmb", opt->arg[1]))
 			got_extended_R = true;
 	}
 	if (!got_extended_R) return 0;	/* No such situation */
-	
+
 	/* Now look for -Idx[/dy] option */
 	for (opt = options; opt; opt = opt->next) {
 		if (opt->option == 'I' && opt->arg[0]) {
@@ -237,14 +235,14 @@ GMT_LOCAL unsigned int parse_check_extended_R (struct GMT_CTRL *GMT, struct GMT_
 	}
 	if (GMT->common.R.active[ISET])
 		return 0;
-	GMT_Report (GMT->parent, GMT_MSG_NORMAL, "-R[L|C|R][T|M|B]<x0>/<y0>/<n_columns>/<ny> requires grid spacings via -I\n");
+	GMT_Report (GMT->parent, GMT_MSG_ERROR, "-R[L|C|R][T|M|B]<x0>/<y0>/<n_columns>/<ny> requires grid spacings via -I\n");
 	return 1;
 }
 
-#define Return { GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Found no history for option -%s\n", str); return (-1); }
+#define Return { GMT_Report (GMT->parent, GMT_MSG_ERROR, "Found no history for option -%s\n", str); return (-1); }
 
 /*! . */
-GMT_LOCAL int parse_complete_options (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
+GMT_LOCAL int gmtparse_complete_options (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
 	/* Go through the given arguments and look for shorthands,
 	 * i.e., -B, -J, -R, -X, -x, -Y, -c, -p. given without arguments.
 	 * If found, see if we have a matching command line history and then
@@ -276,12 +274,12 @@ GMT_LOCAL int parse_complete_options (struct GMT_CTRL *GMT, struct GMT_OPTION *o
 	}
 	for (k = 0, B_id = GMT_NOTSET; k < GMT_N_UNIQUE && B_id == GMT_NOTSET; k++)
 		if (!strcmp (GMT_unique_option[k], "B")) B_id = k;	/* B_id === 0 but just in case this changes we do this search anyway */
-
+	assert (B_id != GMT_NOTSET);	/* Safety valve just in case */
 	check_B = (strncmp (GMT->init.module_name, "psscale", 7U) && strncmp (GMT->init.module_name, "docs", 4U));
 	if (GMT->current.setting.run_mode == GMT_MODERN && n_B && check_B) {	/* Write gmt.frame file unless module is psscale, overwriting any previous file */
 		char file[PATH_MAX] = {""};
 		FILE *fp = NULL;
-		snprintf (file, PATH_MAX, "%s/gmt%d.%s/gmt.frame", GMT->parent->session_dir, GMT_MAJOR_VERSION, GMT->parent->session_name);
+		snprintf (file, PATH_MAX, "%s/gmt.frame", GMT->parent->gwf_dir);
 		if ((fp = fopen (file, "w")) == NULL) {
 			GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Unable to create file %s\n", file);
 			return (-1);
@@ -356,7 +354,7 @@ GMT_LOCAL int parse_complete_options (struct GMT_CTRL *GMT, struct GMT_OPTION *o
 			update_id = id = gmt_get_option_id (0, str);	/* If -R then we get id for RP */
 			if (id == GMT_NOTSET) Return;	/* Error: user gave shorthand option but there is no record in the history */
 			if (GMT->current.setting.run_mode == GMT_MODERN && opt->option == 'R') {	/* Must deal with both RP and RG under modern mode */
-				if (GMT->current.ps.active || !strncmp (GMT->init.module_name, "subplot", 7U) || !strncmp (GMT->init.module_name, "pscoast", 7U) || !strncmp (GMT->init.module_name, "psbasemap", 9U)) {	/* Plotting module plus special options to pscoast and psbasemap: First check RP if it exists */
+				if (gmtlib_module_may_get_R_from_RP (GMT, GMT->init.module_name)) {	/* First check -RP history */
 					if (!GMT->init.history[id]) id++;	/* No RP in the history, try RG next */
 				}
 				else {	/* Only try RG for non-plotting modules. RG follows RP in gmt_unique.h order [Modern mode only] */
@@ -409,7 +407,7 @@ int GMT_List_Args (void *V_API, struct GMT_OPTION *head) {
 	 */
 
 	struct GMT_OPTION *opt = NULL;
-	struct GMTAPI_CTRL *API = parse_get_api_ptr (V_API);
+	struct GMTAPI_CTRL *API = gmtparse_get_api_ptr (V_API);
 
 	if (head == NULL) return_error (API, GMT_OPTION_LIST_NULL);
 
@@ -434,7 +432,7 @@ int GMT_List_Args (void *V_API, struct GMT_OPTION *head) {
 #endif
 
 /*! . */
-GMT_LOCAL struct GMT_OPTION *fix_gdal_files (struct GMT_OPTION *opt) {
+GMT_LOCAL struct GMT_OPTION *gmtparse_fix_gdal_files (struct GMT_OPTION *opt) {
 	char *pch = NULL;
 	if (((pch = strstr (opt->arg, "+b")) != NULL) && !strstr(opt->arg, "=gd")) {
 		/* Here we deal with the case that the filename has embedded a band request for gdalread, as in img.tif+b1
@@ -445,7 +443,7 @@ GMT_LOCAL struct GMT_OPTION *fix_gdal_files (struct GMT_OPTION *opt) {
 		char t[GMT_LEN256] = {""};
 		pch[0] = '\0';
 		strncpy (t, opt->arg, GMT_LEN256-1);
-		strcat (t, "=gd"); 
+		strcat (t, "=gd");
 		pch[0] = '+';			/* Restore what we have erased 2 lines above */
 		strncat(t, pch, GMT_LEN256-1);
 		gmt_M_str_free (opt->arg);	/* free it so that we can extend it */
@@ -454,6 +452,37 @@ GMT_LOCAL struct GMT_OPTION *fix_gdal_files (struct GMT_OPTION *opt) {
 	return opt;
 }
 
+/*! */
+GMT_LOCAL void gmtparse_ensure_b_options_order (struct GMT_CTRL *GMT, struct GMT_OPTION *options) {
+	bool do_sort = false;
+	char *c = NULL;
+	unsigned int k, n_B = 0, this_priority, priority[12]; /* Worst case is -Bpx, -Bsx, ... */
+	struct GMT_OPTION *opt;
+
+	gmt_M_memset (priority, 12, unsigned int);
+
+	for (opt = options; opt; opt = opt->next) {
+		if (opt->option != 'B') continue;	/* Only look at -B options here */
+		if (gmtlib_B_is_frame (GMT, opt->arg)) continue;	/* Don't care about the frame setting here */
+		if ((c = gmt_first_modifier (GMT, opt->arg, "aflLpsSu"))) {	/* Option has axis modifier(s) */
+			c[0] = '\0';	/* Temporary chop them off */
+			k = 0;	/* Start of option string, then advance past any leading [p|s][x|y|z] */
+			if (strchr ("ps",  opt->arg[k])) k++;
+			if (strchr ("xyz", opt->arg[k])) k++;
+			this_priority = (opt->arg[k]) ? 1 : 2;	/* If nothing then probably just a label setting, else we have a leading interval setting */
+			c[0] = '+';	/* Restore modifiers */
+		}
+		else /* Must be interval setting */
+			this_priority = 1;
+		priority[n_B] = this_priority;
+		n_B++;
+	}
+	if (n_B < 2) return;	/* Nothing to sort */
+	for (k = 1; k < n_B; k++) if (priority[k] < priority[k-1]) do_sort = true;
+	if (!do_sort) return;	/* No need to sort */
+	GMT_Report (GMT->parent, GMT_MSG_WARNING, "GMT_Parse_Options: List interval-setting -B options before other axis -B options to ensure proper parsing.\n");
+}
+
 /*! . */
 struct GMT_OPTION *GMT_Create_Options (void *V_API, int n_args_in, const void *in) {
 	/* This function will loop over the n_args_in supplied command line arguments (in) and
@@ -481,7 +510,7 @@ struct GMT_OPTION *GMT_Create_Options (void *V_API, int n_args_in, const void *i
 	if (V_API == NULL) return_null (V_API, GMT_NOT_A_SESSION);		/* GMT_Create_Session has not been called */
 	if (in == NULL && n_args_in > 1) return_null (V_API, GMT_ARGV_LIST_NULL);	/* Gave no argument pointer but said we had at least 1 */
 	if (in == NULL) return (NULL);	/* Gave no argument pointer so a null struct is returned */
-	API = parse_get_api_ptr (V_API);	/* Convert V_API to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Convert V_API to a GMTAPI_CTRL pointer */
 	if (n_args_in < 0) {	/* Already was given a linked list.  Duplicate and return the copy */
 		struct GMT_OPTION *head_in = (struct GMT_OPTION *)in;
 		while (head_in) {
@@ -493,7 +522,7 @@ struct GMT_OPTION *GMT_Create_Options (void *V_API, int n_args_in, const void *i
 		}
 		return (head);
 	}
-	
+
 	G = API->GMT;	/* GMT control structure */
 	if (n_args_in == 0) {	/* Check if a single command line, if so break into tokens */
 		unsigned int pos = 0, new_n_args = 0, k;
@@ -505,7 +534,7 @@ struct GMT_OPTION *GMT_Create_Options (void *V_API, int n_args_in, const void *i
 		 * these items by temporarily replacing spaces inside quoted strings with ASCII 31 US (Unit Separator), do the strtok on
 		 * space, and then replace all ASCII 31 with space at the end (we do the same for tab using ASCII 29 GS (group separator) */
 		for (k = 0, quoted = false; txt_in[k]; k++) {
-			if (txt_in[k] == '\"') quoted = !quoted;	/* Initially false, becomes true at start of quote, then false when exit quote */
+			if (txt_in[k] == '\"' || txt_in[k] == '\'') quoted = !quoted;	/* Initially false, becomes true at start of quote, then false when exit quote */
 			else if (quoted && txt_in[k] == '\t') txt_in[k] = GMT_ASCII_GS;
 			else if (quoted && txt_in[k] == ' ')  txt_in[k] = GMT_ASCII_US;
 		}
@@ -532,30 +561,30 @@ struct GMT_OPTION *GMT_Create_Options (void *V_API, int n_args_in, const void *i
 		n_args = n_args_in;
 	}
 	if (args == NULL && n_args) return_null (API, GMT_ARGV_LIST_NULL);	/* Conflict between # of args and args being NULL */
-	
+
 	for (arg = 0; arg < n_args; arg++) {	/* Loop over all command arguments */
 
 		if (!args[arg]) continue;	/* Skip any NULL arguments quietly */
 
 		/* Note: The UNIX command line will never see redirections like >, >>, and < pass as arguments, so when we check for these
 		 * below it is because command-strings passed from external APIs may contain things like '-Fap -O -K >> plot.ps' */
-		
+
 		if (args[arg][0] == '=' && args[arg][1] && !gmt_access (API->GMT, &args[arg][1], F_OK)) {	/* Gave a file list which we must expand into options */
 			char **flist = NULL;
 			uint64_t n_files, f;
-			n_files = gmtlib_read_list (API->GMT, &args[arg][1], &flist);
+			n_files = gmt_read_list (API->GMT, &args[arg][1], &flist);
 			if ((new_opt = GMT_Make_Option (API, '=', &args[arg][1])) == NULL)	/* Make option with the listing name flagged as option -= */
 				return_null (API, error);	/* Create the new option structure given the args, or return the error */
 			head = GMT_Append_Option (API, new_opt, head);		/* Hook new option to the end of the list (or initiate list if head == NULL) */
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "GMT_Create_Options: Must expand list file %s\n", args[arg]);
+			GMT_Report (API, GMT_MSG_INFORMATION, "GMT_Create_Options: Must expand list file %s\n", args[arg]);
 			for (f = 0; f < n_files; f++) {	/* Now expand all the listed files into options */
 				GMT_Report (API, GMT_MSG_DEBUG, "GMT_Create_Options: Adding input file: %s\n", flist[f]);
 				if ((new_opt = GMT_Make_Option (API, GMT_OPT_INFILE, flist[f])) == NULL)
 					return_null (API, error);	/* Create the new option structure given the args, or return the error */
-				new_opt = fix_gdal_files (new_opt);
+				new_opt = gmtparse_fix_gdal_files (new_opt);
 				head = GMT_Append_Option (API, new_opt, head);		/* Hook new option to the end of the list (or initiate list if head == NULL) */
 			}
-			gmtlib_free_list (API->GMT, flist, n_files);
+			gmt_free_list (API->GMT, flist, n_files);
 			continue;
 		}
 		else if (args[arg][0] == '<' && !args[arg][1] && (arg+1) < n_args && args[arg+1][0] != '-')	/* string command with "< file" for input */
@@ -611,7 +640,7 @@ struct GMT_OPTION *GMT_Create_Options (void *V_API, int n_args_in, const void *i
 				return_null (API, error);	/* Create the new option structure given the args, or return the error */
 
 		if (option == GMT_OPT_INFILE)	/* A special check on infiles to see if they refer to GDAL implicitly */
-			new_opt = fix_gdal_files (new_opt);
+			new_opt = gmtparse_fix_gdal_files (new_opt);
 
 		head = GMT_Append_Option (API, new_opt, head);		/* Hook new option to the end of the list (or initiate list if head == NULL) */
 	}
@@ -649,11 +678,11 @@ int GMT_Destroy_Options (void *V_API, struct GMT_OPTION **head) {
 	struct GMTAPI_CTRL *API = NULL;
 
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
-	API = parse_get_api_ptr (V_API);	/* Cast to GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast to GMTAPI_CTRL pointer */
 
 	current = *head;
 	if (current && current->option < 0) {
-		GMT_Report(API, GMT_MSG_NORMAL, "WARNING in GMT_Destroy_Options(): GMT_OPTION struct has junk. Returning before crash\n");
+		GMT_Report(API, GMT_MSG_ERROR, "GMT_Destroy_Options(): GMT_OPTION struct has junk. Returning before crash\n");
 		*head = NULL;
 		return (GMT_OK);	/* Should we return an error state instead? */
 	}
@@ -669,14 +698,14 @@ int GMT_Destroy_Options (void *V_API, struct GMT_OPTION **head) {
 }
 
 /*! . */
-struct GMT_OPTION * GMT_Duplicate_Options (void *V_API, struct GMT_OPTION *head) {
+struct GMT_OPTION *GMT_Duplicate_Options (void *V_API, struct GMT_OPTION *head) {
 	/* Create an identical copy of the linked list of options pointed to by head */
 	struct GMT_OPTION *opt = NULL, *new_opt = NULL, *new_head = NULL;
 	struct GMTAPI_CTRL *API = NULL;
 
 	if (V_API == NULL) return_null (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 	if (head == NULL)  return_null (V_API, GMT_OPTION_LIST_NULL);	/* No list of options was given */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 
 	for (opt = head; opt; opt = opt->next) {	/* Loop over all options in the linked list */
 		if ((new_opt = GMT_Make_Option (API, opt->option, opt->arg)) == NULL)
@@ -693,7 +722,7 @@ int GMT_Free_Option (void *V_API, struct GMT_OPTION **opt) {
 	/* Free the memory pointed to by *opt */
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 	if (*opt == NULL)  return_error (V_API, GMT_OPTION_LIST_NULL);	/* No list of options was given */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 	gmt_M_str_free ((*opt)->arg);	/* The option had a text argument allocated by strdup, so free it first */
 	gmt_M_free (API->GMT, *opt);	/* Then free the structure which was allocated by gmt_M_memory */
 	*opt = NULL;
@@ -701,7 +730,7 @@ int GMT_Free_Option (void *V_API, struct GMT_OPTION **opt) {
 }
 
 /*! . */
-char **GMT_Create_Args (void *V_API, int *argc, struct GMT_OPTION *head) {
+char ** GMT_Create_Args (void *V_API, int *argc, struct GMT_OPTION *head) {
 	/* This function creates a character array with the command line options that
 	 * correspond to the linked options provided.  It is the inverse of GMT_Create_Options.
 	 * The number of array strings is returned via *argc.
@@ -716,7 +745,7 @@ char **GMT_Create_Args (void *V_API, int *argc, struct GMT_OPTION *head) {
 
 	if (V_API == NULL) return_null (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 	if (head == NULL)  return_null (V_API, GMT_OPTION_LIST_NULL);	/* No list of options was given */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 
 	*argc = 0;	/* Start off with no arguments */
 	for (opt = head; opt; opt = opt->next)	/* Loop over all options in the linked list */
@@ -754,7 +783,7 @@ char **GMT_Create_Args (void *V_API, int *argc, struct GMT_OPTION *head) {
 		*argc = arg;
 		txt = gmt_M_memory (G, txt, *argc, char *);
 	}
-	
+
 	return (txt);	/* Pass back the char** array to the calling module */
 }
 
@@ -768,7 +797,7 @@ int GMT_Destroy_Args (void *V_API, int argc, char **args[]) {
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);		/* GMT_Create_Session has not been called */
 	if (argc == 0 || !args) return_error (V_API, GMT_ARGV_LIST_NULL);	/* We were given no args to destroy, so there! */
 	if (argc < 0) return_error (V_API, GMT_COUNTER_IS_NEGATIVE);		/* We were given a negative count! */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 	/* Just deallocate the space taken by the list of arguments */
 	while (argc--) gmt_M_free (API->GMT, (*args)[argc]);
 	gmt_M_free (API->GMT, *args);	/* Free the array itself */
@@ -776,13 +805,14 @@ int GMT_Destroy_Args (void *V_API, int argc, char **args[]) {
 }
 
 /*! . */
-char * GMT_Create_Cmd (void *V_API, struct GMT_OPTION *head) {
+char *GMT_Create_Cmd (void *V_API, struct GMT_OPTION *head) {
 	/* This function creates a single character string with the command line options that
 	 * correspond to the linked options provided.
 	 */
 
 	char *txt = NULL, *c = NULL, buffer[GMT_BUFSIZ] = {""};
 	bool first = true, skip_infiles = false;
+	int k_data;
 	size_t length = 0, inc, n_alloc = GMT_BUFSIZ;
 	struct GMT_OPTION *opt = NULL;
 	struct GMT_CTRL *G = NULL;
@@ -790,7 +820,7 @@ char * GMT_Create_Cmd (void *V_API, struct GMT_OPTION *head) {
 
 	if (V_API == NULL) return_null (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 	if (head == NULL) return_null (V_API, GMT_OPTION_LIST_NULL);	/* No list of options was given */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 
 	G = API->GMT;	/* GMT control structure */
 	txt = gmt_M_memory (G, NULL, n_alloc, char);
@@ -805,10 +835,11 @@ char * GMT_Create_Cmd (void *V_API, struct GMT_OPTION *head) {
 		}
 		else if (opt->option == GMT_OPT_INFILE)	{	/* Option for input filename [or numbers] */
 			if (skip_infiles) continue;
-			if (gmtlib_file_is_srtmlist (API, opt->arg))	/* Want to replace the srtm list with the original @earth_relief_xxx name instead */
-				snprintf (buffer, GMT_BUFSIZ, "@earth_relief_0%cs", opt->arg[strlen(opt->arg)-8]);
-			else if (gmt_M_file_is_remotedata (opt->arg) && (c = strstr (opt->arg, ".grd"))) {
-				c[0] = '\0';
+			if (gmt_file_is_tiled_list (API, opt->arg, &k_data, NULL, NULL)) {	/* Want to replace the tiled list with the original @remotefile name instead */
+				snprintf (buffer, GMT_BUFSIZ, "@%s", API->remote_info[k_data].file);
+			}
+			else if ((k_data = gmt_remote_dataset_id (API, opt->arg)) != GMT_NOTSET && API->remote_info[k_data].ext[0] && (c = strstr (opt->arg, API->remote_info[k_data].ext))) {
+				c[0] = '\0';	/* Remove extension on remote file */
 				snprintf (buffer, GMT_BUFSIZ, "%s", opt->arg);
 				c[0] = '.';
 			}
@@ -851,7 +882,7 @@ int GMT_Destroy_Cmd (void *V_API, char **cmd) {
 	struct GMTAPI_CTRL *API = NULL;
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 	if (*cmd == NULL) return_error (V_API, GMT_ARG_IS_NULL);	/* No command was given */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 	gmt_M_free (API->GMT, *cmd);	/* Free the command string */
 	return (GMT_OK);		/* No error encountered */
 }
@@ -862,7 +893,7 @@ struct GMT_OPTION *GMT_Make_Option (void *V_API, char option, const char *arg) {
 	struct GMTAPI_CTRL *API = NULL;
 
 	if (V_API == NULL) return_null (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 
 	/* Here we have a program-specific option or a file name.  In either case we create a new option structure */
 
@@ -881,12 +912,12 @@ struct GMT_OPTION *GMT_Make_Option (void *V_API, char option, const char *arg) {
 }
 
 /*! Search the list for the selected option and return the pointer to the item.  Only the first occurrence will be found. */
-struct GMT_OPTION * GMT_Find_Option (void *V_API, char option, struct GMT_OPTION *head) {
+struct GMT_OPTION *GMT_Find_Option (void *V_API, char option, struct GMT_OPTION *head) {
 
 	struct GMT_OPTION *current = NULL;
 
 	if (V_API == NULL) return_null (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
-	
+
 	for (current = head; current && current->option != option; current = current->next);	/* Linearly search for the specified option */
 	return (current);	/* NULL if not found */
 }
@@ -907,14 +938,14 @@ int GMT_Update_Option (void *V_API, struct GMT_OPTION *opt, const char *arg) {
 int GMT_Expand_Option (void *V_API, struct GMT_OPTION *opt, const char *arg) {
 	char buffer[BUFSIZ] = {""};
 	size_t in = 0, out = 0;
-	size_t s_length; 
+	size_t s_length;
 	bool quote = false;	/* We are outside any quoted text */
 
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);	 /* GMT_Create_Session has not been called */
 	if (opt == NULL) return_error (V_API, GMT_OPTION_IS_NULL);	 /* We passed NULL as the option */
 	if (arg == NULL) return_error (V_API, GMT_ARG_IS_NULL);		 /* We passed NULL as the argument */
 	if (opt->arg == NULL) return_error (V_API, GMT_ARG_IS_NULL); /* We passed NULL as the option argument */
-	s_length = strlen (arg); 
+	s_length = strlen (arg);
 	if ((s_length + strlen (opt->arg)) > BUFSIZ) return_error (V_API, GMT_DIM_TOO_LARGE);		/* Don't have room */
 
 	while (opt->arg[in]) {
@@ -969,7 +1000,7 @@ int GMT_Delete_Option (void *V_API, struct GMT_OPTION *current, struct GMT_OPTIO
 
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 	if (!current) return_error (V_API, GMT_OPTION_IS_NULL);		/* No option was passed */
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
 
 	/* Remove the current option and bypass via the next/prev pointers in the linked list */
 	if (current->next) current->next->previous = current->previous;
@@ -996,20 +1027,22 @@ int GMT_Parse_Common (void *V_API, const char *given_options, struct GMT_OPTION
 	char list[2] = {0, 0}, critical_opt_order[] = GMT_CRITICAL_OPT_ORDER;
 	unsigned int i, n_errors;
 	struct GMTAPI_CTRL *API = NULL;
-	const unsigned int s_length = (unsigned int)strlen(critical_opt_order); 
+	const unsigned int s_length = (unsigned int)strlen(critical_opt_order);
 
 	if (V_API == NULL) return_error (V_API, GMT_NOT_A_SESSION);	/* GMT_Create_Session has not been called */
 
 	/* Check if there are short-hand commands present (e.g., -J with no arguments); if so complete these to full options
 	 * by consulting the current GMT history machinery.  If not possible then we have an error to report */
 
-	API = parse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
-	if (parse_complete_options (API->GMT, options)) return_error (API, GMT_OPTION_HISTORY_ERROR);	/* Replace shorthand failed */
+	API = gmtparse_get_api_ptr (V_API);	/* Cast void pointer to a GMTAPI_CTRL pointer */
+	if (gmtparse_complete_options (API->GMT, options)) return_error (API, GMT_OPTION_HISTORY_ERROR);	/* Replace shorthand failed */
 
-	if (API->GMT->common.B.mode == 0) API->GMT->common.B.mode = parse_check_b_options (API->GMT, options);	/* Determine the syntax of the -B option(s) */
+	if (API->GMT->common.B.mode == 0) API->GMT->common.B.mode = gmtparse_check_b_options (API->GMT, options);	/* Determine the syntax of the -B option(s) */
+
+	gmtparse_ensure_b_options_order (API->GMT, options);	/* Avoid parsing axes labels etc before axis increments since we may auto-set increments in the former */
+
+	n_errors = gmtparse_check_extended_R (API->GMT, options);	/* Possibly parse -I if required by -R */
 
-	n_errors = parse_check_extended_R (API->GMT, options);	/* Possibly parse -I if required by -R */
-	
 	/* First parse the common options in the order they appear in GMT_CRITICAL_OPT_ORDER */
 	for (i = 0; i < s_length; i++) {	/* These are the GMT options that must be parsed in this particular order, if present */
 		if (strchr (given_options, critical_opt_order[i]) == NULL) continue;	/* Not a selected option */
@@ -1034,6 +1067,6 @@ int GMT_Parse_Common (void *V_API, const char *given_options, struct GMT_OPTION
 	API->GMT->current.options = options;
 	if (n_errors) return_error (API, GMT_PARSE_ERROR);	/* One or more options failed to parse */
 	if (gmt_M_is_geographic (API->GMT, GMT_IN)) API->GMT->current.io.warn_geo_as_cartesion = false;	/* Don't need this warning */
-	
+
 	return (GMT_OK);
 }
