@@ -73,6 +73,11 @@ struct sigaction cleanup_action, default_action;
 char *file_to_delete_if_ctrl_C;
 #endif
 
+struct LOCFILE_FP {
+	char *file;	/* Pointer to file name */
+	FILE *fp;	/* Open file pointer */
+};
+
 GMT_LOCAL void gmtremote_delete_file_then_exit (int sig_no) {
 	/* If we catch a CTRL-C during CURL download we must assume file is corrupted and remove it before exiting */
 	gmt_M_unused (sig_no);
@@ -156,54 +161,82 @@ GMT_LOCAL int gmtremote_parse_version (char *line) {
 	return GMT_NOERROR;
 }
 
-GMT_LOCAL struct GMT_DATA_INFO *gmtremote_data_load (struct GMT_CTRL *GMT, int *n) {
+GMT_LOCAL int gmtremote_remove_item (struct GMTAPI_CTRL *API, char *path, bool directory) {
+	int error = GMT_NOERROR;
+	if (directory) {	/* Delete populated directories via an operating system remove call */
+		char del_cmd[PATH_MAX] = {""};
+#ifdef _WIN32
+		char *t = gmt_strrep (path, "/", "\\");	/* DOS rmdir needs paths with back-slashes */
+		strcpy (del_cmd, "rmdir /s /q ");
+		strcat (del_cmd, t);
+		gmt_M_str_free (t);
+#else
+		sprintf (del_cmd, "rm -rf %s", path);
+#endif
+		if ((error = system (del_cmd))) {
+			GMT_Report (API, GMT_MSG_ERROR, "Failed to remove %s [error = %d]\n", path, error);
+			error = GMT_RUNTIME_ERROR;
+		}
+	}
+	else	/* Just delete a single file  */
+		gmt_remove_file (API->GMT, path);
+	return error;
+}
+
+GMT_LOCAL struct GMT_DATA_INFO *gmtremote_data_load (struct GMTAPI_CTRL *API, int *n) {
 	/* Read contents of the info file into an array of structs */
 	int k = 0, nr;
 	FILE *fp = NULL;
 	struct GMT_DATA_INFO *I = NULL;
 	char unit, line[GMT_LEN512] = {""}, file[PATH_MAX] = {""}, *c = NULL;
+	struct GMT_CTRL *GMT = API->GMT;
 
 	snprintf (file, PATH_MAX, "%s/server/%s", GMT->session.USERDIR, GMT_INFO_SERVER_FILE);
 
-	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Load contents from %s\n", file);
+	GMT_Report (API, GMT_MSG_DEBUG, "Load contents from %s\n", file);
 	*n = 0;
 	if ((fp = fopen (file, "r")) == NULL) {
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to open file %s\n", file);
+		GMT_Report (API, GMT_MSG_ERROR, "Unable to open file %s\n", file);
 		return NULL;
 	}
 	if (fgets (line, GMT_LEN256, fp) == NULL) {	/* Try to get first record */
 		fclose (fp);
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Read error first record in file %s\n", file);
+		GMT_Report (API, GMT_MSG_ERROR, "Read error first record in file %s\n", file);
+		GMT_Report (API, GMT_MSG_ERROR, "Deleting %s so it can get regenerated - please try again\n", file);
+		gmt_remove_file (GMT, file);
 		return NULL;
 	}
 	*n = atoi (line);		/* Number of non-commented records to follow */
 	if (*n <= 0 || *n > GMT_BIG_CHUNK) {	/* Probably not a good value */
 		fclose (fp);
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Bad record counter in file %s\n", file);
+		GMT_Report (API, GMT_MSG_ERROR, "Bad record counter in file %s\n", file);
+		GMT_Report (API, GMT_MSG_ERROR, "Deleting %s so it can get regenerated - please try again\n", file);
+		gmt_remove_file (GMT, file);
 		return NULL;
 	}
 	if (fgets (line, GMT_LEN256, fp) == NULL) {	/* Try to get second record */
 		fclose (fp);
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Read error second record in file %s\n", file);
+		GMT_Report (API, GMT_MSG_ERROR, "Read error second record in file %s\n", file);
 		return NULL;
 	}
 	if ((k = gmtremote_parse_version (line))) {
 		fclose (fp);
 		if (k == 2)
-			GMT_Report (GMT->parent, GMT_MSG_NOTICE, "Your GMT version too old to use the remote data mechanism - please upgrade to %s or later\n", line);
+			GMT_Report (API, GMT_MSG_NOTICE, "Your GMT version too old to use the remote data mechanism - please upgrade to %s or later\n", line);
 		else
-			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to parse \"%s\" to extract GMT version\n", line);
+			GMT_Report (API, GMT_MSG_ERROR, "Unable to parse \"%s\" to extract GMT version\n", line);
 		return NULL;
-	}	
+	}
 	if ((I = gmt_M_memory (GMT, NULL, *n, struct GMT_DATA_INFO)) == NULL) {
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to allocated %d GMT_DATA_INFO structures!\n", *n);
+		fclose (fp);
+		GMT_Report (API, GMT_MSG_ERROR, "Unable to allocated %d GMT_DATA_INFO structures!\n", *n);
 		return NULL;
 	}
 
 	while (fgets (line, GMT_LEN512, fp) != NULL) {
 		if (line[0] == '#') continue;	/* Skip any comments */
 		if ((nr = sscanf (line, "%s %s %s %c %lg %lg %s %lg %s %s %s %s %[^\n]", I[k].dir, I[k].file, I[k].inc, &I[k].reg, &I[k].scale, &I[k].offset, I[k].size, &I[k].tile_size, I[k].date, I[k].coverage, I[k].filler, I[k].CPT, I[k].remark)) != 13) {
-			GMT_Report (GMT->parent, GMT_MSG_WARNING, "File %s should have 13 fields but only %d read for record %d - download error???\n", file, nr, k);
+			GMT_Report (API, GMT_MSG_WARNING, "File %s should have 13 fields but only %d read for record %d - download error???\n", file, nr, k);
 			gmt_M_free (GMT, I);
 			fclose (fp);
 			return NULL;
@@ -223,13 +256,61 @@ GMT_LOCAL struct GMT_DATA_INFO *gmtremote_data_load (struct GMT_CTRL *GMT, int *
 	fclose (fp);
 
 	if (k != *n) {
-		GMT_Report (GMT->parent, GMT_MSG_WARNING, "File %s said it has %d records but only found %d - download error???\n", file, *n, k);
-		GMT_Report (GMT->parent, GMT_MSG_WARNING, "File %s should be deleted.  Please try again\n", file);
+		GMT_Report (API, GMT_MSG_WARNING, "File %s said it has %d records but only found %d - download error???\n", file, *n, k);
+		GMT_Report (API, GMT_MSG_WARNING, "File %s should be deleted.  Please try again\n", file);
 		*n = 0;	/* Flag that excrement hit the fan */
 	}
 	/* Soft alphabetically on file names */
 	qsort (I, *n, sizeof (struct GMT_DATA_INFO), gmtremote_compare_names);
 	for (k = 0; k < *n; k++) I[k].id = k;	/* Give running number as ID in the sorted array */
+
+	if (GMT->current.io.new_data_list) {	/* Take this opportunity to delete datasets that are past their expiration date */
+		time_t mod_time;
+		struct tm *UTC = NULL;
+		struct stat buf;
+		int year, month, day, kyear, kmonth, kday;
+		size_t L;
+
+		GMT->current.io.new_data_list = false;	/* We only do this once after a gmt_data_server.txt update */
+		if (GMT->session.USERDIR == NULL) goto out_of_here;	/* Cannot have server data if no user directory is set */
+		if (access (GMT->session.USERDIR, R_OK)) goto out_of_here;	/* Set, but have not made a user directory yet, so cannot have any remote data yet either */
+
+		for (k = 0; k < *n; k++) {	/* Check the release date of each data set that has been downloaded against the local file date */
+			if (sscanf (I[k].date, "%d-%d-%d", &kyear, &kmonth, &kday) != 3) continue;	/* Maybe malformed datestring or on purpose to never check */
+			snprintf (file, PATH_MAX, "%s/%s%s", GMT->session.USERDIR, I[k].dir, I[k].file);	/* Local path, may end in slash if a tile directory*/
+			if ((L = strlen (file) - 1) && file[L] == '/') file[L] = '\0';	/* Chop off trailing / that indicates directory of tiles */
+			if (access (file, R_OK)) continue;	/* No such file or directory yet */
+			/* Here we have a local copy of this remote file or directory - we examine its creation date */
+			if (stat (file, &buf)) {
+				GMT_Report (API, GMT_MSG_WARNING, "Unable to get information about %s - skip\n", file);
+				continue;
+			}
+			/*  Get its modification (creation) time */
+#ifdef __APPLE__
+			mod_time = buf.st_mtimespec.tv_sec;	/* Apple even has tv_nsec for nano-seconds... */
+#else
+			mod_time = buf.st_mtime;
+#endif
+			/* Extract the year, month, day integers */
+			UTC   = gmtime (&mod_time);
+			year  = UTC->tm_year + 1900;	/* Yep, how stupid is that, Y2K lovers. I guess 2030 might overflow a 32-bit int... */
+			month = UTC->tm_mon + 1;		/* Make it 1-12 since it is 0-11 */
+			day   = UTC->tm_mday;			/* Yep, lets start at 1 for days and 0 for months, makes sense */
+			if (kyear < year) continue;	/* The origin year is older than our file so no need to check further */
+			if (kyear == year) {	/* Our file and the server file is both from the same year */
+				if (kmonth < month) continue;	/* The origin month is older than our copy so no need to check further */
+				if (kmonth == month) {	/* Same year, same month, we are so close! */
+					if (kday < day) continue; 	/* The origin day is older than our copy so no need to check further */
+				}
+			}
+			/* If we get here we need to remove the outdated file or directory so we may download the latest on next try */
+			if (gmtremote_remove_item (API, file, I[k].tile_size > 0.0)) {
+				GMT_Report (GMT->parent, GMT_MSG_WARNING, "Unable to remove %s \n", file);
+			}
+		}
+	}
+
+out_of_here:
 	return (I);
 };
 
@@ -249,7 +330,13 @@ int gmtremote_wind_to_file (const char *file) {
 }
 
 int gmt_remote_dataset_id (struct GMTAPI_CTRL *API, const char *file) {
-	/* Return the entry in the remote file table of file is found, else -1 */
+	/* Return the entry in the remote file table of file is found, else -1.
+	 * Complications to consider before finding a match:
+	 * Input file may or may not have leading @
+	 * Input file may or may not have _g or _p for registration
+	 * Input file may or many not have an extension
+	 * Key file may be a tiled data set and thus ends with '/'
+	 */
 	int pos = 0;
 	struct GMT_DATA_INFO *key = NULL;
 	if (file == NULL || file[0] == '\0') return GMT_NOTSET;	/* No file name given */
@@ -257,6 +344,16 @@ int gmt_remote_dataset_id (struct GMTAPI_CTRL *API, const char *file) {
 	/* Exclude leading directory for local saved versions of the file */
 	if (pos == 0) pos = gmtremote_wind_to_file (file);	/* Skip any leading directories */
 	key = bsearch (&file[pos], API->remote_info, API->n_remote_info, sizeof (struct GMT_DATA_INFO), gmtremote_compare_key);
+	if (key) {	/* Make sure we actually got a real hit since file = "earth" will find a key starting with "earth****" */
+		char *ckey = strrchr (key->file, '.');		/* Find location of the start of the key file extension (or NULL if no extension) */
+		char *cfile = strrchr (&file[pos], '.');	/* Find location of the start of the input file extension (or NULL if no extension) */
+		size_t Lfile = (cfile) ? (size_t)(cfile - &file[pos]) : strlen (&file[pos]);	/* Length of key file name without extension */
+		size_t Lkey  = (ckey)  ? (size_t)(ckey  - key->file)  : strlen (key->file);		/* Length of key file name without extension */
+		if (ckey == NULL && Lkey > 1 && key->file[Lkey-1] == '/') Lkey--;	/* Skip trailing dir flag */
+		if (Lkey > Lfile && Lkey > 2 && key->file[Lkey-2] == '_' && strchr ("gp", key->file[Lkey-1])) Lkey -= 2;	/* Remove the length of _g or _p from Lkey */
+		if (Lfile != Lkey)	/* Not an exact match (apart from trailing _p|g) */
+			key = NULL;
+	}
 	return ((key == NULL) ? GMT_NOTSET : key->id);
 }
 
@@ -293,7 +390,10 @@ void gmt_set_unspecified_remote_registration (struct GMTAPI_CTRL *API, char **fi
 			/* Found, replace given file name with this */
 			if (c) {	/* Restore the modifiers */
 				c[0] = '+';
-				strcat (newfile, c);
+				if (strstr (c, "+s") || strstr (c, "+o"))
+					GMT_Report (API, GMT_MSG_WARNING, "Cannot append +s<scl> and/or +o<offset> to the remote global grid %s - ignored\n", newfile);
+				else
+					strcat (newfile, c);
 			}
 			gmt_M_str_free (*file_ptr);
 			*file_ptr = strdup (newfile);
@@ -366,7 +466,20 @@ GMT_LOCAL int gmtremote_find_and_give_data_attribution (struct GMTAPI_CTRL *API,
 	return (match);
 }
 
-GMT_LOCAL size_t gmtremote_skip_large_files (struct GMT_CTRL *GMT, char* URL, size_t limit) {
+GMT_LOCAL char *gmtremote_lockfile (struct GMT_CTRL *GMT, char *file) {
+	/* Create a dummy file in temp with extension .download and use as a lock file */
+	char *c = strrchr (file, '/');
+	char Lfile[PATH_MAX] = {""};
+	if (c)	/* Found the last slash, skip it */
+		c++;
+	else	/* No path, just point to file */
+		c = file;
+	if (c[0] == '@') c++;	/* Skip any leading @ sign */
+	sprintf (Lfile, "%s/%s.download", GMT->parent->tmp_dir, c);
+	return (strdup (Lfile));
+}
+
+GMT_LOCAL size_t gmtremote_skip_large_files (struct GMT_CTRL *GMT, char * URL, size_t limit) {
 	/* Get the remote file's size and if too large we refuse to download */
 	CURL *curl = NULL;
 	CURLcode res;
@@ -411,54 +524,103 @@ GMT_LOCAL size_t gmtremote_skip_large_files (struct GMT_CTRL *GMT, char* URL, si
 	return action;
 }
 
+CURL * gmtremote_setup_curl (struct GMTAPI_CTRL *API, char *url, char *local_file, struct FtpFile *urlfile, unsigned int time_out) {
+	/* Single function that sets up an impending CURL operation */
+	CURL *Curl = NULL;
+	if ((Curl = curl_easy_init ()) == NULL) {
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to initiate curl - cannot obtain %s\n", url);
+		return NULL;
+	}
+	if (curl_easy_setopt (Curl, CURLOPT_SSL_VERIFYPEER, 0L)) {		/* Tell libcurl to not verify the peer */
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to not verify the peer\n");
+		return NULL;
+	}
+	if (curl_easy_setopt (Curl, CURLOPT_FOLLOWLOCATION, 1L)) {		/* Tell libcurl to follow 30x redirects */
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to follow redirects\n");
+		return NULL;
+	}
+	if (curl_easy_setopt (Curl, CURLOPT_FAILONERROR, 1L)) {		/* Tell libcurl to fail on 4xx responses (e.g. 404) */
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to fail for 4xx responses\n");
+		return NULL;
+	}
+ 	if (curl_easy_setopt (Curl, CURLOPT_URL, url)) {	/* Set the URL to copy */
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to read from %s\n", url);
+		return NULL;
+	}
+	if (time_out) {	/* Set a timeout limit */
+		if (curl_easy_setopt (Curl, CURLOPT_TIMEOUT, time_out)) {
+			GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to time out after %d seconds\n", time_out);
+			return NULL;
+		}
+	}
+	urlfile->filename = local_file;	/* Set pointer to local filename */
+	/* Define our callback to get called when there's data to be written */
+	if (curl_easy_setopt (Curl, CURLOPT_WRITEFUNCTION, gmtremote_fwrite_callback)) {
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl output callback function\n");
+		return NULL;
+	}
+	/* Set a pointer to our struct that will be passed to the callback function */
+	if (curl_easy_setopt (Curl, CURLOPT_WRITEDATA, urlfile)) {
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to write to %s\n", local_file);
+		return NULL;
+	}
+
+	return Curl;	/* Happily return the Curl pointer */
+}
+
+struct LOCFILE_FP *gmtremote_lock_on (struct GMT_CTRL *GMT, char *file) {
+	/* Creates filename for lock and activates the lock */
+	struct LOCFILE_FP *P = gmt_M_memory (GMT, NULL, 1, struct LOCFILE_FP);
+	P->file = gmtremote_lockfile (GMT, file);
+	if ((P->fp = fopen (P->file, "w")) == NULL) {
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to create lock file %s\n", P->file);
+		gmt_M_str_free (P->file);
+		gmt_M_free (GMT, P);
+		return NULL;
+	}
+	gmtlib_file_lock (GMT, fileno(P->fp));	/* Attempt exclusive lock */
+	return P;
+}
+
+void gmtremote_lock_off (struct GMT_CTRL *GMT, struct LOCFILE_FP **P) {
+	/* Deactivates the lock on the file */
+	gmtlib_file_unlock (GMT, fileno((*P)->fp));
+	fclose ((*P)->fp);
+	gmt_remove_file (GMT, (*P)->file);
+	gmt_M_str_free ((*P)->file);
+	gmt_M_free (GMT, *P);
+}
+
 /* Deal with hash values of cache/data files */
 
 #define GMT_HASH_TIME_OUT 10L	/* Not waiting longer than this to time out on getting the hash file */
 
 GMT_LOCAL int gmtremote_get_url (struct GMT_CTRL *GMT, char *url, char *file, char *orig, unsigned int index) {
-	int curl_err = 0;
+	bool turn_ctrl_C_off = false;
+	int curl_err = 0, error = 0;
 	long time_spent;
 	CURL *Curl = NULL;
+	struct LOCFILE_FP *LF = NULL;
 	struct FtpFile urlfile = {NULL, NULL};
+	struct GMTAPI_CTRL *API = GMT->parent;
 	time_t begin, end;
 
-	if ((Curl = curl_easy_init ()) == NULL) {
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to initiate curl - cannot obtain %s\n", url);
+	if (GMT->current.setting.auto_download == GMT_NO_DOWNLOAD) {  /* Not allowed to use remote copying */
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Remote download is currently deactivated\n");
 		return 1;
 	}
-	if (curl_easy_setopt (Curl, CURLOPT_SSL_VERIFYPEER, 0L)) {		/* Tell libcurl to not verify the peer */
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl option to not verify the peer\n");
+	if (GMT->current.io.internet_error) return 1;   			/* Not able to use remote copying in this session */
+
+	/* Make a lock */
+	if ((LF = gmtremote_lock_on (GMT, file)) == NULL)
 		return 1;
-	}
-	if (curl_easy_setopt (Curl, CURLOPT_FOLLOWLOCATION, 1L)) {		/* Tell libcurl to follow 30x redirects */
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl option to follow redirects\n");
-		return 1;
-	}
-	if (curl_easy_setopt (Curl, CURLOPT_FAILONERROR, 1L)) {		/* Tell libcurl to fail on 4xx responses (e.g. 404) */
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl option to fail for 4xx responses\n");
-		return 1;
-	}
- 	if (curl_easy_setopt (Curl, CURLOPT_URL, url)) {	/* Set the URL to copy */
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl option to read from %s\n", url);
-		return 1;
-	}
- 	if (curl_easy_setopt (Curl, CURLOPT_TIMEOUT, GMT_HASH_TIME_OUT)) {	/* Set a max timeout */
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl option to time out after %ld seconds\n", GMT_HASH_TIME_OUT);
-		return 1;
-	}
-	urlfile.filename = file;	/* Set pointer to local filename */
-	/* Define our callback to get called when there's data to be written */
-	if (curl_easy_setopt (Curl, CURLOPT_WRITEFUNCTION, gmtremote_fwrite_callback)) {
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl output callback function\n");
-		return 1;
-	}
-	/* Set a pointer to our struct to pass to the callback */
-	if (curl_easy_setopt (Curl, CURLOPT_WRITEDATA, &urlfile)) {
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to set curl option to write to %s\n", file);
-		return 1;
-	}
+
+	/* Initialize the curl session */
+	if ((Curl = gmtremote_setup_curl (API, url, file, &urlfile, GMT_HASH_TIME_OUT)) == NULL)
+		goto unlocking1;
+
 	GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Downloading file %s ...\n", url);
-	gmtremote_turn_on_ctrl_C_check (file);
+	gmtremote_turn_on_ctrl_C_check (file);	turn_ctrl_C_off = true;
 	begin = time (NULL);
 	if ((curl_err = curl_easy_perform (Curl))) {	/* Failed, give error message */
 		end = time (NULL);
@@ -481,13 +643,20 @@ GMT_LOCAL int gmtremote_get_url (struct GMT_CTRL *GMT, char *url, char *file, ch
 				GMT->current.io.refreshed[index] = GMT->current.io.internet_error = true;
 			}
 		}
-		return 1;
+		error = 1; goto unlocking1;
 	}
 	curl_easy_cleanup (Curl);
 	if (urlfile.fp) /* close the local file */
 		fclose (urlfile.fp);
-	gmtremote_turn_off_ctrl_C_check ();
-	return 0;
+
+unlocking1:
+
+	/* Remove lock file after successful download */
+	gmtremote_lock_off (GMT, &LF);
+
+	if (turn_ctrl_C_off) gmtremote_turn_off_ctrl_C_check ();
+
+	return error;
 }
 
 GMT_LOCAL struct GMT_DATA_HASH *gmtremote_hash_load (struct GMT_CTRL *GMT, char *file, int *n) {
@@ -523,13 +692,14 @@ GMT_LOCAL struct GMT_DATA_HASH *gmtremote_hash_load (struct GMT_CTRL *GMT, char
 	return (L);
 };
 
-GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
+GMT_LOCAL int gmtremote_refresh (struct GMTAPI_CTRL *API, unsigned int index) {
 	/* This function is called every time we are about to access a @remotefile.
 	 * It is called twice: Once for the hash table and once for the info table.
 	 * First we check that we have the GMT_HASH_SERVER_FILE in the server directory.
 	 * If we don't then we download it and return since no old file to compare to.
 	 * If we do find the hash file then we get its creation time [st_mtime] as
-	 * well as the current system time.  If the file is < 1 day old we are done.
+	 * well as the current system time.  If the file is < GMT->current.setting.refresh_time
+	 * days old we are done.
 	 * If the file is older we rename it to *.old and download the latest hash file.
 	 * This is the same for both values of index (hash and info).  For hash, we do more:
 	 * Next, we load the contents of both files and do a double loop to find the
@@ -544,6 +714,7 @@ GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
 	time_t mod_time, right_now = time (NULL);	/* Unix time right now */
 	char indexpath[PATH_MAX] = {""}, old_indexpath[PATH_MAX] = {""}, new_indexpath[PATH_MAX] = {""}, url[PATH_MAX] = {""};
 	const char *index_file = (index == GMT_HASH_INDEX) ? GMT_HASH_SERVER_FILE : GMT_INFO_SERVER_FILE;
+	struct GMT_CTRL *GMT = API->GMT;	/* Short hand */
 
 	if (GMT->current.io.refreshed[index]) return GMT_NOERROR;	/* Already been here */
 
@@ -553,13 +724,13 @@ GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
 		char serverdir[PATH_MAX] = {""};
 		snprintf (serverdir, PATH_MAX, "%s/server", GMT->session.USERDIR);
 		if (access (serverdir, R_OK) && gmt_mkdir (serverdir)) {
-			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to create GMT server directory : %s\n", serverdir);
+			GMT_Report (API, GMT_MSG_ERROR, "Unable to create GMT server directory : %s\n", serverdir);
 			return 1;
 		}
 		snprintf (url, PATH_MAX, "%s/%s", GMT->session.DATASERVER, index_file);
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Download remote file %s for the first time\n", url);
+		GMT_Report (API, GMT_MSG_DEBUG, "Download remote file %s for the first time\n", url);
 		if (gmtremote_get_url (GMT, url, indexpath, NULL, index)) {
-			GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Failed to get remote file %s\n", url);
+			GMT_Report (API, GMT_MSG_INFORMATION, "Failed to get remote file %s\n", url);
 			if (!access (indexpath, F_OK)) gmt_remove_file (GMT, indexpath);	/* Remove index file just in case it got corrupted or zero size */
 			GMT->current.setting.auto_download = GMT_NO_DOWNLOAD;	/* Temporarily turn off auto download in this session only */
 			GMT->current.io.internet_error = true;		/* No point trying again */
@@ -569,14 +740,14 @@ GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
 		return GMT_NOERROR;
 	}
 	else
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Local file %s found\n", indexpath);
+		GMT_Report (API, GMT_MSG_DEBUG, "Local file %s found\n", indexpath);
 
 	GMT->current.io.refreshed[index] = true;	/* Done our job */
 
 	/* Here we have the existing index file and its path is in indexpath. Check how old it is */
 
 	if (stat (indexpath, &buf)) {
-		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to get information about %s - abort\n", indexpath);
+		GMT_Report (API, GMT_MSG_ERROR, "Unable to get information about %s - abort\n", indexpath);
 		return 1;
 	}
 	/*  Get its modification (creation) time */
@@ -586,28 +757,28 @@ GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
 	mod_time = buf.st_mtime;
 #endif
 
-	if ((right_now - mod_time) > GMT_DAY2SEC_I) {	/* Older than 1 day; Time to get a new index file */
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "File %s older than 24 hours, get latest from server.\n", indexpath);
+	if ((right_now - mod_time) > (GMT_DAY2SEC_I * GMT->current.setting.refresh_time)) {	/* Older than selected number of days; Time to get a new index file */
+		GMT_Report (API, GMT_MSG_DEBUG, "File %s older than 24 hours, get latest from server.\n", indexpath);
 		strcpy (new_indexpath, indexpath);	/* Duplicate path name */
 		strcat (new_indexpath, ".new");		/* Append .new to the copied path */
 		strcpy (old_indexpath, indexpath);	/* Duplicate path name */
 		strcat (old_indexpath, ".old");		/* Append .old to the copied path */
 		snprintf (url, PATH_MAX, "%s/%s", GMT->session.DATASERVER, index_file);	/* Set remote path to new index file */
 		if (gmtremote_get_url (GMT, url, new_indexpath, indexpath, index)) {	/* Get the new index file from server */
-			GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Failed to download %s - Internet troubles?\n", url);
+			GMT_Report (API, GMT_MSG_DEBUG, "Failed to download %s - Internet troubles?\n", url);
 			if (!access (new_indexpath, F_OK)) gmt_remove_file (GMT, new_indexpath);	/* Remove index file just in case it got corrupted or zero size */
 			return 1;	/* Unable to update the file (no Internet?) - skip the tests */
 		}
 		if (!access (old_indexpath, F_OK))
 			remove (old_indexpath);	/* Remove old index file if it exists */
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Rename %s to %s\n", indexpath, old_indexpath);
+		GMT_Report (API, GMT_MSG_DEBUG, "Rename %s to %s\n", indexpath, old_indexpath);
 		if (gmt_rename_file (GMT, indexpath, old_indexpath, GMT_RENAME_FILE)) {	/* Rename existing file to .old */
-			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to rename %s to %s.\n", indexpath, old_indexpath);
+			GMT_Report (API, GMT_MSG_ERROR, "Failed to rename %s to %s.\n", indexpath, old_indexpath);
 			return 1;
 		}
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Rename %s to %s\n", new_indexpath, indexpath);
+		GMT_Report (API, GMT_MSG_DEBUG, "Rename %s to %s\n", new_indexpath, indexpath);
 		if (gmt_rename_file (GMT, new_indexpath, indexpath, GMT_RENAME_FILE)) {	/* Rename newly copied file to existing file */
-			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Failed to rename %s to %s.\n", new_indexpath, indexpath);
+			GMT_Report (API, GMT_MSG_ERROR, "Failed to rename %s to %s.\n", new_indexpath, indexpath);
 			return 1;
 		}
 
@@ -630,26 +801,26 @@ GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
 					if (!strcmp (N[n].name, O[o].name)) {	/* File is in the current hash table */
 						found = true;	/* We will exit this loop regardless of what happens next below */
 						if (strcmp (N[n].hash, O[o].hash)) {	/* New hash differs from entry in hash old file */
-							GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Server and cache versions of %s have different hash codes - must download new copy.\n", N[n].name);
+							GMT_Report (API, GMT_MSG_DEBUG, "Server and cache versions of %s have different hash codes - must download new copy.\n", N[n].name);
 							gmt_remove_file (GMT, url);	/* Need to re-download so be gone with it */
 						}
 						else {	/* Do size check */
 							struct stat buf;
 							if (stat (url, &buf)) {
-								GMT_Report (GMT->parent, GMT_MSG_WARNING, "Could not determine size of file %s.\n", url);
+								GMT_Report (API, GMT_MSG_WARNING, "Could not determine size of file %s.\n", url);
 								continue;
 							}
 							if (N[n].size != (size_t)buf.st_size) {	/* Downloaded file size differ - need to re-download */
-								GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Server and cache versions of %s have different byte sizes (%" PRIuS " versus %" PRIuS ") - must download new copy.\n", N[n].name, N[n].size, (size_t)buf.st_size);
+								GMT_Report (API, GMT_MSG_DEBUG, "Server and cache versions of %s have different byte sizes (%" PRIuS " versus %" PRIuS ") - must download new copy.\n", N[n].name, N[n].size, (size_t)buf.st_size);
 								gmt_remove_file (GMT, url);	/* Need to re-download so be gone with it */
 							}
 							else
-								GMT_Report (GMT->parent, GMT_MSG_DEBUG, "Server and cache versions of %s are identical - no need to download new file.\n", N[n].name);
+								GMT_Report (API, GMT_MSG_DEBUG, "Server and cache versions of %s are identical - no need to download new file.\n", N[n].name);
 						}
 					}
 				}
 				if (!found) {	/* This file was present locally but is no longer part of files on the server and should be removed */
-					GMT_Report (GMT->parent, GMT_MSG_DEBUG, "File %s no longer supported on server - deleting local copy.\n", O[o].name);
+					GMT_Report (API, GMT_MSG_DEBUG, "File %s no longer supported on server - deleting local copy.\n", O[o].name);
 					gmt_remove_file (GMT, url);
 				}
 			}
@@ -659,13 +830,15 @@ GMT_LOCAL int gmtremote_refresh (struct GMT_CTRL *GMT, unsigned int index) {
 			if (!access (old_indexpath, F_OK))
 				remove (old_indexpath);	/* Remove old index file if it exists */
 		}
+		else
+			GMT->current.io.new_data_list = true;	/* Flag that we wish to delete datasets older than entries in this file */
 	}
 	else
-		GMT_Report (GMT->parent, GMT_MSG_DEBUG, "File %s less than 24 hours old, refresh is premature.\n", indexpath);
+		GMT_Report (API, GMT_MSG_DEBUG, "File %s less than 24 hours old, refresh is premature.\n", indexpath);
 	return GMT_NOERROR;
 }
 
-void gmtlib_refresh_server (struct GMT_CTRL *GMT) {
+void gmt_refresh_server (struct GMTAPI_CTRL *API) {
 	/* Called once in gmt_begin from GMT_Create_Session,  The following actions take place:
 	 *
 	 * The data info table is refreshed if missing or older than 24 hours.
@@ -676,16 +849,16 @@ void gmtlib_refresh_server (struct GMT_CTRL *GMT) {
 	 *   user requests it, it forces a download of the updated file.
 	 */
 
-	if (gmtremote_refresh (GMT, GMT_INFO_INDEX))	/* Watch out for changes on the server info once a day */
-		GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Unable to obtain remote information file %s\n", GMT_INFO_SERVER_FILE);
-	else {	/* Get server file attribution info */
-		if ((GMT->parent->remote_info = gmtremote_data_load (GMT, &GMT->parent->n_remote_info)) == NULL) {	/* Failed to load the info file */
-			GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Unable to read server information file\n");
+	if (gmtremote_refresh (API, GMT_INFO_INDEX))	/* Watch out for changes on the server info once a day */
+		GMT_Report (API, GMT_MSG_INFORMATION, "Unable to obtain remote information file %s\n", GMT_INFO_SERVER_FILE);
+	else if (API->remote_info == NULL) {	/* Get server file attribution info if not yet loaded */
+		if ((API->remote_info = gmtremote_data_load (API, &API->n_remote_info)) == NULL) {	/* Failed to load the info file */
+			GMT_Report (API, GMT_MSG_INFORMATION, "Unable to read server information file\n");
 		}
 	}
 
-	if (gmtremote_refresh (GMT, GMT_HASH_INDEX)) {	/* Watch out for changes on the server hash once a day */
-		GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Unable to obtain remote hash table %s\n", GMT_HASH_SERVER_FILE);
+	if (gmtremote_refresh (API, GMT_HASH_INDEX)) {	/* Watch out for changes on the server hash once a day */
+		GMT_Report (API, GMT_MSG_INFORMATION, "Unable to obtain remote hash table %s\n", GMT_HASH_SERVER_FILE);
 	}
 }
 
@@ -835,7 +1008,15 @@ int gmt_set_remote_and_local_filenames (struct GMT_CTRL *GMT, const char * file,
 		else {	/* Must be cache file */
 			if (GMT->session.CACHEDIR == NULL) goto not_local;	/* Cannot have cache data if no cache directory created yet */
 			snprintf (local_path, PATH_MAX, "%s/%s", GMT->session.CACHEDIR, &file[1]);	/* This is where all cache files live */
-			if (access (local_path, R_OK)) goto not_local;	/* No such file yet */
+			if ((c = strchr (local_path, '=')) || (c = strchr (local_path, '?'))) {
+				was = c[0];	c[0] = '\0';
+			}
+			GMT->parent->cache = true;
+			if (access (local_path, R_OK)) {
+				if (c) c[0] = was;
+				goto not_local;	/* No such file yet */
+			}
+			if (c) c[0] = was;
 		}
 		GMT_Report (API, GMT_MSG_DEBUG, "Remote file %s exists locally as %s\n", file, local_path);
 		remote_path[0] = '\0';	/* No need to get from elsewhere */
@@ -974,17 +1155,19 @@ int gmtlib_file_is_jpeg2000_tile (struct GMTAPI_CTRL *API, char *file) {
 }
 
 int gmt_download_file (struct GMT_CTRL *GMT, const char *name, char *url, char *localfile, bool be_fussy) {
-	int curl_err, error;
+	bool query = gmt_M_file_is_query (url), turn_ctrl_C_off = false;
+	int curl_err, error = 0;
 	size_t fsize;
 	CURL *Curl = NULL;
 	struct FtpFile urlfile = {NULL, NULL};
+	struct LOCFILE_FP *LF = NULL;
 	struct GMTAPI_CTRL *API = GMT->parent;
 
 	if (GMT->current.setting.auto_download == GMT_NO_DOWNLOAD) {  /* Not allowed to use remote copying */
 		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Remote download is currently deactivated\n");
 		return 1;
 	}
-	if (GMT->current.io.internet_error) return 1;   			/* Not able to use remote copying in this session */
+	if (GMT->current.io.internet_error) return 1;   /* Not able to use remote copying in this session */
 
 	/* Check if the file is too big for our current limit */
 
@@ -997,42 +1180,19 @@ int gmt_download_file (struct GMT_CTRL *GMT, const char *name, char *url, char *
 
 	/* Here we will try to download a file */
 
-  	if ((Curl = curl_easy_init ()) == NULL) {
-		GMT_Report (API, GMT_MSG_ERROR, "Failed to initiate curl\n");
+	/* Only make a lock if not a query */
+	if (!query && (LF = gmtremote_lock_on (GMT, (char *)name)) == NULL)
 		return 1;
-	}
-	if (curl_easy_setopt (Curl, CURLOPT_SSL_VERIFYPEER, 0L)) {		/* Tell libcurl to not verify the peer */
-		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to not verify the peer\n");
-		return 1;
-	}
-	if (curl_easy_setopt (Curl, CURLOPT_FOLLOWLOCATION, 1L)) {		/* Tell libcurl to follow 30x redirects */
-		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to follow redirects\n");
-		return 1;
-	}
-	if (curl_easy_setopt (Curl, CURLOPT_FAILONERROR, 1L)) {		/* Tell libcurl to fail on 4xx responses (e.g. 404) */
-		return 1;
-	}
 
- 	if (curl_easy_setopt (Curl, CURLOPT_URL, url)) {	/* Set the URL to copy */
-		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to read from %s\n", url);
-		return 1;
-	}
-	urlfile.filename = localfile;	/* Set pointer to local filename */
-	/* Define our callback to get called when there's data to be written */
-	if (curl_easy_setopt (Curl, CURLOPT_WRITEFUNCTION, gmtremote_fwrite_callback)) {
-		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl output callback function\n");
-		return 1;
-	}
-	/* Set a pointer to our struct to pass to the callback */
-	if (curl_easy_setopt (Curl, CURLOPT_WRITEDATA, &urlfile)) {
-		GMT_Report (API, GMT_MSG_ERROR, "Failed to set curl option to write to %s\n", localfile);
-		return 1;
-	}
+	/* Initialize the curl session */
+	if ((Curl = gmtremote_setup_curl (API, url, localfile, &urlfile, 0)) == NULL)
+		goto unlocking2;
 
 	gmtremote_find_and_give_data_attribution (API, name);
 
 	GMT_Report (API, GMT_MSG_INFORMATION, "Downloading file %s ...\n", url);
 	gmtremote_turn_on_ctrl_C_check (localfile);
+	turn_ctrl_C_off = true;
 	if ((curl_err = curl_easy_perform (Curl))) {	/* Failed, give error message */
 		if (be_fussy || !(curl_err == CURLE_REMOTE_FILE_NOT_FOUND || curl_err == CURLE_HTTP_RETURNED_ERROR)) {	/* Unexpected failure - want to bitch about it */
 			GMT_Report (API, GMT_MSG_ERROR, "Libcurl Error: %s\n", curl_easy_strerror (curl_err));
@@ -1050,9 +1210,15 @@ int gmt_download_file (struct GMT_CTRL *GMT, const char *name, char *url, char *
 	curl_easy_cleanup (Curl);
 	if (urlfile.fp) /* close the local file */
 		fclose (urlfile.fp);
-	gmtremote_turn_off_ctrl_C_check ();
 
-	error = gmtremote_convert_jp2_to_nc (API, localfile);
+unlocking2:
+
+	if (!query)	/* Remove lock file after successful download (unless query) */
+		gmtremote_lock_off (GMT, &LF);
+
+	if (turn_ctrl_C_off) gmtremote_turn_off_ctrl_C_check ();
+
+	if (error == 0) error = gmtremote_convert_jp2_to_nc (API, localfile);
 
 	return (error);
 }
@@ -1252,7 +1418,7 @@ char ** gmt_get_dataset_tiles (struct GMTAPI_CTRL *API, double wesn_in[], int k_
 			XS = (lon < 0) ? 'W' : 'E';
 			/* Write remote tile name to list */
 			if (n >= n_alloc) {
-				n_alloc <<= 1; 
+				n_alloc <<= 1;
 				if ((list = gmt_M_memory (API->GMT, list, n_alloc, char *)) == NULL) {
 					GMT_Report (API, GMT_MSG_ERROR, "gmt_get_dataset_tiles: Unable to reallocate memory.\n");
 					API->error = GMT_RUNTIME_ERROR;
@@ -1295,7 +1461,7 @@ char *gmtlib_get_tile_list (struct GMTAPI_CTRL *API, double wesn[], int k_data,
 	if (strcmp (Ip->filler, "-") && srtm_flag == 0) {	/* Want background filler, except special case when srtm_relief is the given dataset name (srtm_flag == 1) */
 		if ((k_filler = gmt_remote_dataset_id (API, Ip->filler)) == GMT_NOTSET) {
 			GMT_Report (API, GMT_MSG_ERROR, "gmtlib_get_tile_list: Internal error - Filler grid %s is not a recognized remote data set.\n", Ip->filler);
-			return NULL;			
+			return NULL;
 		}
 		Is = &API->remote_info[k_filler];	/* Pointer to secondary tiled dataset */
 		ocean = (strcmp (Is->inc, "15s") == 0);
@@ -1398,7 +1564,7 @@ struct GMT_GRID *gmtlib_assemble_tiles (struct GMTAPI_CTRL *API, double *region,
 
 	GMT_Open_VirtualFile (API, GMT_IS_GRID, GMT_IS_SURFACE, GMT_OUT|GMT_IS_REFERENCE, NULL, grid);
 	/* Pass -N0 so that missing tiles (oceans) yield z = 0 and not NaN, and -Co+n to override using negative earth_relief_15s values */
-	snprintf (cmd, GMT_LEN256, "%s -R%.16g/%.16g/%.16g/%.16g -I%s -r%c -G%s -Co+n", file, wesn[XLO], wesn[XHI], wesn[YLO], wesn[YHI], API->remote_info[k_data].inc, API->remote_info[k_data].reg, grid);
+	snprintf (cmd, GMT_LEN256, "%s -R%.16g/%.16g/%.16g/%.16g -I%s -r%c -G%s -fg -Co+n", file, wesn[XLO], wesn[XHI], wesn[YLO], wesn[YHI], API->remote_info[k_data].inc, API->remote_info[k_data].reg, grid);
 	if (code != 'X') strcat (cmd, " -N0");	/* If ocean/land, set empty nodes to 0, else NaN */
 	if (GMT_Call_Module (API, "grdblend", GMT_MODULE_CMD, cmd) != GMT_NOERROR) {
 		GMT_Report (API, GMT_MSG_ERROR, "ERROR - Unable to produce blended grid from %s\n", file);
@@ -1408,6 +1574,11 @@ struct GMT_GRID *gmtlib_assemble_tiles (struct GMTAPI_CTRL *API, double *region,
 		GMT_Report (API, GMT_MSG_ERROR, "ERROR - Unable to receive blended grid from grdblend\n");
 		return NULL;
 	}
+	if (gmtlib_delete_virtualfile (API, grid)) {	/* Remove trace since passed upwards anyway */
+		GMT_Report (API, GMT_MSG_ERROR, "ERROR - Unable to destroy temporary object for assembled grid\n");
+		return NULL;
+	}
+
 	HH = gmt_get_H_hidden (G->header);
 	HH->orig_datatype = GMT_SHORT;	/* Since we know this */
 	return (G);
