@@ -1,7 +1,6 @@
 /*--------------------------------------------------------------------
- *	$Id$
  *
- *	Copyright (c) 1991-2019 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -13,7 +12,7 @@
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU Lesser General Public License for more details.
  *
- *	Contact info: gmt.soest.hawaii.edu
+ *	Contact info: www.generic-mapping-tools.org
  *--------------------------------------------------------------------*/
 
 /*
@@ -24,16 +23,16 @@
  *
  * Author: Paul Wessel
  * Date:	1-JAN-2010
- * Version:	5 API
+ * Version:	6 API
  */
 
 /*!
  * \file gmt_symbol.h
- * \brief Miscellaneous definitions and structures related to symbols 
+ * \brief Miscellaneous definitions and structures related to symbols
  */
 
-#ifndef _GMT_SYMBOLS_H
-#define _GMT_SYMBOLS_H
+#ifndef GMT_SYMBOLS_H
+#define GMT_SYMBOLS_H
 
 /* VECTOR attributes are used by psxy, psxyz, psrose, grdvector */
 #define VECTOR_LINE_WIDTH	2.0	/* Default vector attributes in points */
@@ -53,7 +52,7 @@ enum gmt_enum_panel {
 	GMT_PANEL_FILL		= 8,
 	GMT_PANEL_OUTLINE	= 16
 };
-	
+
 /*! Definition of structure used for holding information about a reference point */
 struct GMT_REFPOINT {	/* Used to hold items relevant for a reference point */
 	double x;		/* X position of reference point */
@@ -65,16 +64,31 @@ struct GMT_REFPOINT {	/* Used to hold items relevant for a reference point */
 
 #define CUSTOM_SYMBOL_MAXVAR	3	/* So we can check in the code if we exceed this */
 
+enum gmt_enum_custsymb {
+	GMT_CONST_STRING	= -5,	/* We have a constant string in a conditional test */
+	GMT_VAR_STRING		= -4,	/* We have a variable string (the trailing text) in a conditional test */
+	GMT_VAR_SIZE		= -3,	/* We have the symbol size $s in a conditional test */
+	GMT_VAR_IS_Y		= -2,	/* We have y or latitude in a conditional test */
+	GMT_VAR_IS_X		= -1,	/* We have x or longitude in a conditional test */
+	GMT_CONST_VAR		=  0,	/* We have a constant factor in a conditional test */
+	GMT_BEGIN_SINGLE_IF	=  1,	/* We have a single, 1-liner if condition, with no end if */
+	GMT_BEGIN_BLOCK_IF	=  2,	/* Starting a new if branch */
+	GMT_END_IF		=  4,	/* Ending an if branch */
+	GMT_END_IF_ELSE		=  6,	/* Ending an if-branch and start the else branch */
+	GMT_BEGIN_ELSEIF	=  8	/* Ending the if-branch and start another if branch */
+};
+
 struct GMT_CUSTOM_SYMBOL_ITEM {
-	double x, y, p[CUSTOM_SYMBOL_MAXVAR], const_val[CUSTOM_SYMBOL_MAXVAR];
-	int action, operator, var_pen, var[CUSTOM_SYMBOL_MAXVAR];	/* For conditionals: var[0] refers to variable on left hand side of operator, var[1] and var[2] to the right hand */
-	unsigned int conditional;
+	double x, y, p[CUSTOM_SYMBOL_MAXVAR], const_val[CUSTOM_SYMBOL_MAXVAR], var_sign[CUSTOM_SYMBOL_MAXVAR];
+	int operator, var_pen, var[CUSTOM_SYMBOL_MAXVAR];	/* For conditionals: var[0] refers to variable on left hand side of operator, var[1] and var[2] to the right hand */
+	enum gmt_enum_custsymb conditional;
 	unsigned int justify;	/* For macro code l text justification [PSL_MC] */
 	bool negate, is_var[CUSTOM_SYMBOL_MAXVAR];
 	struct GMT_FILL *fill;
 	struct GMT_PEN *pen;
 	struct GMT_CUSTOM_SYMBOL_ITEM *next;
 	struct GMT_FONT font;	/* Font to use for the l macro */
+	char action;
 	char *string;
 };
 
@@ -84,7 +98,7 @@ struct GMT_CUSTOM_SYMBOL {
 	unsigned int  n_required;   /* Number of additional columns necessary to decode chosen symbol */
 	unsigned int  start;    /* Column number of first additional column [2-4 depending on -C and psxy vs psxyz] */
 	unsigned int  PS;       /* nonzero if a PSL symbol */
-	bool          text;     /* true if symbol places text and hence need fonts to be set properly */
+	unsigned int  text;     /* >0 if symbol places text and hence need fonts to be set properly, 2 if using trailing text */
 	unsigned int *type;     /* Array with type of each parameter [0 = dimensionless, 1 = dimension, 2 = geographic angle (convert via projection)] */
 	double        PS_BB[4]; /* Will hold the BoundingBox as [x0 x1 y0 y1] if PS is true */
 	struct        GMT_CUSTOM_SYMBOL_ITEM *first;
@@ -105,19 +119,19 @@ struct GMT_MAP_PANEL {
 	bool debug;
 };
 
-/*! Plot a map insert box in psbasemap */
-struct GMT_MAP_INSERT {
-	/* -D[g|j|n|x]<refpoint>+w<width>[<unit>][/<height>[<unit>]][+j<justify>[+o<dx>[/<dy>]][+s<file>][+t] or [<unit>]<xmin>/<xmax>/<ymin>/<ymax>[r][+s<file>][+t] */
-	int justify;		/* Gave center of insert */
-	bool plot;		/* true if we want to draw the insert */
+/*! Plot a map inset box in psbasemap */
+struct GMT_MAP_INSET {
+	/* -D[g|j|n|x]<refpoint>+w<width>[/<height>][+j<justify>[+o<dx>[/<dy>]][+s<file>][+t] or [<unit>]<xmin>/<xmax>/<ymin>/<ymax>[r][+s<file>][+t] */
+	int justify;		/* Gave center of inset */
+	bool plot;		/* true if we want to draw the inset */
 	bool oblique;		/* true if we want got <w/s/e/n>r instead of <w/e/s/n> */
-	bool translate;		/* true if we want to translate plot origin to the LL corner of insert */
+	bool translate;		/* true if we want to translate plot origin to the LL corner of inset */
 	char unit;		/* Unit of projected coordinates or 0 for geographic */
 	struct GMT_REFPOINT *refpoint;
 	double wesn[4];		/* Geographic or projected boundaries */
 	double off[2];		/* Offset from reference point */
 	double dim[2];		/* Width & height of box */
-	char *file;			/* Used to write insert location and dimensions [+s] */
+	char *file;			/* Used to write inset location and dimensions [+s] */
 	struct GMT_MAP_PANEL *panel;	/* Everything about optional back panel */
 };
 
@@ -127,11 +141,14 @@ struct GMT_MAP_SCALE {
 	double origin[2];	/* Longitude/latitude where scale should apply */
 	double off[2];		/* Offset from reference point */
 	double length;		/* How long the scale is in measure units */
+	double z_scale;		/* How long the scale is in measure units */
 	bool plot;		/* true if we want to draw the scale */
 	bool fancy;		/* true for a fancy map scale */
 	bool unit;		/* true if we should append distance unit to all annotations along the scale */
 	bool do_label;		/* true if we should plot a label for the scale */
 	bool old_style;		/* true if we are using old syntax, pre-panel settings */
+	bool vertical;		/* Want a Cartesian vertical scale (i.e., for y-data) */
+	bool zdata;		/* z-data vertical scale (i.e., for z-data in pswiggle) */
 	int justify;		/* Justification of anchor point */
 	char measure;		/* The unit, i.e., e|f|k|M|n|u */
 	char alignment;		/* Placement of label: t(op), b(ottom), l(eft), r(ight) */
@@ -160,4 +177,4 @@ struct GMT_MAP_ROSE {
 	struct GMT_MAP_PANEL *panel;	/* Everything about optional back panel */
 };
 
-#endif	/* _GMT_SYMBOLS_H */
+#endif	/* GMT_SYMBOLS_H */
