@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -35,10 +35,7 @@
 #define THIS_MODULE_PURPOSE	"Convert, paste, or extract columns from data tables"
 #define THIS_MODULE_KEYS	"<D{,>D}"
 #define THIS_MODULE_NEEDS	""
-#define THIS_MODULE_OPTIONS "-:>Vabdefghios" GMT_OPT("HMm")
-
-EXTERN_MSC int gmt_get_ogr_id (struct GMT_OGR *G, char *name);
-EXTERN_MSC int gmt_parse_o_option (struct GMT_CTRL *GMT, char *arg);
+#define THIS_MODULE_OPTIONS "-:>Vabdefghioqs" GMT_OPT("HMm")
 
 #define INV_ROWS	1
 #define INV_SEGS	2
@@ -47,67 +44,67 @@ EXTERN_MSC int gmt_parse_o_option (struct GMT_CTRL *GMT, char *arg);
 /* Control structure for gmtconvert */
 
 struct GMTCONVERT_CTRL {
-	struct Out {	/* -> */
+	struct GMTCONVERT_Out {	/* -> */
 		bool active;
 		char *file;
 	} Out;
-	struct A {	/* -A */
+	struct GMTCONVERT_A {	/* -A */
 		bool active;
 	} A;
-	struct C {	/* -C[+l<min>+u<max>+i>] */
+	struct GMTCONVERT_C {	/* -C[+l<min>+u<max>+i>] */
 		bool active, invert;
 		uint64_t min, max;
 	} C;
-	struct D {	/* -D[<template>][+o<orig>] */
+	struct GMTCONVERT_D {	/* -D[<template>][+o<orig>] */
 		bool active;
 		bool origin;
 		unsigned int mode;
 		unsigned int t_orig, s_orig;
 		char *name;
 	} D;
-	struct E {	/* -E */
+	struct GMTCONVERT_E {	/* -E */
 		bool active;
 		bool end;
 		int mode;	/* -3, -1, -1, 0, or increment stride */
 	} E;
-	struct F {	/* -F<mode> */
+	struct GMTCONVERT_F {	/* -F<mode> */
 		bool active;
 		struct GMT_SEGMENTIZE S;
 	} F;
-	struct I {	/* -I[ast] */
+	struct GMTCONVERT_I {	/* -I[ast] */
 		bool active;
 		unsigned int mode;
 	} I;
-	struct L {	/* -L */
+	struct GMTCONVERT_L {	/* -L */
 		bool active;
 	} L;
-	struct N {	/* -N<col>[+a|d] sorting */
+	struct GMTCONVERT_N {	/* -N<col>[+a|d] sorting */
 		bool active;
 		int dir;	/* +1 ascending [default], -1 descending */
 		uint64_t col;
 	} N;
-	struct Q {	/* -Q<selections> */
+	struct GMTCONVERT_Q {	/* -Q<selections> */
 		bool active;
 		struct GMT_INT_SELECTION *select;
 	} Q;
-	struct S {	/* -S[~]\"search string\" */
+	struct GMTCONVERT_S {	/* -S[~]\"search string\" */
 		bool active;
 		struct GMT_TEXT_SELECTION *select;
 	} S;
-	struct T {	/* -T[sd] */
+	struct GMTCONVERT_T {	/* -T[sd] */
 		bool active[2];
 	} T;
-	struct W {	/* -W[+n] */
+	struct GMTCONVERT_W {	/* -W[+n] */
 		bool active;
 		unsigned int mode;
 	} W;
-	struct Z {	/* -Z[<first>]:[<last>] */
+	struct GMTCONVERT_Z {	/* -Z[<first>]:[<last>] [DEPRECATED - use -q instead]*/
 		bool active;
 		int64_t first, last;
 	} Z;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct GMTCONVERT_CTRL *C;
 
 	C = gmt_M_memory (GMT, NULL, 1, struct GMTCONVERT_CTRL);
@@ -118,7 +115,7 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_M_str_free (C->Out.file);
 	gmt_M_str_free (C->D.name);
@@ -127,12 +124,12 @@ GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *C) {	/*
 	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s [<table>] [-A] [-C[+l<min>][+u<max>][+i]] [-D[<template>[+o<orig>]]] [-E[f|l|m|M<stride>]] [-F<arg>] [-I[tsr]]\n", name);
-	GMT_Message (API, GMT_TIME_NONE, "\t[-L] [-N<col>[+a|d]] [-Q[~]<selection>] [-S[~]\"search string\"] [-T[hd]] [%s] [-W[+n]] [-Z[<first>][/<last>]] [%s]\n\t[%s] [%s] [%s] [%s] [%s]\n", GMT_V_OPT, GMT_a_OPT, GMT_b_OPT, GMT_d_OPT, GMT_e_OPT, GMT_f_OPT, GMT_g_OPT);
-	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s]\n\t[%s] [%s] [%s] [%s]\n\n", GMT_h_OPT, GMT_i_OPT, GMT_o_OPT, GMT_s_OPT, GMT_colon_OPT, GMT_PAR_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t[-L] [-N<col>[+a|d]] [-Q[~]<selection>] [-S[~]\"search string\"] [-T[hd]] [%s] [-W[+n]] [%s]\n\t[%s] [%s] [%s] [%s] [%s]\n", GMT_V_OPT, GMT_a_OPT, GMT_b_OPT, GMT_d_OPT, GMT_e_OPT, GMT_f_OPT, GMT_g_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s]\n\t[%s] [%s] [%s] [%s] [%s]\n\n", GMT_h_OPT, GMT_i_OPT, GMT_o_OPT, GMT_q_OPT, GMT_s_OPT, GMT_colon_OPT, GMT_PAR_OPT);
 
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
@@ -183,13 +180,12 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   d: Prevent the writing of duplicate data records.\n");
 	GMT_Option (API, "V");
 	GMT_Message (API, GMT_TIME_NONE, "\t-W Convert trailing text to numbers, if possible.  Append +n to suppress NaN columns.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t-Z Select range of output records.  If not set, <first> = 0 and <last> = last record [all records].\n");
-	GMT_Option (API, "a,bi,bo,d,e,f,g,h,i,o,s,:,.");
+	GMT_Option (API, "a,bi,bo,d,e,f,g,h,i,o,q,s,:,.");
 
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to gmtconvert and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -207,13 +203,13 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 		switch (opt->option) {
 
 			case '<':	/* Skip input files */
-				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_DATASET, GMT_IN, GMT_FILE_REMOTE, &(opt->arg))) n_errors++;;
 				break;
 			case '>':	/* Got named output file */
-				if (n_files++ == 0 && gmt_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
-					Ctrl->Out.file = strdup (opt->arg);
-				else
-					n_errors++;
+				if (n_files++ > 0) { n_errors++; continue; }
+				Ctrl->Out.active = true;
+				if (opt->arg[0]) Ctrl->Out.file = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_DATASET, GMT_OUT, GMT_FILE_LOCAL, &(Ctrl->Out.file))) n_errors++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -230,13 +226,13 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 							Ctrl->C.invert = true;	break;
 						case 'l':	/* Set fewest records required */
 						 	if ((value = atol (&p[1])) < 0)
-								GMT_Report (API, GMT_MSG_NORMAL, "The -C+l modifier was given negative record count!\n");
+								GMT_Report (API, GMT_MSG_ERROR, "The -C+l modifier was given negative record count!\n");
 							else
 								Ctrl->C.min = (uint64_t)value;
 							break;
 						case 'u':	/* Set max records required */
 					 		if ((value = atol (&p[1])) < 0)
-								GMT_Report (API, GMT_MSG_NORMAL, "The -C+u modifier was given negative record count!\n");
+								GMT_Report (API, GMT_MSG_ERROR, "The -C+u modifier was given negative record count!\n");
 							else
 								Ctrl->C.max = (uint64_t)value;
 							break;
@@ -265,7 +261,8 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 					case 'l':		/* Get last point only */
 						Ctrl->E.mode = -2; break;
 					case 'M':		/* Set modulo step */
-						Ctrl->E.end = true;	/* Include last point; fall through on purpose to set the step */
+						Ctrl->E.end = true;	/* Include last point */
+						/* Intentionally fall through - to set the step */
 					case 'm':		/* Set modulo step */
 						Ctrl->E.mode = atoi (&opt->arg[1]); break;
 					default:		/* Get first and last point only */
@@ -295,7 +292,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 						case 's': Ctrl->I.mode |= INV_SEGS; break;	/* Reverse segment order */
 						case 'r': Ctrl->I.mode |= INV_ROWS; break;	/* Reverse record order */
 						default:
-							GMT_Report (API, GMT_MSG_NORMAL,
+							GMT_Report (API, GMT_MSG_ERROR,
 							            "The -I option does not recognize modifier %c\n", (int)opt->arg[k]);
 							n_errors++;
 							break;
@@ -340,6 +337,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 				break;
 			case 'Z':
 				Ctrl->Z.active = true;
+				GMT_Report (API, GMT_MSG_COMPAT, "Option -Z is deprecated (but still works); Use common option -q instead\n");
 				if ((c = strchr (opt->arg, ':')) || (c = strchr (opt->arg, '/'))) {	/* Got [<first>]:[<last>] or [<first>]/[<last>] */
 					char div = c[0];	/* Either : or / */
 					if (opt->arg[0] == div) /* No first given, default to 0 */
@@ -380,16 +378,16 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 				p += strspn (p, "0123456789."); /* span past digits and decimal */
 				if ( strspn (p, "diu") == 0 ) {
 					/* No valid conversion specifier */
-					GMT_Report (API, GMT_MSG_NORMAL,
-						"Syntax error: Use of unsupported conversion specifier at position %" PRIuS " in format string '%s'.\n",
+					GMT_Report (API, GMT_MSG_ERROR,
+						"Option -D: Use of unsupported conversion specifier at position %" PRIuS " in format string '%s'.\n",
 						p - Ctrl->D.name + 1, Ctrl->D.name);
 					n_errors++;
 				}
 				++n_formats;
 			}
 			if ( n_formats == 0 || n_formats > 2 ) {	/* Incorrect number of format specifiers */
-				GMT_Report (API, GMT_MSG_NORMAL,
-					"Syntax error: Incorrect number of format specifiers in format string '%s'.\n",
+				GMT_Report (API, GMT_MSG_ERROR,
+					"Option -D: Incorrect number of format specifiers in format string '%s'.\n",
 					Ctrl->D.name);
 				n_errors++;
 			}
@@ -398,23 +396,25 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTCONVERT_CTRL *Ctrl, struct
 		}
 	}
 	n_errors += gmt_M_check_condition (GMT, GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] == 0,
-	                                 "Syntax error: Must specify number of columns in binary input data (-bi)\n");
+	                                 "Must specify number of columns in binary input data (-bi)\n");
 	n_errors += gmt_M_check_condition (GMT, GMT->common.b.active[GMT_IN] && (Ctrl->L.active || Ctrl->S.active),
-	                                 "Syntax error: -L or -S requires ASCII input data\n");
+	                                 "Options -L or -S requires ASCII input data\n");
 	n_errors += gmt_M_check_condition (GMT, Ctrl->C.active && (Ctrl->C.min > Ctrl->C.max),
-	                                 "Syntax error: -C minimum records cannot exceed maximum records\n");
+	                                 "Option -C: minimum records cannot exceed maximum records\n");
 	n_errors += gmt_M_check_condition (GMT, Ctrl->D.active && Ctrl->D.name && !strstr (Ctrl->D.name, "%"),
-	                                 "Syntax error: -D Output template must contain %%d\n");
+	                                 "Option -D: Output template must contain %%d\n");
 	n_errors += gmt_M_check_condition (GMT, Ctrl->Q.active && Ctrl->S.active,
-	                                 "Syntax error: Only one of -Q and -S can be used simultaneously\n");
+	                                 "Only one of -Q and -S can be used simultaneously\n");
 	n_errors += gmt_M_check_condition (GMT, Ctrl->N.active && Ctrl->F.active,
-	                                 "Syntax error: The -N option cannot be used with -F\n");
-	n_errors += gmt_M_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
+	                                 "The -N option cannot be used with -F\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->Z.active && GMT->common.q.active[GMT_OUT],
+	                                 "The deprecated -Z option cannot be used with -qo\n");
+	n_errors += gmt_M_check_condition (GMT, n_files > 1, "Only one output destination can be specified\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-GMT_LOCAL bool is_duplicate_row (struct GMT_DATASEGMENT *S, uint64_t row) {
+GMT_LOCAL bool gmtconvert_is_duplicate_row (struct GMT_DATASEGMENT *S, uint64_t row) {
 	uint64_t col;
 	/* Loop over all columns and compare the two records, if differ then return false.
 	 * If passes all columns then they are the same and we return true. */
@@ -427,7 +427,7 @@ GMT_LOCAL bool is_duplicate_row (struct GMT_DATASEGMENT *S, uint64_t row) {
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_gmtconvert (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_gmtconvert (void *V_API, int mode, void *args) {
 	bool match = false, prevent_seg_headers = false;
 	int error = 0;
 	uint64_t out_col, col, n_cols_in = 0, n_cols_out, tbl, tlen;
@@ -459,14 +459,14 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the gmtconvert main code ----------------------------*/
 
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Processing input table data\n");
+	GMT_Report (API, GMT_MSG_INFORMATION, "Processing input table data\n");
 
 	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_POINT, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {
 		Return (API->error);	/* Establishes data files or stdin */
@@ -479,17 +479,17 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 	}
 
 	if (D[GMT_IN]->n_records == 0) {
-		GMT_Report (API, GMT_MSG_VERBOSE, "No data records provided\n");
+		GMT_Report (API, GMT_MSG_WARNING, "No data records provided\n");
 		Return (GMT_NOERROR);
 	}
 	if (GMT->common.a.active && D[GMT_IN]->n_tables > 1) {
-		GMT_Report (API, GMT_MSG_NORMAL, "The -a option requires a single table only.\n");
+		GMT_Report (API, GMT_MSG_ERROR, "The -a option requires a single table only.\n");
 		Return (GMT_RUNTIME_ERROR);
 	}
 	DHi = gmt_get_DD_hidden (D[GMT_IN]);
 	THi = gmt_get_DT_hidden (D[GMT_IN]->table[0]);
 	if (GMT->common.a.active && THi->ogr) {
-		GMT_Report (API, GMT_MSG_NORMAL, "The -a option requires a single table without OGR metadata.\n");
+		GMT_Report (API, GMT_MSG_ERROR, "The -a option requires a single table without OGR metadata.\n");
 		Return (GMT_RUNTIME_ERROR);
 	}
 
@@ -526,13 +526,13 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 				nan = gmt_M_memory (GMT, NULL, n_col, char);
 				tmp = gmt_M_memory (GMT, NULL, n_col, double);
 				for (col = 0; col < n_col; col++) if (gmt_M_is_dnan (out[col])) nan[col] = 1, n_cols_in--;
-				GMT_Report (API, GMT_MSG_LONG_VERBOSE, "First record trailing text converted to %" PRIu64 " columns, with %" PRIu64 " of them yielding NaNs [skipped]\n", n_col, n_col - n_cols_in);
+				GMT_Report (API, GMT_MSG_INFORMATION, "First record trailing text converted to %" PRIu64 " columns, with %" PRIu64 " of them yielding NaNs [skipped]\n", n_col, n_col - n_cols_in);
 			}
 			else
-				GMT_Report (API, GMT_MSG_LONG_VERBOSE, "First record trailing text converted to %" PRIu64 " columns\n", n_col);
+				GMT_Report (API, GMT_MSG_INFORMATION, "First record trailing text converted to %" PRIu64 " columns\n", n_col);
 		}
 		else
-			GMT_Report (API, GMT_MSG_VERBOSE, "No trialing text found in first record; -W will not have any effect.\n");
+			GMT_Report (API, GMT_MSG_WARNING, "No trialing text found in first record; -W will not have any effect.\n");
 		if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_POINT, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Registers default output destination, unless already set */
 			Return (API->error);
 		}
@@ -587,11 +587,11 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 	n_cols_out = (Ctrl->A.active) ? n_cols_in : n_cols_out;	/* Default or Reset since we did not have -A */
 
 	if (error) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Parsing requires files with same number of records.\n");
+		GMT_Report (API, GMT_MSG_ERROR, "Parsing requires files with same number of records.\n");
 		Return (GMT_RUNTIME_ERROR);
 	}
 	if (n_cols_out == 0 && !GMT->current.io.trailing_text[GMT_OUT]) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Selection led to no output columns.\n");
+		GMT_Report (API, GMT_MSG_ERROR, "Selection led to no output columns.\n");
 		Return (GMT_RUNTIME_ERROR);
 
 	}
@@ -643,7 +643,7 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 				n_in_rows++;
 				if (Ctrl->Z.active && (n_in_rows < Ctrl->Z.first || n_in_rows > Ctrl->Z.last)) continue;	/* Skip if outside limited record range */
 				if (!Ctrl->E.active) {
-					if (Ctrl->T.active[1] && row && is_duplicate_row (S, row)) continue;	/* Skip duplicate records */
+					if (Ctrl->T.active[1] && row && gmtconvert_is_duplicate_row (S, row)) continue;	/* Skip duplicate records */
 				}
 				else if (Ctrl->E.mode < 0) {	/* Only pass first or last or both of them, skipping all others */
 					if (row > 0 && row < last_row) continue;		/* Always skip the middle of the segment */
@@ -692,7 +692,7 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 		uint64_t tbl1, tbl2, row1, row2, seg1, seg2;
 		void *p = NULL;
 		if (Ctrl->I.mode & INV_ROWS) {	/* Must actually swap rows */
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Reversing order of records within each segment.\n");
+			GMT_Report (API, GMT_MSG_INFORMATION, "Reversing order of records within each segment.\n");
 			for (tbl = 0; tbl < D[GMT_OUT]->n_tables; tbl++) {	/* Number of output tables */
 				for (seg = 0; seg < D[GMT_OUT]->table[tbl]->n_segments; seg++) {	/* For each segment in the tables */
 					for (row1 = 0, row2 = D[GMT_OUT]->table[tbl]->segment[seg]->n_rows - 1; row1 < D[GMT_OUT]->table[tbl]->segment[seg]->n_rows/2; row1++, row2--) {
@@ -703,7 +703,7 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 			}
 		}
 		if (Ctrl->I.mode & INV_SEGS) {	/* Must reorder pointers to segments within each table */
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Reversing order of segments within each table.\n");
+			GMT_Report (API, GMT_MSG_INFORMATION, "Reversing order of segments within each table.\n");
 			for (tbl = 0; tbl < D[GMT_OUT]->n_tables; tbl++) {	/* Number of output tables */
 				for (seg1 = 0, seg2 = D[GMT_OUT]->table[tbl]->n_segments-1; seg1 < D[GMT_OUT]->table[tbl]->n_segments/2; seg1++, seg2--) {	/* For each segment in the table */
 					p = D[GMT_OUT]->table[tbl]->segment[seg1];
@@ -713,7 +713,7 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 			}
 		}
 		if (Ctrl->I.mode & INV_TBLS) {	/* Must reorder pointers to tables within dataset  */
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Reversing order of tables within the data set.\n");
+			GMT_Report (API, GMT_MSG_INFORMATION, "Reversing order of tables within the data set.\n");
 			for (tbl1 = 0, tbl2 = D[GMT_OUT]->n_tables-1; tbl1 < D[GMT_OUT]->n_tables/2; tbl1++, tbl2--) {	/* For each table */
 				p = D[GMT_OUT]->table[tbl1];
 				D[GMT_OUT]->table[tbl1] = D[GMT_OUT]->table[tbl2];
@@ -749,7 +749,7 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 		unsigned int flag[3] = {0, 0, GMT_WRITE_SEGMENT};
 		struct GMT_DATASET *D2 = NULL;
 		if ((D2 = GMT_Convert_Data (API, D[GMT_OUT], GMT_IS_DATASET, NULL, GMT_IS_DATASET, flag)) == NULL) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Error collating each table's segments into a single segment per table.\n");
+			GMT_Report (API, GMT_MSG_ERROR, "Failure while collating each table's segments into a single segment per table.\n");
 			Return (API->error);
 		}
 		if (GMT_Destroy_Data (API, &D[GMT_OUT]) != GMT_NOERROR) {	/* Remove the previously registered output dataset */
@@ -763,11 +763,11 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 		bool do_it = true;
 		char *way[3] = {"descending", "", "ascending"};
 		if (Ctrl->N.col >= D[GMT_OUT]->n_columns) {
-			GMT_Report (API, GMT_MSG_VERBOSE, "Column selected (%d) as sorting key is outside range of valid columns [0-%d].  No sorting performed\n", (int)Ctrl->N.col, (int)(D[GMT_OUT]->n_columns - 1));
+			GMT_Report (API, GMT_MSG_WARNING, "Column selected (%d) as sorting key is outside range of valid columns [0-%d].  No sorting performed\n", (int)Ctrl->N.col, (int)(D[GMT_OUT]->n_columns - 1));
 			do_it = false;
 		}
 		else
-			GMT_Report (API, GMT_MSG_VERBOSE, "Sort data based on column %d in %s order\n", (int)Ctrl->N.col, way[Ctrl->N.dir+1]);
+			GMT_Report (API, GMT_MSG_INFORMATION, "Sort data based on column %d in %s order\n", (int)Ctrl->N.col, way[Ctrl->N.dir+1]);
 		GMT->current.io.record_type[GMT_OUT] = GMT->current.io.record_type[GMT_IN];
 		for (tbl = 0; do_it && tbl < D[GMT_OUT]->n_tables; tbl++) {	/* Number of output tables */
 			for (seg = 0; seg < D[GMT_OUT]->table[tbl]->n_segments; seg++) {	/* For each segment in the tables */
@@ -794,15 +794,15 @@ int GMT_gmtconvert (void *V_API, int mode, void *args) {
 		}
 		if (do_it) gmt_M_free (GMT, Z);
 	}
-	
+
 	if (GMT_Write_Data (API, GMT_IS_DATASET, GMT_IS_FILE, D[GMT_IN]->geometry, DHo->io_mode, NULL, Ctrl->Out.file, D[GMT_OUT]) != GMT_NOERROR) {
 		Return (API->error);
 	}
 	if (prevent_seg_headers) GMT->current.io.skip_headers_on_outout = false;	/* Restore to default if it was changed for file output */
 
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "%" PRIu64 " tables %s, %" PRIu64 " records passed (input cols = %d; output cols = %d)\n",
+	GMT_Report (API, GMT_MSG_INFORMATION, "%" PRIu64 " tables %s, %" PRIu64 " records passed (input cols = %d; output cols = %d)\n",
 		D[GMT_IN]->n_tables, method[Ctrl->A.active], D[GMT_OUT]->n_records, n_cols_in, n_cols_out);
-	if (Ctrl->Q.active || Ctrl->S.active) GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Extracted %" PRIu64 " from a total of %" PRIu64 " segments\n", n_out_seg, D[GMT_OUT]->n_segments);
+	if (Ctrl->Q.active || Ctrl->S.active) GMT_Report (API, GMT_MSG_INFORMATION, "Extracted %" PRIu64 " from a total of %" PRIu64 " segments\n", n_out_seg, D[GMT_OUT]->n_segments);
 
 	Return (GMT_NOERROR);
 }
