@@ -342,7 +342,7 @@ EXTERN_MSC int GMT_grdclip (void *V_API, int mode, void *args) {
 		Return (API->error);	/* Get subset */
 	}
 
-	new_grid = gmt_set_outgrid (GMT, Ctrl->In.file, false, G, &Out);	/* true if input is a read-only array */
+	new_grid = gmt_set_outgrid (GMT, Ctrl->In.file, false, 0, G, &Out);	/* true if input is a read-only array */
 
 	gmt_M_grd_loop (GMT, G, row, col, ij) {
 		/* Checking if extremes are exceeded (need not check NaN) */
