@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -41,43 +41,43 @@ enum GRDFILL_mode {
 };
 
 struct GRDFILL_CTRL {
-	struct In {
+	struct GRDFILL_In {
 		bool active;
 		char *file;
 	} In;
-	struct A {	/* -A<algo>[<options>] */
+	struct GRDFILL_A {	/* -A<algo>[<options>] */
 		bool active;
 		unsigned int mode;
 		double value;
 	} A;
-	struct G {	/* -G<outgrid> */
+	struct GRDFILL_G {	/* -G<outgrid> */
 		bool active;
 		char *file;
 	} G;
-	struct L {	/* -L[p] */
+	struct GRDFILL_L {	/* -L[p] */
 		bool active;
 		unsigned int mode;	/* 0 = region, 1 = polygons */
 	} L;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct GRDFILL_CTRL *C;
-	
+
 	C = gmt_M_memory (GMT, NULL, 1, struct GRDFILL_CTRL);
-	
+
 	/* Initialize values whose defaults are not 0/false/NULL */
-	
+
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	gmt_M_str_free (C->In.file);	
-	gmt_M_str_free (C->G.file);	
-	gmt_M_free (GMT, C);	
+	gmt_M_str_free (C->In.file);
+	gmt_M_str_free (C->G.file);
+	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s <ingrid> [-A<mode><options>] [-G<outgrid>] [-L[p]]\n\t[%s] [%s] [%s] [%s]\n\n",
@@ -91,8 +91,8 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   c<value> Fill in NaNs with the constant <value>.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   n<radius> Fill in NaNs with nearest neighbor values;\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t     append <max_radius> nodes for the outward search.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t     [Default radius is sqrt(xn^2+by^2)]\n");
-//	GMT_Message (API, GMT_TIME_NONE, "\t   s Fill in NaNs with a spline (optionally append tension).\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t     [Default radius is sqrt(nx^2+ny^2), with (nx,ny) the dimensions of the grid].\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   s Fill in NaNs with a spline (optionally append tension).\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-G <outgrid> is the file to write the filled-in grid.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-L Just list the subregions w/e/s/n of each hole.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   No grid fill takes place and -G is ignored.\n");
@@ -102,14 +102,14 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to grdfill and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
 	 * returned when registering these sources/destinations with the API.
 	 */
 
-	unsigned int n_errors = 0;
+	unsigned int n_errors = 0, n_files = 0;
 	struct GMT_OPTION *opt = NULL;
 	struct GMTAPI_CTRL *API = GMT->parent;
 
@@ -117,22 +117,15 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *Ctrl, struct GMT
 		switch (opt->option) {
 
 			case '<':	/* Input and Output files */
-				/* Since grdfill allowed output grid to be given without -G we must actually
-				 * check for two input files and assign the 2nd as the actual output file */
-				if (gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_GRID)) {
-					Ctrl->In.file= strdup (opt->arg);
-				}
-				else {
-					GMT_Report (API, GMT_MSG_NORMAL, "Syntax error: Cannot find input file %s\n", opt->arg);
-					n_errors++;
-				}
+				if (n_files++ > 0) {n_errors++; continue; }
+				Ctrl->In.active = true;
+				if (opt->arg[0]) Ctrl->In.file = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_GRID, GMT_IN, GMT_FILE_REMOTE, &(Ctrl->In.file))) n_errors++;
 				break;
 			case '>':	/* Output file  */
 				Ctrl->G.active = true;
-				if (gmt_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_GRID))
-					Ctrl->G.file = strdup (opt->arg);
-				else
-					n_errors++;
+				if (opt->arg[0]) Ctrl->G.file = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_GRID, GMT_OUT, GMT_FILE_LOCAL, &(Ctrl->G.file))) n_errors++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -153,7 +146,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *Ctrl, struct GMT
 						if (opt->arg[1]) Ctrl->A.value =  atof (&opt->arg[1]);
 						break;
 					default:
-						GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -A: Unrecognized algorithm (%c)\n", opt->arg[0]);
+						GMT_Report (API, GMT_MSG_ERROR, "Option -A: Unrecognized algorithm (%c)\n", opt->arg[0]);
 						n_errors++;
 				}
 				break;
@@ -161,11 +154,13 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *Ctrl, struct GMT
 			case 'G':
 				Ctrl->G.active = true;
 				if (Ctrl->G.file) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Syntax error: Specify only one output file\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Specify only one output file\n");
 					n_errors++;
 				}
-				else
+				else {
 					Ctrl->G.file = strdup (opt->arg);
+					if (GMT_Get_FilePath (GMT->parent, GMT_IS_GRID, GMT_OUT, GMT_FILE_LOCAL, &(Ctrl->G.file))) n_errors++;
+				}
 				break;
 
 			case 'L':
@@ -173,25 +168,25 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDFILL_CTRL *Ctrl, struct GMT
 				if (opt->arg[0] == 'p')
 					Ctrl->L.mode = 1;
 				break;
-	
+
 			default:	/* Report bad options */
 				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Syntax error: Must specify input grid file\n");
-	n_errors += gmt_M_check_condition (GMT, !(Ctrl->L.active || Ctrl->G.file), "Syntax error: Must specify output grid file\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Must specify input grid file\n");
+	n_errors += gmt_M_check_condition (GMT, !(Ctrl->L.active || Ctrl->G.file), "Must specify output grid file\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-GMT_LOCAL int do_constant_fill (struct GMT_GRID *G, unsigned int limit[], gmt_grdfloat value) {
+GMT_LOCAL int grdfill_do_constant_fill (struct GMT_GRID *G, unsigned int limit[], gmt_grdfloat value) {
 	/* Algorithm 1: Replace NaNs with a constant value */
 	uint64_t node;
-	
-	for (unsigned int row = limit[YLO]; row < limit[YHI]; row++) {
-		for (unsigned int col = limit[XLO]; col < limit[XHI]; col++) {
+
+	for (unsigned int row = limit[YLO]; row <= limit[YHI]; row++) {
+		for (unsigned int col = limit[XLO]; col <= limit[XHI]; col++) {
 			node = gmt_M_ijp (G->header, row, col);
 			if (gmt_M_is_fnan (G->data[node]))
 				G->data[node] = value;
@@ -200,10 +195,10 @@ GMT_LOCAL int do_constant_fill (struct GMT_GRID *G, unsigned int limit[], gmt_gr
 	return GMT_NOERROR;
 }
 
-#if 0
-GMT_LOCAL int do_splinefill (struct GMTAPI_CTRL *API, struct GMT_GRID *G, double wesn[], unsigned int limit[], unsigned int n_in_hole, double value) {
+#if 1
+GMT_LOCAL int grdfill_do_splinefill (struct GMTAPI_CTRL *API, struct GMT_GRID *G, double wesn[], unsigned int limit[], unsigned int n_in_hole, double value) {
 	/* Algorithm 2: Replace NaNs with a spline */
-	char input[GMT_STR16] = {""}, output[GMT_STR16] = {""}, args[GMT_LEN256] = {""}, method[GMT_LEN32] = {""};
+	char input[GMT_VF_LEN] = {""}, output[GMT_VF_LEN] = {""}, args[GMT_LEN256] = {""}, method[GMT_LEN32] = {""};
 	unsigned int row, col, row_hole, col_hole, mode, d_limit[4], n_constraints;
 	uint64_t node, node_hole, k = 0, dim[GMT_DIM_SIZE] = {0, 0, 0, 0};
 	double *x = NULL, *y = NULL;
@@ -211,28 +206,35 @@ GMT_LOCAL int do_splinefill (struct GMTAPI_CTRL *API, struct GMT_GRID *G, double
 	struct GMT_VECTOR *V = NULL;
 	struct GMT_GRID *G_hole = NULL;
 	struct GMT_CTRL *GMT = API->GMT;
-	
+
 	/* Allocate a vector container for input to greenspline */
 	dim[0] = 3;	/* Want three input columns but let length be 0 - this signals that no vector allocations should take place */
-	if ((V = GMT_Create_Data (API, GMT_IS_VECTOR, GMT_IS_POINT, 0, dim, NULL, NULL, 0, 0, NULL)) == NULL) GMT_exit (API->GMT, EXIT_FAILURE);
+	if ((V = GMT_Create_Data (API, GMT_IS_VECTOR, GMT_IS_POINT, 0, dim, NULL, NULL, 0, 0, NULL)) == NULL) {
+		return (API->error);
+	}
 	/* Create a virtual file to hold the resampled grid */
-	if (GMT_Open_VirtualFile (API, GMT_IS_GRID, GMT_IS_SURFACE, GMT_OUT, NULL, output) == GMT_NOTSET) {
+	if (GMT_Open_VirtualFile (API, GMT_IS_GRID, GMT_IS_SURFACE, GMT_OUT|GMT_IS_REFERENCE, NULL, output) == GMT_NOTSET) {
 		return (API->error);
 	}
 	/* Add up to 2 rows/cols around hole, but watch for grid edges */
 	gmt_M_memcpy (d_limit, limit, 4, unsigned int);	/* d_limit will be used to set the grid domain */
+	/* Undo the half grid inc padding done in the main */
+	wesn[XLO] += 0.5 * G->header->inc[GMT_X];
+	wesn[XHI] -= 0.5 * G->header->inc[GMT_X];
+	wesn[YLO] += 0.5 * G->header->inc[GMT_Y];
+	wesn[YHI] -= 0.5 * G->header->inc[GMT_Y];
 	for (k = 1; k <= 2; k++) {
 		if (d_limit[XLO]) d_limit[XLO]--, wesn[XLO] -= G->header->inc[GMT_X];	/* Move one column westward */
 		if (d_limit[XHI] < (G->header->n_columns-1)) d_limit[XHI]++, wesn[XHI] += G->header->inc[GMT_X];	/* Move one column eastward */
-		if (d_limit[YLO]) d_limit[YLO]--, wesn[YLO] -= G->header->inc[GMT_Y];	/* Move one row northward */
-		if (d_limit[YHI] < (G->header->n_rows-1)) d_limit[YHI]++, wesn[YHI] += G->header->inc[GMT_Y];	/* Move one row southward */
+		if (d_limit[YLO]) d_limit[YLO]--, wesn[YHI] += G->header->inc[GMT_Y];	/* Move one row northward */
+		if (d_limit[YHI] < (G->header->n_rows-1)) d_limit[YHI]++, wesn[YLO] -= G->header->inc[GMT_Y];	/* Move one row southward */
 	}
-	n_constraints = (d_limit[YHI] - d_limit[YLO] - 1) * (d_limit[XHI] - d_limit[XLO] - 1) - n_in_hole;
+	n_constraints = (d_limit[YHI] - d_limit[YLO] + 1) * (d_limit[XHI] - d_limit[XLO] + 1) - n_in_hole;
 	x = gmt_M_memory (GMT, NULL, n_constraints, double);
 	y = gmt_M_memory (GMT, NULL, n_constraints, double);
 	z = gmt_M_memory (GMT, NULL, n_constraints, gmt_grdfloat);
-	for (row = d_limit[YLO]; row < d_limit[YHI]; row++) {
-		for (col = d_limit[XLO]; col < d_limit[XHI]; col++) {
+	for (row = d_limit[YLO], k = 0; row <= d_limit[YHI]; row++) {
+		for (col = d_limit[XLO]; col <= d_limit[XHI]; col++) {
 			node = gmt_M_ijp (G->header, row, col);
 			if (gmt_M_is_fnan (G->data[node])) continue;
 			x[k] = gmt_M_grd_col_to_x (GMT, col, G->header);
@@ -241,12 +243,13 @@ GMT_LOCAL int do_splinefill (struct GMTAPI_CTRL *API, struct GMT_GRID *G, double
 			k++;
 		}
 	}
+	V->n_rows = n_constraints;	/* Must specify how many input points we have */
 	GMT_Put_Vector (API, V, GMT_X, GMT_DOUBLE, x);
 	GMT_Put_Vector (API, V, GMT_Y, GMT_DOUBLE, y);
 	GMT_Put_Vector (API, V, GMT_Z, GMT_FLOAT,  z);
-	V->n_rows = k;	/* Must specify how many input points we have */
 	/* Associate our input data vectors with a virtual input file */
-	GMT_Open_VirtualFile (API, GMT_IS_DATASET, GMT_IS_POINT, GMT_IN, V, input);
+	if (GMT_Open_VirtualFile (API, GMT_IS_DATASET|GMT_VIA_VECTOR, GMT_IS_POINT, GMT_IN|GMT_IS_REFERENCE, V, input) == GMT_NOTSET)
+		return (API->error);
 	/* Prepare the greenspline command-line arguments */
 	mode = (gmt_M_is_geographic (GMT, GMT_IN)) ? 2 : 1;
 	if (value > 0.0)
@@ -257,7 +260,7 @@ GMT_LOCAL int do_splinefill (struct GMTAPI_CTRL *API, struct GMT_GRID *G, double
 	if (G->header->registration == GMT_GRID_PIXEL_REG) strcat (args, " -r");
 	strcat (args, " --GMT_HISTORY=false");
    	/* Run the greenspline module */
-	GMT_Report (API, GMT_MSG_VERBOSE, "Calling greenspline with args %s\n", args);
+	GMT_Report (API, GMT_MSG_INFORMATION, "Calling greenspline with args %s\n", args);
   	if (GMT_Call_Module (API, "greenspline", GMT_MODULE_CMD, args)) {
 		return (API->error);	/* Some sort of failure */
 	}
@@ -276,25 +279,25 @@ GMT_LOCAL int do_splinefill (struct GMTAPI_CTRL *API, struct GMT_GRID *G, double
 
 	/* Close the two virtual files */
 	if (GMT_Close_VirtualFile (API, output)) {
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to close virtual output file %s\n", output);
 		return (API->error);
-		GMT_Report (API, GMT_MSG_NORMAL, "Failed to close virtual output file %s\n", output);
 	}
 	if (GMT_Close_VirtualFile (API, input)) {
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to close virtual input file %s\n", input);
 		return (API->error);
-		GMT_Report (API, GMT_MSG_NORMAL, "Failed to close virtual input file %s\n", input);
 	}
-	
+
 	/* Free our custom vectors */
 	gmt_M_free (GMT, x);	gmt_M_free (GMT, y);	gmt_M_free (GMT, z);
 	if (GMT_Destroy_Data (API, &G_hole) != GMT_NOERROR) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Failed to destroy temporary hold grid\n");
+		GMT_Report (API, GMT_MSG_ERROR, "Failed to destroy temporary hold grid\n");
 		return (API->error);
 	}
 	return (GMT_NOERROR);
 }
 #endif
 
-GMT_LOCAL unsigned int trace_the_hole (struct GMT_GRID *G, uint64_t node, unsigned int row, unsigned int col, int64_t *step, char *ID, unsigned int limit[]) {
+GMT_LOCAL unsigned int grdfill_trace_the_hole (struct GMT_GRID *G, uint64_t node, unsigned int row, unsigned int col, int64_t *step, char *ID, unsigned int limit[]) {
 	/* Determine all the direct neighbor nodes in the W/E/S/N directions that are also NaN, recursively.
 	 * This is a limited form of Moore neighborhood called Von Neumann neighborhood since we only do the
 	 * four cardinal directions and ignore the diagonals.  Ignoring the diagonal means two holes that
@@ -304,7 +307,7 @@ GMT_LOCAL unsigned int trace_the_hole (struct GMT_GRID *G, uint64_t node, unsign
 	static int drow[4] = {1, 0, -1, 0}, dcol[4] = {0, 1, 0, -1};	/* Change in row,col per cardinal direction */
 	unsigned int side, next_row, next_rcol, n_nodes = 0;
 	int64_t ij;
-	
+
 	for (side = 0; side < 4; side++) {	/* For each of the 4 cardinal directions */
 		ij = node + step[side];		/* This is the grid node (and ID node) of this cardinal point */
 		if (ID[ij] == 0 && gmt_M_is_fnan (G->data[ij])) {	/* Hole extends in this direction, follow it to its next neighbor */
@@ -316,18 +319,18 @@ GMT_LOCAL unsigned int trace_the_hole (struct GMT_GRID *G, uint64_t node, unsign
 			if (next_row < limit[YLO]) limit[YLO] = next_row;
 			else if (next_row > limit[YHI]) limit[YHI] = next_row;
 			/* Recursively trace this nodes next neighbors as well */
-			n_nodes = n_nodes + 1 + trace_the_hole (G, ij, next_row, next_rcol, step, ID, limit);
+			n_nodes = n_nodes + 1 + grdfill_trace_the_hole (G, ij, next_row, next_rcol, step, ID, limit);
 		}
 	}
 	return (n_nodes);
 }
 
-GMT_LOCAL int64_t find_nearest (int64_t i, int64_t j, int64_t *r2, int64_t *is, int64_t *js, int64_t *xs, int64_t *ys) {
-	/* function to find the nearest point based on previous search, smallest distance ourside a radius */
+GMT_LOCAL int64_t grdfill_find_nearest (int64_t i, int64_t j, int64_t *r2, int64_t *is, int64_t *js, int64_t *xs, int64_t *ys) {
+	/* function to find the nearest point based on previous search, smallest distance outside a radius */
 	int64_t ct = 0, nx, ny, nx1, ii, k = 0, rr, nx1_2, ny_2;
-    
+
 	rr = INTMAX_MAX;	/* Ensure we reset this the first time */
-    
+
 	/* starting with nx = ny */
 	nx = (int64_t)(sqrt((double)(*r2) / 2.0));
 	/* loop over possible nx, find smallest rr */
@@ -362,7 +365,7 @@ GMT_LOCAL int64_t find_nearest (int64_t i, int64_t j, int64_t *r2, int64_t *is,
 		if (ny == 0) {
 			js[ct] =   0;	is[ct++] =  nx;
 			js[ct] =   0;	is[ct++] = -nx;
-			js[ct] =  nx;	is[ct++] =   0; 
+			js[ct] =  nx;	is[ct++] =   0;
 			js[ct] = -nx;	is[ct++] =   0;
 		}
 		else if (nx != ny){
@@ -373,7 +376,7 @@ GMT_LOCAL int64_t find_nearest (int64_t i, int64_t j, int64_t *r2, int64_t *is,
 			js[ct] =  nx;	is[ct++] =  ny;
 			js[ct] = -nx;	is[ct++] =  ny;
 			js[ct] =  nx;	is[ct++] = -ny;
-			js[ct] = -nx;	is[ct++] = -ny; 
+			js[ct] = -nx;	is[ct++] = -ny;
 		}
 		else {
 			js[ct] =  nx;	is[ct++] =  nx;
@@ -394,14 +397,14 @@ GMT_LOCAL int64_t find_nearest (int64_t i, int64_t j, int64_t *r2, int64_t *is,
 	return (ct);
 }
 
-GMT_LOCAL void nearest_interp (struct GMT_CTRL *GMT, struct GMT_GRID *In, struct GMT_GRID *Out, int64_t radius) {
+GMT_LOCAL void grdfill_nearest_interp (struct GMT_CTRL *GMT, struct GMT_GRID *In, struct GMT_GRID *Out, int64_t radius) {
 	uint64_t ij, node;
 	int64_t nx = In->header->n_columns, ny = In->header->n_rows;
  	int64_t i, j, flag, ct, k, recx = 1, recy = 1, cs = 0, rr;
  	int64_t *is = NULL, *js = NULL, *xs = NULL, *ys = NULL;
 	gmt_grdfloat *m = In->data, *m_interp = Out->data;	/* Short-hand for input and output grids */
 	double rad2;
- 	
+
  	/* Allocate memory for temporary indexes */
  	is = gmt_M_memory (GMT, NULL, 2048, int64_t);
  	js = gmt_M_memory (GMT, NULL, 2048, int64_t);
@@ -411,11 +414,11 @@ GMT_LOCAL void nearest_interp (struct GMT_CTRL *GMT, struct GMT_GRID *In, struct
 	if (radius == -1)	/* Set default radius */
 		radius = (int64_t)floor (sqrt ((double)(nx*nx + ny*ny)));
 	rad2 = (double)(radius * radius);
-	
-	GMT_Report (GMT->parent, GMT_MSG_LONG_VERBOSE, "Interpolating to nearest neighbor...\n");
+
+	GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Interpolating to nearest neighbor...\n");
 	gmt_M_row_loop (GMT, In, i) {	/* Loop over each row in grid */
- 		GMT_Report (GMT->parent, GMT_MSG_LONG_VERBOSE, "Working on row %" PRIi64 "\n", i);
-		rr = 0; 
+ 		GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Working on row %" PRIi64 "\n", i);
+		rr = 0;
 		gmt_M_col_loop (GMT, In, i, j, ij) {	/* Loop over all columns */
 			if (!gmt_M_is_fnan (m[ij]))	/* Already duplicated in the calling program */
 				rr = 0;
@@ -434,7 +437,7 @@ GMT_LOCAL void nearest_interp (struct GMT_CTRL *GMT, struct GMT_GRID *In, struct
 					rr = 0;
 
 				while (flag == 0 && rr <= rad2) {
-					ct = find_nearest (i, j, &rr, is, js, xs, ys);
+					ct = grdfill_find_nearest (i, j, &rr, is, js, xs, ys);
 					cs++;
 					for (k = 0; k < ct; k++) {
 						if (is[k] >= 0 && is[k] < ny && js[k] >=0 && js[k] < nx) {
@@ -455,7 +458,7 @@ GMT_LOCAL void nearest_interp (struct GMT_CTRL *GMT, struct GMT_GRID *In, struct
 		}
 	}
 
-	GMT_Report (GMT->parent, GMT_MSG_LONG_VERBOSE, "%" PRIi64 " number of searches used\n", cs);
+	GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "%" PRIi64 " number of searches used\n", cs);
 
 	gmt_M_free (GMT, is);
 	gmt_M_free (GMT, js);
@@ -466,9 +469,9 @@ GMT_LOCAL void nearest_interp (struct GMT_CTRL *GMT, struct GMT_GRID *In, struct
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_grdfill (void *V_API, int mode, void *args) {
-	char *ID = NULL;
-	int error = 0;
+EXTERN_MSC int GMT_grdfill (void *V_API, int mode, void *args) {
+	char *ID = NULL, *RG_orig_hist = NULL;
+	int error = 0, RG_id = 0;
 	unsigned int hole_number = 0, row, col, limit[4], n_nodes;
 	uint64_t node, offset;
 	int64_t off[4];
@@ -490,7 +493,7 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
@@ -507,7 +510,7 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 		if (!global && (GMT->common.R.wesn[XLO] < Grid->header->wesn[XLO] || GMT->common.R.wesn[XHI] > Grid->header->wesn[XHI])) error++;
 		if (GMT->common.R.wesn[YLO] < Grid->header->wesn[YLO] || GMT->common.R.wesn[YHI] > Grid->header->wesn[YHI]) error++;
 		if (error) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Subset exceeds data domain!\n");
+			GMT_Report (API, GMT_MSG_ERROR, "Subset exceeds data domain!\n");
 			Return (GMT_RUNTIME_ERROR);
 		}
 		if (GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_DATA_ONLY, GMT->common.R.wesn, Ctrl->In.file, Grid) == NULL) {
@@ -517,23 +520,23 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 	else if (GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_DATA_ONLY, NULL, Ctrl->In.file, Grid) == NULL) {
 		Return (API->error);	/* Get all */
 	}
-	
+
 	if (Ctrl->A.mode == ALG_NN) {	/* Do Eric Xu's NN algorithm and bail */
 		int64_t radius = lrint (Ctrl->A.value);
 		struct GMT_GRID *New = NULL;
 		if ((New = GMT_Duplicate_Data (API, GMT_IS_GRID, GMT_DUPLICATE_DATA, Grid)) == NULL) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Unable to duplicate input grid!\n");
+			GMT_Report (API, GMT_MSG_ERROR, "Unable to duplicate input grid!\n");
 			Return (API->error);
 		}
-		nearest_interp (GMT, Grid, New, radius);	/* Perform the NN replacements */
-		
+		grdfill_nearest_interp (GMT, Grid, New, radius);	/* Perform the NN replacements */
+
 		if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_ALL, NULL, Ctrl->G.file, New)) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Failed to write output grid!\n");
+			GMT_Report (API, GMT_MSG_ERROR, "Failed to write output grid!\n");
 			Return (API->error);
 		}
 		Return (GMT_NOERROR);
 	}
-	
+
 	if (Ctrl->L.active) {
 		if (GMT_Init_IO (API, GMT_IS_DATASET, (Ctrl->L.mode) ? GMT_IS_POLYGON : GMT_IS_POINT, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Registers default output destination, unless already set */
 			Return (API->error);
@@ -549,10 +552,15 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 		}
 		if (Ctrl->L.mode) gmt_set_segmentheader (GMT, GMT_OUT, true);
 	}
-	
+
+	if (Ctrl->A.mode == ALG_SPLINE) {	/* Must preserve the original -RG history which greenspline messes with */
+		RG_id = gmt_get_option_id (0, "R") + 1;
+		if (GMT->init.history[RG_id]) RG_orig_hist = strdup (GMT->init.history[RG_id]);
+	}
+
 	/* To avoid having to check every row,col for being inside the grid we set
 	 * the boundary row/cols in the ID grid to 1. */
-	
+
 	ID = gmt_M_memory_aligned (GMT, NULL, Grid->header->size, char);
 	/* Set the top and bottom boundary rows to UINT_MAX */
 	offset = (uint64_t)(Grid->header->pad[YHI] + Grid->header->n_rows) * Grid->header->mx;
@@ -567,7 +575,7 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 	}
 	/* Initiate the node offsets in the cardinal directions */
 	off[0] = Grid->header->mx;	off[1] = 1; 	off[2] = -off[0]; off[3] = -off[1];
-	
+
 	Out = gmt_new_record (GMT, wesn, NULL);	/* Since we only need to worry about numerics in this module */
 	gmt_M_grd_loop (GMT, Grid, row, col, node) {	/* Loop over all grid nodes */
 		if (ID[node]) continue;	/* Already identified as part of a hole */
@@ -577,26 +585,26 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 			ID[node] = 1;	/* Flag this node as part of a hole */
 			++hole_number;	/* Increase the current hole number */
 			/* Trace all the contiguous neighbors, updating the bounding box as we go along */
-			n_nodes = 1 + trace_the_hole (Grid, node, row, col, off, ID, limit);
+			n_nodes = 1 + grdfill_trace_the_hole (Grid, node, row, col, off, ID, limit);
 			wesn[XLO] = gmt_M_grd_col_to_x (GMT, limit[XLO], Grid->header) - 0.5 * Grid->header->inc[GMT_X];
 			wesn[XHI] = gmt_M_grd_col_to_x (GMT, limit[XHI], Grid->header) + 0.5 * Grid->header->inc[GMT_X];
 			wesn[YLO] = gmt_M_grd_row_to_y (GMT, limit[YHI], Grid->header) - 0.5 * Grid->header->inc[GMT_Y];
 			wesn[YHI] = gmt_M_grd_row_to_y (GMT, limit[YLO], Grid->header) + 0.5 * Grid->header->inc[GMT_Y];
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Hole BB %u: -R: %g/%g/%g/%g [%u nodes]\n", hole_number, wesn[XLO], wesn[XHI], wesn[YLO], wesn[YHI], n_nodes);
+			GMT_Report (API, GMT_MSG_INFORMATION, "Hole BB %u: -R: %g/%g/%g/%g [%u nodes]\n", hole_number, wesn[XLO], wesn[XHI], wesn[YLO], wesn[YHI], n_nodes);
 			if (Ctrl->L.active) {
 				if (Ctrl->L.mode) {	/* Write a closed polygon */
 					double tmp[4];
 					gmt_M_memcpy (tmp, wesn, 4, double);
 					GMT_Put_Record (API, GMT_WRITE_SEGMENT_HEADER, NULL);
-					wesn[GMT_X] = tmp[XLO];	wesn[GMT_Y] = tmp[YLO];	
+					wesn[GMT_X] = tmp[XLO];	wesn[GMT_Y] = tmp[YLO];
 					GMT_Put_Record (API, GMT_WRITE_DATA, Out);
 					wesn[GMT_X] = tmp[XHI];
 					GMT_Put_Record (API, GMT_WRITE_DATA, Out);
-					wesn[GMT_Y] = tmp[YHI];	
+					wesn[GMT_Y] = tmp[YHI];
 					GMT_Put_Record (API, GMT_WRITE_DATA, Out);
-					wesn[GMT_X] = tmp[XLO];	
+					wesn[GMT_X] = tmp[XLO];
 					GMT_Put_Record (API, GMT_WRITE_DATA, Out);
-					wesn[GMT_Y] = tmp[YLO];	
+					wesn[GMT_Y] = tmp[YLO];
 					GMT_Put_Record (API, GMT_WRITE_DATA, Out);
 				}
 				else	/* Write west east south north limits */
@@ -605,20 +613,20 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 			else {
 				switch (Ctrl->A.mode) {
 					case ALG_CONSTANT:	/* Fill in using a constant value */
-						error = do_constant_fill (Grid, limit, (gmt_grdfloat)Ctrl->A.value);
+						error = grdfill_do_constant_fill (Grid, limit, (gmt_grdfloat)Ctrl->A.value);
 						break;
 					case ALG_SPLINE:	/* Fill in using a spline */
-						//error = do_splinefill (API, Grid, wesn, limit, n_nodes, Ctrl->A.value);
+						error = grdfill_do_splinefill (API, Grid, wesn, limit, n_nodes, Ctrl->A.value);
 						break;
 				}
 				if (error) {
-					GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Failed to fill hole %u\n", hole_number);
+					GMT_Report (API, GMT_MSG_INFORMATION, "Failed to fill hole %u\n", hole_number);
 					continue;
 				}
 			}
 		}
 	}
-	if (hole_number) GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Found %u holes\n", hole_number);
+	if (hole_number) GMT_Report (API, GMT_MSG_INFORMATION, "Found %u holes\n", hole_number);
 	gmt_M_free_aligned (GMT, ID);
 	gmt_M_free (GMT, Out);
 
@@ -634,8 +642,13 @@ int GMT_grdfill (void *V_API, int mode, void *args) {
 			Return (API->error);
 	}
 	else {
-		GMT_Report (API, GMT_MSG_VERBOSE, "No holes detected in grid - grid was not updated\n");
+		GMT_Report (API, GMT_MSG_WARNING, "No holes detected in grid - grid was not updated\n");
 	}
-	
+
+	if (Ctrl->A.mode == ALG_SPLINE) {
+		if (GMT->init.history[RG_id]) gmt_M_str_free (GMT->init.history[RG_id]);
+		if (RG_orig_hist) GMT->init.history[RG_id] = RG_orig_hist;
+	}
+
 	Return (GMT_NOERROR);
 }
