@@ -625,6 +625,7 @@ static int parse (struct GMT_CTRL *GMT, struct GRDVIEW_CTRL *Ctrl, struct GMT_OP
 					case 'c':	/* Image with colormask */
 						if (opt->arg[1] && isdigit ((int)opt->arg[1])) Ctrl->Q.dpi = atoi (&opt->arg[1]);
 						Ctrl->Q.mode = GRDVIEW_IMAGE;
+						Ctrl->Q.cpt = true;	/* Will need a CPT */
 						Ctrl->Q.mask = true;
 						break;
 					case 't':	/* Image without color interpolation */
@@ -681,15 +682,20 @@ static int parse (struct GMT_CTRL *GMT, struct GRDVIEW_CTRL *Ctrl, struct GMT_OP
 				Ctrl->S.value = sval;
 				break;
 			case 'T':	/* Tile plot -T[+s][+o<pen>] */
-				Ctrl->T.active = true;
-				if (strchr (opt->arg, '+') || gmt_M_compat_check (GMT, 6)) {	/* New syntax */
-					if (strstr (opt->arg, "+s")) Ctrl->T.skip = true;
-					if ((c = strstr (opt->arg, "+o")) && gmt_getpen (GMT, &c[2], &Ctrl->T.pen)) {
-						gmt_pen_syntax (GMT, 'T', NULL, " ", 0);
-						n_errors++;
+				Ctrl->T.active = true;	/* Plot as tiles */
+				if (opt->arg[0] && (strchr (opt->arg, '+') || gmt_M_compat_check (GMT, 6))) {	/* New syntax */
+					if (strstr (opt->arg, "+s"))
+						Ctrl->T.skip = true;
+					if ((c = strstr (opt->arg, "+o"))) {
+						if (gmt_getpen (GMT, &c[2], &Ctrl->T.pen)) {
+							gmt_pen_syntax (GMT, 'T', NULL, " ", 0);
+							n_errors++;
+						}
+						else
+							Ctrl->T.outline = true;
 					}
 				}
-				else {	/* Old-style syntax -T[s][o<pen>] */
+				else if (opt->arg[0]) {	/* Old-style syntax -T[s][o<pen>] */
 					k = 0;
 					if (opt->arg[0] == 's') Ctrl->T.skip = true, k = 1;
 					if (opt->arg[k] == 'o') {	/* Want tile outline also */
@@ -846,7 +852,7 @@ EXTERN_MSC int GMT_grdview (void *V_API, int mode, void *args) {
 		}
 	}
 
-	if (!Ctrl->C.active && Ctrl->Q.cpt && Ctrl->G.n == 1)
+	if (!Ctrl->C.active && Ctrl->Q.cpt && Ctrl->G.n != 3)
 		Ctrl->C.active = true;	/* Use default CPT (GMT_DEFAULT_CPT_NAME) and autostretch or under modern reuse current CPT */
 
 	/* Determine what wesn to pass to map_setup */
