@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,10 @@
  * Brief synopsis: grdredpol reads a grid file with the magnetic field anomaly and
  * computes the continuous reduction to the pole (RTP) anomaly by calculating the
  * filter coefficients in the frequency, inverse FT and convolve in space domain.
- * For details on the method see, Luis, J.F and J.M. Miranda (2008), 
- * "Reevaluation of magnetic chrons in the North Atlantic between 35N and 47N: 
- * Implications for the formation of the Azores Triple Junction and associated plateau, 
- * J. Geophys. Res., 113, B10105, doi:10.1029/2007JB005573 
+ * For details on the method see, Luis, J.F and J.M. Miranda (2008),
+ * "Reevaluation of magnetic chrons in the North Atlantic between 35N and 47N:
+ * Implications for the formation of the Azores Triple Junction and associated plateau,
+ * J. Geophys. Res., 113, B10105, doi:10.1029/2007JB005573
  *
  * Author:	Joaquim Luis / Miguel Miranda
  * Date:	18-Feb-2003 (original GMT4 version)
@@ -40,53 +40,53 @@
 #define THIS_MODULE_NEEDS	"g"
 #define THIS_MODULE_OPTIONS "-RVn"
 
-struct REDPOL_CTRL {
-	struct In {
+struct GRDREDPOL_CTRL {
+	struct GRDREDPOL_In {
 		bool active;
 		char *file;
 	} In;
-	struct C {	/* -C */
+	struct GRDREDPOL_C {	/* -C */
 		bool use_igrf;
 		bool const_f;
 		double	dec;
 		double	dip;
 	} C;
-	struct E {	/* -E */
+	struct GRDREDPOL_E {	/* -E */
 		bool active;
 		bool dip_grd_only;
 		bool dip_dec_grd;
 		char *decfile;
 		char *dipfile;
 	} E;
-	struct F {	/* -F */
+	struct GRDREDPOL_F {	/* -F */
 		bool active;
 		unsigned int	ncoef_row;
 		unsigned int	ncoef_col;
 		unsigned int	compute_n;	/* Compute ncoef_col */
 		double	width;
 	} F;
-	struct G {	/* -G<file> */
+	struct GRDREDPOL_G {	/* -G<file> */
 		bool active;
 		char	*file;
 	} G;
-	struct M {	/* -M */
+	struct GRDREDPOL_M {	/* -M */
 		bool pad_zero;
 		bool mirror;
 	} M;
-	struct N {	/* -N */
+	struct GRDREDPOL_N {	/* -N */
 		bool active;
 	} N;
-	struct S {	/* -S, size of working grid */
+	struct GRDREDPOL_S {	/* -S, size of working grid */
 		unsigned int	n_columns;
 		unsigned int	n_rows;
 	} S;
-	struct T {	/* -T */
+	struct GRDREDPOL_T {	/* -T */
 		double	year;
 	} T;
-	struct W {	/* -W */
+	struct GRDREDPOL_W {	/* -W */
 		double	wid;
 	} W;
-	struct Z {	/* -Z */
+	struct GRDREDPOL_Z {	/* -Z */
 		bool active;
 		char	*file;
 	} Z;
@@ -96,11 +96,11 @@ struct REDPOL_CTRL {
 #define ij0_data(Ctrl,i,j) ((Ctrl->S.n_columns+Ctrl->F.ncoef_col-1)*(i)+(j))
 #define ij_mn(Ctrl,i,j) (Ctrl->F.ncoef_row*(j)+(i))
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
-	struct REDPOL_CTRL *C;
-	
-	C = gmt_M_memory (GMT, NULL, 1, struct REDPOL_CTRL);
-	
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+	struct GRDREDPOL_CTRL *C;
+
+	C = gmt_M_memory (GMT, NULL, 1, struct GRDREDPOL_CTRL);
+
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->C.use_igrf = true;
 	C->M.pad_zero = true;
@@ -112,19 +112,19 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct REDPOL_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct GRDREDPOL_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	gmt_M_str_free (C->In.file);	
-	gmt_M_str_free (C->G.file);	
-	gmt_M_str_free (C->E.dipfile);	
-	gmt_M_str_free (C->E.decfile);	
-	gmt_M_str_free (C->Z.file);	
-	gmt_M_free (GMT, C);	
+	gmt_M_str_free (C->In.file);
+	gmt_M_str_free (C->G.file);
+	gmt_M_str_free (C->E.dipfile);
+	gmt_M_str_free (C->E.decfile);
+	gmt_M_str_free (C->Z.file);
+	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL void rtp_filt_colinear (int i, int j, int n21, double *gxr,double *gxi, double *gxar, 
-		double *gxai, double *gxbr, double *gxbi, double *gxgr, double *gxgi, double u, 
-		double v, double alfa, double beta, double gama, struct REDPOL_CTRL *Ctrl) {
+GMT_LOCAL void grdgravmag3d_rtp_filt_colinear (int i, int j, int n21, double *gxr,double *gxi, double *gxar,
+		double *gxai, double *gxbr, double *gxbi, double *gxgr, double *gxgi, double u,
+		double v, double alfa, double beta, double gama, struct GRDREDPOL_CTRL *Ctrl) {
 
 	uint64_t ij = ij_mn(Ctrl,i,j-n21+1);
 	double ro, ro2, ro3, ro4, ro5, alfa_u, beta_v, gama_ro, gama_ro_2;
@@ -139,7 +139,7 @@ GMT_LOCAL void rtp_filt_colinear (int i, int j, int n21, double *gxr,double *gxi
 
 	t2 = 1 / ((alfa_u_beta_v_2 + gama_ro_2) * (alfa_u_beta_v_2 + gama_ro_2));
 	t3 = t2 / (alfa_u_beta_v_2 + gama_ro_2);
-          					 
+
 	rnr = (gama_ro_2 - alfa_u_beta_v_2) * ro2;
 	rni = 2 * gama_ro * alfa_u_beta_v * ro2;
 
@@ -157,10 +157,10 @@ GMT_LOCAL void rtp_filt_colinear (int i, int j, int n21, double *gxr,double *gxi
 }
 
 
-GMT_LOCAL void rtp_filt_NOTcolinear (int i, int j, int n21, double *gxr, double *gxi, double *gxar, 
-		double *gxai, double *gxbr, double *gxbi, double *gxgr, double *gxgi, double *gxtr, 
-		double *gxti, double *gxmr, double *gxmi, double *gxnr, double *gxni, double u, double v, double alfa, 
-		double beta, double gama, double tau, double mu, double nu, struct REDPOL_CTRL *Ctrl) {
+GMT_LOCAL void grdgravmag3d_rtp_filt_not_colinear (int i, int j, int n21, double *gxr, double *gxi, double *gxar,
+		double *gxai, double *gxbr, double *gxbi, double *gxgr, double *gxgi, double *gxtr,
+		double *gxti, double *gxmr, double *gxmi, double *gxnr, double *gxni, double u, double v, double alfa,
+		double beta, double gama, double tau, double mu, double nu, struct GRDREDPOL_CTRL *Ctrl) {
 
 	uint64_t ij = ij_mn(Ctrl,i,j-n21+1);
 	double ro, ro2, ro3, ro4, ro5, alfa_u, beta_v, gama_ro, gama_ro_2;
@@ -211,7 +211,7 @@ GMT_LOCAL void rtp_filt_NOTcolinear (int i, int j, int n21, double *gxr, double
 	}
 }
 
-GMT_LOCAL void mirror_edges (gmt_grdfloat *grid, int nc, int i_data_start, int j_data_start, struct REDPOL_CTRL *Ctrl) {
+GMT_LOCAL void grdgravmag3d_mirror_edges (gmt_grdfloat *grid, int nc, int i_data_start, int j_data_start, struct GRDREDPOL_CTRL *Ctrl) {
 	/* This routine mirrors or replicates the West and East borders j_data_start times
 	   and the South and North borders by i_data_start times.
 	   nc	is the total number of columns by which the grid is extended
@@ -258,7 +258,7 @@ GMT_LOCAL void mirror_edges (gmt_grdfloat *grid, int nc, int i_data_start, int j
 	}
 }
 
-GMT_LOCAL void tfpoeq(double *w, int m, int n, double *greel, double *gim, 
+GMT_LOCAL void grdgravmag3d_tfpoeq(double *w, int m, int n, double *greel, double *gim,
 	    double *cosphi, double *sinphi, double *cospsi, double *sinpsi) {
     /* Initialized data */
 
@@ -368,11 +368,11 @@ L4:
 }
 
 
-GMT_LOCAL int igrf10syn (struct GMT_CTRL *C, int isv, double date, int itype, double alt, double elong, double lat, double *out) {
+GMT_LOCAL int grdgravmag3d_igrf10syn (struct GMT_CTRL *C, int isv, double date, int itype, double alt, double elong, double lat, double *out) {
  /*     This is a synthesis routine for the 10th generation IGRF as agreed
   *     in December 2004 by IAGA Working Group V-MOD. It is valid 1900.0 to
   *     2010.0 inclusive. Values for dates from 1945.0 to 2000.0 inclusive are
-  *     definitve, otherwise they are non-definitive.
+  *     definitive, otherwise they are non-definitive.
   *   INPUT
   *     isv   = 0 if main-field values are required
   *     isv   = 1 if secular variation values are required
@@ -407,19 +407,19 @@ GMT_LOCAL int igrf10syn (struct GMT_CTRL *C, int isv, double date, int itype, do
   *
   *	Joaquim Luis 1-MARS-2005
   *	Converted to C (with help of f2c, which explains the ugliness)
-  *     1995.0 coefficients as published in igrf9coeffs.xls and igrf10coeffs.xls 
-  *     used - (Kimmo Korhonen spotted 1 nT difference in 11 coefficients) 
-  *     Susan Macmillan July 2005 (PW update Oct 2006) 
+  *     1995.0 coefficients as published in igrf9coeffs.xls and igrf10coeffs.xls
+  *     used - (Kimmo Korhonen spotted 1 nT difference in 11 coefficients)
+  *     Susan Macmillan July 2005 (PW update Oct 2006)
   *
   *	Joaquim Luis 21-JAN-2010
   *	Updated for IGRF 11th generation
   */
 
-	struct IGRF {
+	struct GRDREDPOL_IGRF {
 		double e_1[3450];
 	};
      /* Initialized data */
-     static struct IGRF equiv_22 = {
+     static struct GRDREDPOL_IGRF equiv_22 = {
        {-31543.,-2298., 5922., -677., 2905.,-1061.,  924., 1121., /* g0 (1900) */
          1022.,-1469., -330., 1256.,    3.,  572.,  523.,  876.,
           628.,  195.,  660.,  -69., -361., -210.,  134.,  -75.,
@@ -883,12 +883,12 @@ GMT_LOCAL int igrf10syn (struct GMT_CTRL *C, int isv, double date, int itype, do
 	double rr, st, one, gmm, rho, two, three, ratio;
 	double p[105], q[105], r, t, a2, b2;
 	double H, F, X = 0, Y = 0, Z = 0, dec, dip;
-	
+
 	if (date < 1900.0 || date > 2020.0) {
-		GMT_Report (C->parent, GMT_MSG_NORMAL, "Your date (%g) is outside valid extrapolated range for IGRF (1900-2020)\n", date);
+		GMT_Report (C->parent, GMT_MSG_ERROR, "Your date (%g) is outside valid extrapolated range for IGRF (1900-2020)\n", date);
 		return (true);
 	}
-	
+
 	if (date < 2015.) {
 		t = 0.2 * (date - 1900.);
 		ll = (int) t;
@@ -1019,11 +1019,11 @@ GMT_LOCAL int igrf10syn (struct GMT_CTRL *C, int isv, double date, int itype, do
 	out[2] = X;		out[3] = Y;
 	out[4] = Z;
 	out[5] = dec;		out[6] = dip;
-	
+
 	return (GMT_NOERROR);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s <anomgrid> -G<rtp_grdfile> [-C<dec>/<dip>] [-Ei<dip_grd>] [-Ee<dec_grd>] [-F<m>/<n>]\n", name);
@@ -1031,7 +1031,7 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 				GMT_Rgeo_OPT, GMT_V_OPT, GMT_n_OPT, GMT_PAR_OPT);
 
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
-                
+
 	GMT_Message (API, GMT_TIME_NONE, "\t<anomgrid> is the input grdfile with the magnetic anomaly.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-G Sets filename for output grid with the RTP solution.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
@@ -1046,11 +1046,11 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t-W Sets window width in degrees [5].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-Z Write filter file <filterfile> to disk.\n");
 	GMT_Option  (API, "V,n,.");
-	
+
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct REDPOL_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct GRDREDPOL_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to grdredpol and sets parameters in Ctrl.
 	 * Note Ctrl has already been initialized and non-zero default values set.
 	 * Any GMT common options will override values set previously by other commands.
@@ -1106,7 +1106,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct REDPOL_CTRL *Ctrl, struct GMT_
 								Ctrl->E.dip_dec_grd = true;
 								break;
 							default:
-								GMT_Report (API, GMT_MSG_NORMAL, "Syntax error using option -E\n");
+								GMT_Report (API, GMT_MSG_ERROR, "Syntax error using option -E\n");
 								n_errors++;
 								break;
 						}
@@ -1118,19 +1118,18 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct REDPOL_CTRL *Ctrl, struct GMT_
 				j = sscanf (opt->arg, "%d/%d", &Ctrl->F.ncoef_row, &Ctrl->F.ncoef_col);
 				if (j == 1) Ctrl->F.compute_n = true;	/* Case of only one filter dimension was given */
 				if (Ctrl->F.ncoef_row %2 != 1 || Ctrl->F.ncoef_col %2 != 1) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Number of filter coefficients must be odd\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Number of filter coefficients must be odd\n");
 					n_errors++;
 				}
 				if (Ctrl->F.ncoef_row < 5 || Ctrl->F.ncoef_col < 5) {
-					GMT_Report (API, GMT_MSG_NORMAL, "That was a ridiculous number of filter coefficients\n");
+					GMT_Report (API, GMT_MSG_ERROR, "That was a ridiculous number of filter coefficients\n");
 					n_errors++;
 				}
 				break;
 			case 'G':
-				if ((Ctrl->G.active = gmt_check_filearg (GMT, 'G', opt->arg, GMT_OUT, GMT_IS_GRID)) != 0)
-					Ctrl->G.file = strdup (opt->arg);
-				else
-					n_errors++;
+				Ctrl->G.active = true;
+				if (opt->arg[0]) Ctrl->G.file = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_GRID, GMT_OUT, GMT_FILE_LOCAL, &(Ctrl->G.file))) n_errors++;
 				break;
 			case 'M':
 				Ctrl->M.pad_zero = false;
@@ -1140,7 +1139,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct REDPOL_CTRL *Ctrl, struct GMT_
 					else if (opt->arg[j] == 'r')
 						Ctrl->M.mirror = false;
 					else {
-						GMT_Report (API, GMT_MSG_NORMAL, "Error using option -M (option ignored)\n");
+						GMT_Report (API, GMT_MSG_ERROR, "Failure while using option -M (option ignored)\n");
 						Ctrl->M.pad_zero = true;
 					}
 				}
@@ -1164,11 +1163,11 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct REDPOL_CTRL *Ctrl, struct GMT_
 		}
 	}
 
-	n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Syntax error: Must specify input file\n");
-	n_errors += gmt_M_check_condition (GMT, !Ctrl->G.file, "Syntax error -G option: Must specify output file\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->In.file, "Must specify input file\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->G.file, "Option -G: Must specify output file\n");
 
-	if (Ctrl->C.const_f && Ctrl->C.use_igrf) {	
-		GMT_Report (API, GMT_MSG_NORMAL, "-E option overrides -C\n");
+	if (Ctrl->C.const_f && Ctrl->C.use_igrf) {
+		GMT_Report (API, GMT_MSG_ERROR, "-E option overrides -C\n");
 		Ctrl->C.const_f = false;
 	}
 
@@ -1178,7 +1177,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct REDPOL_CTRL *Ctrl, struct GMT_
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_grdredpol (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_grdredpol (void *V_API, int mode, void *args) {
 
 	bool wrote_one = false;
 	unsigned int i, j, row, col, nx_new, ny_new, one_or_zero, m21, n21, i2, j2;
@@ -1197,7 +1196,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 	double	dec_m, dip_m, tau1, mu1, nu1, dt = 0, dm = 0, dn = 0, tau = 0, mu = 0, nu = 0;
 	double	wesn_new[4], out_igrf[7];
 
-	struct	REDPOL_CTRL *Ctrl = NULL;
+	struct	GRDREDPOL_CTRL *Ctrl = NULL;
 	struct	GMT_GRID *Gin = NULL, *Gout = NULL, *Gdip = NULL, *Gdec = NULL, *Gfilt = NULL;
 	struct	GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct	GMT_OPTION *options = NULL;
@@ -1213,11 +1212,11 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
-	
+
 	/*--------------------------- This is the grdredpol main code --------------------------*/
 
 	if ((Gin = GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_CONTAINER_ONLY, NULL, Ctrl->In.file, NULL)) == NULL) /* Get header only */
@@ -1233,7 +1232,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 	GMT->current.io.pad[XLO] = GMT->current.io.pad[XHI] = n21-1;
 	GMT->current.io.pad[YLO] = GMT->current.io.pad[YHI] = m21-1;
 
-	if (!GMT->common.R.active[RSET]) 
+	if (!GMT->common.R.active[RSET])
 		gmt_M_memcpy (wesn_new, Gin->header->wesn, 4, double);
 	else
 		gmt_M_memcpy (wesn_new, GMT->common.R.wesn, 4, double);
@@ -1252,31 +1251,31 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 
 	if (GMT->common.R.active[RSET]) {
 		if (wesn_new[XLO] < Gin->header->wesn[XLO] || wesn_new[XHI] > Gin->header->wesn[XHI]) {
-			GMT_Report (API, GMT_MSG_NORMAL, " Selected region exceeds the X-boundaries of the grid file!\n");
+			GMT_Report (API, GMT_MSG_ERROR, " Selected region exceeds the X-boundaries of the grid file!\n");
 			return (GMT_RUNTIME_ERROR);
 		}
 		else if (wesn_new[YLO] < Gin->header->wesn[YLO] || wesn_new[YHI] > Gin->header->wesn[YHI]) {
-			GMT_Report (API, GMT_MSG_NORMAL, " Selected region exceeds the Y-boundaries of the grid file!\n");
+			GMT_Report (API, GMT_MSG_ERROR, " Selected region exceeds the Y-boundaries of the grid file!\n");
 			return (GMT_RUNTIME_ERROR);
 		}
 	}
 
 	if (!Ctrl->M.pad_zero)		/* That is, if we want edges reflected or replicated */
-		mirror_edges (Gin->data, Ctrl->F.ncoef_col-1, m21-1, n21-1, Ctrl);
+		grdgravmag3d_mirror_edges (Gin->data, Ctrl->F.ncoef_col-1, m21-1, n21-1, Ctrl);
 
 	/* Section to deal with possible external grids with dip and dec for interpolation */
 
 	if (Ctrl->E.dip_grd_only || Ctrl->E.dip_dec_grd) {
 		if ((Gdip = GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_CONTAINER_ONLY, NULL, Ctrl->E.dipfile, NULL)) == NULL)	/* Get header only */
 			Return (API->error);
-	
+
 		if (GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_DATA_ONLY, wesn_new, Ctrl->E.dipfile, Gdip) == NULL)
 			Return (API->error);
 	}
 	if (Ctrl->E.dip_dec_grd) {
 		if ((Gdec = GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_CONTAINER_ONLY, NULL, Ctrl->E.decfile, NULL)) == NULL)
 			Return (API->error);
-	
+
 		if (GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_DATA_ONLY, wesn_new, Ctrl->E.decfile, Gdec) == NULL)
 			Return (API->error);
 	}
@@ -1302,7 +1301,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 	ftlon  = gmt_M_memory (GMT, NULL, Gin->header->n_columns, double);
 	ftlat  = gmt_M_memory (GMT, NULL, Gin->header->n_rows, double);
 
-	if ((Ctrl->E.dip_grd_only || Ctrl->E.dip_dec_grd)) { 
+	if ((Ctrl->E.dip_grd_only || Ctrl->E.dip_dec_grd)) {
 		gxtr = gmt_M_memory (GMT, NULL, n_coef, double);
 		gxti = gmt_M_memory (GMT, NULL, n_coef, double);
 		gxmr = gmt_M_memory (GMT, NULL, n_coef, double);
@@ -1326,19 +1325,19 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 		beta =  cos(Ctrl->C.dip) * sin(Ctrl->C.dec);
 		gama = -sin(Ctrl->C.dip);
 	}
-	
+
 	fi  = TWO_PI / Ctrl->F.ncoef_row;
 	psi = TWO_PI / Ctrl->F.ncoef_col;
 
 	if ((Gout = GMT_Create_Data (API, GMT_IS_GRID, GMT_IS_SURFACE, GMT_CONTAINER_AND_DATA, NULL, wesn_new, Gin->header->inc, \
 	                             Gin->header->registration, GMT_NOTSET, NULL)) == NULL) Return (API->error);
-					
+
 	if (Ctrl->Z.active) {		/* Create one grid to hold the filter coefficients */
 		double wesn[4], inc[2];
 		wesn[XLO] = 1;	wesn[XHI] = (double)Ctrl->F.ncoef_col;
 		wesn[YLO] = 1;	wesn[YHI] = (double)Ctrl->F.ncoef_row;
 		inc[GMT_X] = inc[GMT_Y] = 1;
-		
+
 		if ((Gfilt = GMT_Create_Data (API, GMT_IS_GRID, GMT_IS_SURFACE, GMT_CONTAINER_AND_DATA, NULL, wesn, inc,
 		                              GMT_GRID_PIXEL_REG, 0, NULL)) == NULL) Return (API->error);
 		strcpy (Gfilt->header->title, "Reduction To the Pole filter");
@@ -1348,8 +1347,8 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 
 	for (l = 0; l < n_jlat; l++) {		/* Main loop over the moving windows */
 		for (k = 0; k < n_jlon; k++) {
-			sloni = Gin->header->wesn[XLO] + k * Ctrl->W.wid; 
-			slati = Gin->header->wesn[YHI] - (l+1) * Ctrl->W.wid; 
+			sloni = Gin->header->wesn[XLO] + k * Ctrl->W.wid;
+			slati = Gin->header->wesn[YHI] - (l+1) * Ctrl->W.wid;
 			slonf = sloni + Ctrl->W.wid;
 			slatf = slati + Ctrl->W.wid;
 			slonm = (sloni + slonf) / 2;
@@ -1362,7 +1361,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 				n21 = (Ctrl->F.ncoef_row+1) / 2;
 			}
 			/* Compute dec and dip at the central point of the moving window */
-			igrf10syn(GMT, 0, Ctrl->T.year, 1, 0, slonm, slatm, out_igrf); 
+			grdgravmag3d_igrf10syn(GMT, 0, Ctrl->T.year, 1, 0, slonm, slatm, out_igrf);
 			if (!Ctrl->C.const_f) {
 				Ctrl->C.dec = out_igrf[5] * D2R;
 				Ctrl->C.dip = out_igrf[6] * D2R;
@@ -1386,8 +1385,8 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 					nu  = -sin(dip_m);
 				}
 			}
-			if (gmt_M_is_verbose (GMT, GMT_MSG_LONG_VERBOSE))
-				GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Dec %5.1f  Dip %5.1f  Bin_lon %6.1f  Bin_lat %5.1f\r", 
+			if (gmt_M_is_verbose (GMT, GMT_MSG_INFORMATION))
+				GMT_Report (API, GMT_MSG_INFORMATION, "Dec %5.1f  Dip %5.1f  Bin_lon %6.1f  Bin_lat %5.1f\r",
 					    Ctrl->C.dec/D2R, Ctrl->C.dip/D2R, slonm, slatm);
 
 			/* Compute the filter coefficients in the frequency domain */
@@ -1398,33 +1397,33 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 					u = r * fi;		v = s * psi;
 
 					if (!(Ctrl->E.dip_grd_only || Ctrl->E.dip_dec_grd)) {
-						rtp_filt_colinear(i,j,n21,gxr,gxi,gxar,gxai,gxbr,gxbi,gxgr,gxgi,
+						grdgravmag3d_rtp_filt_colinear(i,j,n21,gxr,gxi,gxar,gxai,gxbr,gxbi,gxgr,gxgi,
 						                  u,v,alfa,beta,gama, Ctrl);
 					}
 					else {		/* Case more general. alfa, beta, gama, tau, mu e nu */
-						rtp_filt_NOTcolinear(i,j,n21,gxr,gxi,gxar,gxai,gxbr,gxbi,gxgr,gxgi,gxtr,gxti,
+						grdgravmag3d_rtp_filt_not_colinear(i,j,n21,gxr,gxi,gxar,gxai,gxbr,gxbi,gxgr,gxgi,gxtr,gxti,
 						                     gxmr,gxmi,gxnr,gxni,u,v,alfa,beta,gama,tau,mu,nu, Ctrl);
 					}
 				}
 			}
-			gxr[ij_mn(Ctrl,m21-1,0)]  = 1;	gxi[ij_mn(Ctrl,m21-1,0)]  = 0; 
-			gxar[ij_mn(Ctrl,m21-1,0)] = 0;	gxai[ij_mn(Ctrl,m21-1,0)] = 0; 
-			gxbr[ij_mn(Ctrl,m21-1,0)] = 0;	gxbi[ij_mn(Ctrl,m21-1,0)] = 0; 
-			gxgr[ij_mn(Ctrl,m21-1,0)] = 0;	gxgi[ij_mn(Ctrl,m21-1,0)] = 0; 
+			gxr[ij_mn(Ctrl,m21-1,0)]  = 1;	gxi[ij_mn(Ctrl,m21-1,0)]  = 0;
+			gxar[ij_mn(Ctrl,m21-1,0)] = 0;	gxai[ij_mn(Ctrl,m21-1,0)] = 0;
+			gxbr[ij_mn(Ctrl,m21-1,0)] = 0;	gxbi[ij_mn(Ctrl,m21-1,0)] = 0;
+			gxgr[ij_mn(Ctrl,m21-1,0)] = 0;	gxgi[ij_mn(Ctrl,m21-1,0)] = 0;
 
 			/* Compute iFT of the filter */
-			tfpoeq(fxr, Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxr,gxi,   cosphi,sinphi,cospsi,sinpsi); 
-			tfpoeq(fxar,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxar,gxai, cosphi,sinphi,cospsi,sinpsi); 
-			tfpoeq(fxbr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxbr,gxbi, cosphi,sinphi,cospsi,sinpsi); 
-			tfpoeq(fxgr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxgr,gxgi, cosphi,sinphi,cospsi,sinpsi); 
+			grdgravmag3d_tfpoeq(fxr, Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxr,gxi,   cosphi,sinphi,cospsi,sinpsi);
+			grdgravmag3d_tfpoeq(fxar,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxar,gxai, cosphi,sinphi,cospsi,sinpsi);
+			grdgravmag3d_tfpoeq(fxbr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxbr,gxbi, cosphi,sinphi,cospsi,sinpsi);
+			grdgravmag3d_tfpoeq(fxgr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxgr,gxgi, cosphi,sinphi,cospsi,sinpsi);
 
-			if ((Ctrl->E.dip_grd_only || Ctrl->E.dip_dec_grd)) { 
-				gxtr[ij_mn(Ctrl,m21-1,0)] = 0;	gxti[ij_mn(Ctrl,m21-1,0)] = 0; 
-				gxmr[ij_mn(Ctrl,m21-1,0)] = 0;	gxmi[ij_mn(Ctrl,m21-1,0)] = 0; 
+			if ((Ctrl->E.dip_grd_only || Ctrl->E.dip_dec_grd)) {
+				gxtr[ij_mn(Ctrl,m21-1,0)] = 0;	gxti[ij_mn(Ctrl,m21-1,0)] = 0;
+				gxmr[ij_mn(Ctrl,m21-1,0)] = 0;	gxmi[ij_mn(Ctrl,m21-1,0)] = 0;
 				gxnr[ij_mn(Ctrl,m21-1,0)] = 0;	gxni[ij_mn(Ctrl,m21-1,0)] = 0;
-				tfpoeq(fxtr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxtr,gxti, cosphi,sinphi,cospsi,sinpsi); 
-				tfpoeq(fxmr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxmr,gxmi, cosphi,sinphi,cospsi,sinpsi); 
-				tfpoeq(fxnr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxnr,gxni, cosphi,sinphi,cospsi,sinpsi);
+				grdgravmag3d_tfpoeq(fxtr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxtr,gxti, cosphi,sinphi,cospsi,sinpsi);
+				grdgravmag3d_tfpoeq(fxmr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxmr,gxmi, cosphi,sinphi,cospsi,sinpsi);
+				grdgravmag3d_tfpoeq(fxnr,Ctrl->F.ncoef_row, Ctrl->F.ncoef_col,gxnr,gxni, cosphi,sinphi,cospsi,sinpsi);
 			}
 
 			/* Convolve filter with input data that is inside current window (plus what filter width imposes) */
@@ -1434,7 +1433,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 					if (ftlon[col] < sloni || ftlon[col] > slonf) continue;	/* Current point outside WOI */
 					/* Compute dec and dip at current point */
 					if (!Ctrl->C.const_f) {		/* It means we need to get F (& M) vector parameters */
-						igrf10syn(GMT, 0, Ctrl->T.year, 1, 0, ftlon[col], ftlat[row], out_igrf); 
+						grdgravmag3d_igrf10syn(GMT, 0, Ctrl->T.year, 1, 0, ftlon[col], ftlat[row], out_igrf);
 						Ctrl->C.dec = out_igrf[5] * D2R;
 						Ctrl->C.dip = out_igrf[6] * D2R;
 						if (Ctrl->E.dip_grd_only) {
@@ -1463,7 +1462,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 
 					/* Rebuild the filter */
 					if (!Ctrl->C.const_f) {
-						if (Ctrl->C.use_igrf) { 
+						if (Ctrl->C.use_igrf) {
 							for (i2 = 0; i2 < n_coef; i2++)
 								fix[i2] = fxr[i2] + da * fxar[i2] + db * fxbr[i2] + dg * fxgr[i2];
 						}
@@ -1497,7 +1496,7 @@ int GMT_grdredpol (void *V_API, int mode, void *args) {
 		}
 	}
 
-	if (gmt_M_is_verbose (GMT, GMT_MSG_LONG_VERBOSE)) GMT_Report (API, GMT_MSG_LONG_VERBOSE, "\n"); 
+	if (gmt_M_is_verbose (GMT, GMT_MSG_INFORMATION)) GMT_Report (API, GMT_MSG_LONG_VERBOSE, "\n");
 
 	gmt_M_free (GMT, cosphi);      gmt_M_free (GMT, sinphi);
 	gmt_M_free (GMT, cospsi);      gmt_M_free (GMT, sinpsi);
