@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -65,34 +65,34 @@ FILE *fp = NULL;
 #endif
 
 struct TALWANI3D_CTRL {
-	struct A {	/* -A Set positive up  */
+	struct TALWANI3D_A {	/* -A Set positive up  */
 		bool active;
 	} A;
-	struct D {	/* -D<rho> fixed density to override model files */
+	struct TALWANI3D_D {	/* -D<rho> fixed density to override model files */
 		bool active;
 		double rho;
 	} D;
-	struct F {	/* -F[f|n[<lat>]|v] */
+	struct TALWANI3D_F {	/* -F[f|n[<lat>]|v] */
 		bool active, lset;
 		unsigned int mode;
 		double lat;
 	} F;
-	struct G {	/* Output file */
+	struct TALWANI3D_G {	/* Output file */
 		bool active;
 		char *file;
 	} G;
-	struct I {	/* -Idx[/dy] */
+	struct TALWANI3D_I {	/* -Idx[/dy] */
 		bool active;
 		double inc[2];
 	} I;
-	struct M {	/* -Mh|z  */
+	struct TALWANI3D_M {	/* -Mh|z  */
 		bool active[2];	/* True if km, else m */
 	} M;
-	struct N {	/* Desired output points */
+	struct TALWANI3D_N {	/* Desired output points */
 		bool active;
 		char *file;
 	} N;
-	struct Z {	/* Observation level file or constant */
+	struct TALWANI3D_Z {	/* Observation level file or constant */
 		bool active;
 		double level;
 		unsigned int mode;
@@ -100,15 +100,15 @@ struct TALWANI3D_CTRL {
 	} Z;
 };
 
-struct SLICE {	/* Holds a single contour slice and its density, plus link to next slice at the same depth */
-	struct SLICE *next;
+struct TALWANI3D_SLICE {	/* Holds a single contour slice and its density, plus link to next slice at the same depth */
+	struct TALWANI3D_SLICE *next;
 	int n;
 	double rho;
 	double *x, *y;
 };
 
-struct CAKE {	/* Holds linked list of slices for same depth */
-	struct SLICE *first_slice;
+struct TALWANI3D_CAKE {	/* Holds linked list of slices for same depth */
+	struct TALWANI3D_SLICE *first_slice;
 	double depth;
 };
 
@@ -120,11 +120,11 @@ enum Talwani3d_fields {
 	TALWANI3D_VER=1
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct TALWANI3D_CTRL *C = NULL;
-	
+
 	C = gmt_M_memory (GMT, NULL, 1, struct TALWANI3D_CTRL);
-	
+
 	/* Initialize values whose defaults are not 0/false/NULL */
 
 	C->F.lat = 45.0;	/* So we compute normal gravity at 45 */
@@ -132,15 +132,15 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	gmt_M_str_free (C->N.file);	
-	gmt_M_str_free (C->G.file);	
-	gmt_M_str_free (C->Z.file);	
-	gmt_M_free (GMT, C);	
+	gmt_M_str_free (C->N.file);
+	gmt_M_str_free (C->G.file);
+	gmt_M_str_free (C->Z.file);
+	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *Ctrl, struct GMT_OPTION *options) {
 	unsigned int k, n_errors = 0;
 	struct GMT_OPTION *opt = NULL;
 
@@ -148,7 +148,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *Ctrl, struct G
 		switch (opt->option) {
 
 			case '<':	/* Input file(s) */
-				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_DATASET, GMT_IN, GMT_FILE_REMOTE, &(opt->arg))) n_errors++;;
 				break;
 
 			case 'A':	/* Specify z-axis is positive up [Default is down] */
@@ -166,8 +166,8 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *Ctrl, struct G
 						if (opt->arg[1]) Ctrl->F.lat = atof (&opt->arg[1]), Ctrl->F.lset = true;
 						break;
 					case 'g':  Ctrl->F.mode = TALWANI3D_FAA; 	break;
-					default:  
-						GMT_Report (GMT->parent, GMT_MSG_VERBOSE, "Syntax error -F: Unrecognized field %c\n", opt->arg[0]);
+					default:
+						GMT_Report (GMT->parent, GMT_MSG_WARNING, "Option -F: Unrecognized field %c\n", opt->arg[0]);
 						n_errors++;
 						break;
 				}
@@ -187,7 +187,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *Ctrl, struct G
 						case 'z': Ctrl->M.active[TALWANI3D_VER] = true; break;
 						default:
 							n_errors++;
-							GMT_Report (GMT->parent, GMT_MSG_VERBOSE, "Syntax error -M: Unrecognized modifier %c\n", opt->arg[k]);
+							GMT_Report (GMT->parent, GMT_MSG_WARNING, "Option -M: Unrecognized modifier %c\n", opt->arg[k]);
 							break;
 					}
 					k++;
@@ -215,21 +215,21 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct TALWANI3D_CTRL *Ctrl, struct G
 	}
 	if (GMT->common.R.active[RSET]) {
 		n_errors += gmt_M_check_condition (GMT, !GMT->common.R.active[ISET],
-		                                 "Syntax error -R option: Must specify both -R and -I (and optionally -r)\n");
+		                                 "Option -R: Must specify both -R and -I (and optionally -r)\n");
 	}
 	n_errors += gmt_M_check_condition (GMT, (GMT->common.R.active[RSET] && GMT->common.R.active[ISET]) && Ctrl->Z.mode == 1,
-	                                 "Syntax error -Z option: Cannot also specify -R -I\n");
+	                                 "Option -Z: Cannot also specify -R -I\n");
 	n_errors += gmt_M_check_condition (GMT, !Ctrl->N.active && !Ctrl->G.active,
-	                                 "Syntax error -G option: Must specify output gridfile name.\n");
+	                                 "Option -G: Must specify output gridfile name.\n");
 	n_errors += gmt_M_check_condition (GMT, Ctrl->G.active && !Ctrl->G.file,
-	                                 "Syntax error -G option: Must specify output gridfile name.\n");
+	                                 "Option -G: Must specify output gridfile name.\n");
 	n_errors += gmt_M_check_condition (GMT, Ctrl->N.active && !Ctrl->N.file,
-	                                 "Syntax error -N option: Must specify output gridfile name.\n");
+	                                 "Option -N: Must specify output gridfile name.\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s <modelfile> [-A] [-D<rho>] [-Ff|n[<lat>]|v] [-G<outfile>] [%s]\n", name, GMT_I_OPT);
@@ -267,19 +267,19 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 
 #define INV_3 (1.0/3.0)
 
-GMT_LOCAL double parint (double x[], double y[], int n) {
-	/* parint is a piecewise parabolic integrator
+GMT_LOCAL double talwani3d_parint (double x[], double y[], int n) {
+	/* talwani3d_parint is a piecewise parabolic integrator
 	 *
 	 * Arguments:
 	 *       x and y are arrays of size n   (sent)
 	 *       area is area under y = f(x) from x(1) to x(n) (returned)
 	 *
 	 * Method:
-	 *       We approximate y = f(x) by a seies of parabolas, each 
+	 *       We approximate y = f(x) by a seies of parabolas, each
 	 *       an exact fit to three points, at x(i-1), x(i), x(i+1).
 	 *       The area under this curve in the region about x(i) is
 	 *       summed as we increment i.  The region about x(i) is
-	 *       defined as extending from x1 to x2, where 
+	 *       defined as extending from x1 to x2, where
 	 *         x1 = (x(i-1) + x(i)) / 2
 	 *         x2 = (x(i) + x(i+1)) / 2
 	 *       and the area piece at i is the area under the parabola
@@ -301,16 +301,16 @@ GMT_LOCAL double parint (double x[], double y[], int n) {
 	 * the code below is faithful to the sign of y and the order of x
 	 * as written, so if the user desires that area should have same
 	 * sign as y, regardless of order of x, then user should test x in
-	 * calling program and adjust sign of area accordingly.	
+	 * calling program and adjust sign of area accordingly.
 	 *
 	 * If n == 2 then a simple trapezoidal integration is returned.
 	 */
 
 	int i, ip1, im1;
 	double c2top, c2bot, c2, c1, c0, x1, x2, x1_2, x2_2, area;
-	 
+
 	if (n == 2) return (0.5 * (x[1] - x[0]) * (y[0] + y[1])); /* Linear integration */
-	 	
+
 	area = 0.0;
 	for (i = 1; i < n-1; i++) {
 		im1 = i - 1;	ip1 = i + 1;
@@ -330,13 +330,13 @@ GMT_LOCAL double parint (double x[], double y[], int n) {
 	return (area);
 }
 
-GMT_LOCAL double get_grav3d (double x[], double y[], int n, double x_obs, double y_obs, double z_obs, double rho, bool flat) {
+GMT_LOCAL double talwani3d_get_grav3d (double x[], double y[], int n, double x_obs, double y_obs, double z_obs, double rho, bool flat) {
 	/* Talwani et al., 1959 */
 	int k;
 	double gsum = 0.0, x1, x2, y1, y2, r1, r2, ir1, ir2, xr1 = 0.0, yr1 = 0.0, side, iside;
 	double xr2 = 0.0, yr2 = 0.0, dx, dy, p, em, sign2, wsign, value, part1 = 0.0, part2 = 0.0, part3 = 0.0, q, f, psi;
 	bool zerog;
-	
+
 	/* Get x- and y-distances of first point relative to observation point */
 	if (flat) {	/* Got lon, lat and must convert to Flat-Earth km */
 		x1 = DX_FROM_DLON (x[0], x_obs, y[0], y_obs);
@@ -352,9 +352,9 @@ GMT_LOCAL double get_grav3d (double x[], double y[], int n, double x_obs, double
 		xr1 = x1 * ir1;
 		yr1 = y1 * ir1;
 	}
-				
+
 	for (k = 1; k < n; k++) {	/* Loop over vertices */
-		/* Get coordinates of next vectex */	
+		/* Get coordinates of next vectex */
 		if (flat) {
 			x2 = DX_FROM_DLON (x[k], x_obs, y[k], y_obs);
 			y2 = DY_FROM_DLAT (y[k], y_obs);
@@ -403,33 +403,33 @@ GMT_LOCAL double get_grav3d (double x[], double y[], int n, double x_obs, double
 				}
 			}
 		}
-					
+
 		if (!zerog) gsum += part1 - part2 + part3;
-					
+
 		/* Move this vertex to last vertex */
-					
+
 		x1 = x2;
 		y1 = y2;
 		r1 = r2;
 		xr1 = xr2;
 		yr1 = yr2;
 	}
-				
+
 	/* If z axis is positive down, then gsum should have the same sign as z. */
-				 
+
 	gsum = (z_obs > 0.0) ? fabs (gsum) : -fabs (gsum);
-				
+
 	return (GAMMA * rho * gsum);	/* Return contribution in mGal */
 }
 
-GMT_LOCAL double get_vgg3d (double x[], double y[], int n, double x_obs, double y_obs, double z_obs, double rho, bool flat) {
+GMT_LOCAL double talwani3d_get_vgg3d (double x[], double y[], int n, double x_obs, double y_obs, double z_obs, double rho, bool flat) {
 	/* Kim & Wessel, 2016 */
 	int k;
 	double vsum = 0.0, x1, x2, y1, y2, r1, r2, ir1, ir2, xr1 = 0.0, yr1 = 0.0, side, iside;
 	double xr2 = 0.0, yr2 = 0.0, dx, dy, p, em, sign2, part2 = 0.0, part3 = 0.0, q, f, z2, p2;
 	double scl, cos_theta_i, sin_theta2_i, cos_phi_i, sin_phi2_i, area = 0.0;
 	bool zerog;
-	
+
 	/* Get x- and y-distances relative to observation point */
 	if (flat) {	/* Got lon, lat and must convert to Flat-Earth km */
 		x1 = DX_FROM_DLON (x[0], x_obs, y[0], y_obs);
@@ -445,7 +445,7 @@ GMT_LOCAL double get_vgg3d (double x[], double y[], int n, double x_obs, double
 		xr1 = x1 * ir1;
 		yr1 = y1 * ir1;
 	}
-    
+
 	for (k = 1; k < n; k++) {	/* Loop over vertices */
         	/* Get coordinates to the next vertex */
 		if (flat) {
@@ -496,11 +496,11 @@ GMT_LOCAL double get_vgg3d (double x[], double y[], int n, double x_obs, double
 				}
 			}
 		}
-        
+
 		if (!zerog) vsum += -part2 + part3;
-        
+
 		/* Move this vertex to last vertex : */
-        
+
 		x1 = x2;
 		y1 = y2;
 		r1 = r2;
@@ -511,7 +511,7 @@ GMT_LOCAL double get_vgg3d (double x[], double y[], int n, double x_obs, double
 	return (10 * GAMMA * rho * vsum);	/* To get Eotvos = 0.1 mGal/km */
 }
 
-GMT_LOCAL double definite_integral (double a, double s, double c) {
+GMT_LOCAL double talwani3d_definite_integral (double a, double s, double c) {
 	/* Return out definite integral n_ij (except the factor z_j) */
 	/* Here, 0 <= a <= TWO_I and c >= 0 */
 	double s2, c2, u2, k, k2, q, q2, f, v, n_ij, arg1, arg2, y;
@@ -538,16 +538,16 @@ GMT_LOCAL double definite_integral (double a, double s, double c) {
 #endif
 	if (a > M_PI_2) n_ij = -n_ij;
 	if (gmt_M_is_dnan (n_ij))
-		fprintf (stderr, "definite_integral returns n_ij = NaN!\n");
+		fprintf (stderr, "talwani3d_definite_integral returns n_ij = NaN!\n");
 	return (n_ij);
 }
 
-GMT_LOCAL double integral (double a, double sa, double b, double sb, double c) {
+GMT_LOCAL double talwani3d_integral (double a, double sa, double b, double sb, double c) {
 	/* Return integral of geoid function from a to b */
-	return (definite_integral (b, sb, c) - definite_integral (a, sa, c));
+	return (talwani3d_definite_integral (b, sb, c) - talwani3d_definite_integral (a, sa, c));
 }
 
-GMT_LOCAL double get_geoid3d (double x[], double y[], int n, double x_obs, double y_obs, double z_obs, double rho, bool flat, double G0) {
+GMT_LOCAL double talwani3d_get_geoid3d (double x[], double y[], int n, double x_obs, double y_obs, double z_obs, double rho, bool flat, double G0) {
 	/* Kim & Wessel, 2016 */
 	int k;
 	double nsum = 0.0, x1, x2, y1, y2, r1, r2, ir1, ir2, xr1 = 0.0, yr1 = 0.0, side, iside, c, z_j = z_obs;
@@ -611,7 +611,7 @@ GMT_LOCAL double get_geoid3d (double x[], double y[], int n, double x_obs, doubl
 						s_th = p_i / r2;
 						del_alpha = theta_i - fi_i;
 						c = z_j / fabs (p_i);
-						part1 = integral (fi_i, s_fi, theta_i, s_th, c);
+						part1 = talwani3d_integral (fi_i, s_fi, theta_i, s_th, c);
 						part2 = z_j * (part1 - del_alpha);
 #if 0
 						if (dump) fprintf (stderr, "I(%g, %g, %g) = %g [z = %g p_i = %g, da = %g dx = %g dy = %g]\n", R2D*(fi_i), R2D*(theta_i), c, part2, z_j, p_i, del_alpha, dx, dy);
@@ -621,9 +621,9 @@ GMT_LOCAL double get_geoid3d (double x[], double y[], int n, double x_obs, doubl
 			}
 		}
 		if (!zerog) nsum += part2;
-					
+
 		/* Move this vertex to last vertex */
-					
+
 		x1 = x2;
 		y1 = y2;
 		r1 = r2;
@@ -631,18 +631,18 @@ GMT_LOCAL double get_geoid3d (double x[], double y[], int n, double x_obs, doubl
 		yr1 = yr2;
 	}
 	/* If z axis is positive down, then nsum should have the same sign as z */
-				 
+
 	nsum = (z_j > 0.0) ? fabs (nsum) : -fabs (nsum);
 
 	return (1.0e-2 * GAMMA * rho * nsum / G0);	/* To get geoid in meter */
 }
 
-GMT_LOCAL double get_one_output3D (double x_obs, double y_obs, double z_obs, struct CAKE *cake, double depths[], unsigned int ndepths, unsigned int mode, bool flat_earth, double G0) {
+GMT_LOCAL double talwani3d_get_one_output (double x_obs, double y_obs, double z_obs, struct TALWANI3D_CAKE *cake, double depths[], unsigned int ndepths, unsigned int mode, bool flat_earth, double G0) {
 	/* Evaluate output at a single observation point (x,y,z) */
 	/* Work array vtry must have at least of length ndepths */
 	unsigned int k;
 	double z;
-	struct SLICE *sl = NULL;
+	struct TALWANI3D_SLICE *sl = NULL;
 	double vtry[GMT_TALWANI3D_N_DEPTHS];	/* Allocate on stack since trouble with OpenMP otherwise */
 #if 0
 	/* Debug stuff that will eventually go away after more testing */
@@ -669,19 +669,19 @@ GMT_LOCAL double get_one_output3D (double x_obs, double y_obs, double z_obs, str
 		z = cake[k].depth - z_obs;	/* Vertical distance from observation point to this slice */
 		for (sl = cake[k].first_slice; sl; sl = sl->next) {	/* Loop over slices */
 			if (mode == TALWANI3D_FAA) /* FAA */
-				vtry[k] += get_grav3d  (sl->x, sl->y, sl->n, x_obs, y_obs, z, sl->rho, flat_earth);
+				vtry[k] += talwani3d_get_grav3d  (sl->x, sl->y, sl->n, x_obs, y_obs, z, sl->rho, flat_earth);
 			else if (mode == TALWANI3D_GEOID) /* GEOID */
-				vtry[k] += get_geoid3d (sl->x, sl->y, sl->n, x_obs, y_obs, z, sl->rho, flat_earth, G0);
+				vtry[k] += talwani3d_get_geoid3d (sl->x, sl->y, sl->n, x_obs, y_obs, z, sl->rho, flat_earth, G0);
 			else /* VGG */
-				vtry[k] += get_vgg3d   (sl->x, sl->y, sl->n, x_obs, y_obs, z, sl->rho, flat_earth);
+				vtry[k] += talwani3d_get_vgg3d   (sl->x, sl->y, sl->n, x_obs, y_obs, z, sl->rho, flat_earth);
 		}
 	}
-	return (parint (depths, vtry, ndepths));	/* Use parabolic integrator and return value */
+	return (talwani3d_parint (depths, vtry, ndepths));	/* Use parabolic integrator and return value */
 }
 
-GMT_LOCAL int comp_cakes (const void *cake_a, const void *cake_b) {
+GMT_LOCAL int talwani3d_comp_cakes (const void *cake_a, const void *cake_b) {
 	/* Used in the sorting of layers on depths */
-	const struct CAKE *a = cake_a, *b = cake_b;
+	const struct TALWANI3D_CAKE *a = cake_a, *b = cake_b;
 	if (a->depth < b->depth) return (-1);
 	if (a->depth > b->depth) return (+1);
 	return (0);
@@ -690,20 +690,20 @@ GMT_LOCAL int comp_cakes (const void *cake_a, const void *cake_b) {
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_talwani3d (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_talwani3d (void *V_API, int mode, void *args) {
 	int error = 0, ns;
 	unsigned int k, tbl, seg, ndepths = 0, n = 0, dup_node = 0, n_duplicate = 0;
 	uint64_t node;
 	size_t n_alloc = 0, n_alloc1 = 0;
-	
+
 	bool flat_earth = false, first_slice = true;
-	
+
 	char *uname[2] = {"meter", "km"}, *kind[3] = {"FAA", "VGG", "GEOID"}, remark[GMT_LEN64] = {""};
 	double z_level, depth = 0.0, rho = 0.0, lat = 45.0, G0;
 	double *x = NULL, *y = NULL, *in = NULL, *depths = NULL;
-					
-	struct SLICE *sl = NULL, *slnext = NULL;
-	struct CAKE *cake = NULL;
+
+	struct TALWANI3D_SLICE *sl = NULL, *slnext = NULL;
+	struct TALWANI3D_CAKE *cake = NULL;
 	struct TALWANI3D_CTRL *Ctrl = NULL;
 	struct GMT_GRID *G = NULL;
 	struct GMT_DATASET *D = NULL;
@@ -724,13 +724,13 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the talwani3d main code ----------------------------*/
-	
+
 	gmt_enable_threads (GMT);	/* Set number of active threads, if supported */
 	/* Specify input expected columns to be at least 2 */
 	if ((error = GMT_Set_Columns (API, GMT_IN, 2, GMT_COL_FIX_NO_TEXT)) != GMT_NOERROR) {
@@ -757,34 +757,34 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 		if (gmt_M_is_geographic (GMT, GMT_IN)) lat = 0.5 * (G->header->wesn[YLO] + G->header->wesn[YHI]);
 	}
 	else {	/* Got a dataset with output locations via -N */
-		gmt_disable_bhi_opts (GMT);	/* Do not want any -b -h -i to affect the reading from the -N file */
+		gmt_disable_bghi_opts (GMT);	/* Do not want any -b -g -h -i to affect the reading from the -N file */
 		if ((D = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_POINT, GMT_READ_NORMAL, NULL, Ctrl->N.file, NULL)) == NULL)
 			Return (API->error);
 		if (D->n_columns < 2) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->N.file, (int)D->n_columns);
+			GMT_Report (API, GMT_MSG_ERROR, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->N.file, (int)D->n_columns);
 			Return (GMT_DIM_TOO_SMALL);
 		}
-		gmt_reenable_bhi_opts (GMT);	/* Recover settings provided by user (if -b -h -i were used at all) */
+		gmt_reenable_bghi_opts (GMT);	/* Recover settings provided by user (if -b -g -h -i were used at all) */
 		if (gmt_M_is_geographic (GMT, GMT_IN)) lat = 0.5 * (D->min[GMT_Y] + D->max[GMT_Y]);
 	}
-	
+
 	flat_earth = gmt_M_is_geographic (GMT, GMT_IN);		/* If true then input is in degrees and we must convert to km later on */
-	
+
 	if (flat_earth && Ctrl->M.active[TALWANI3D_HOR]) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Error -M: Cannot specify both geographic coordinates (degrees) AND -Mh\n");
+		GMT_Report (API, GMT_MSG_ERROR, "Option -M: Cannot specify both geographic coordinates (degrees) AND -Mh\n");
 		Return (GMT_RUNTIME_ERROR);
 	}
-	
+
 	if (Ctrl->A.active) Ctrl->Z.level = -Ctrl->Z.level;
-	
+
 	/* Read polygon information from multiple segment file */
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "All x/y-values are assumed to be given in %s\n", uname[Ctrl->M.active[TALWANI3D_HOR]]);
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "All z-values are assumed to be given in %s\n",   uname[Ctrl->M.active[TALWANI3D_VER]]);
-	
+	GMT_Report (API, GMT_MSG_INFORMATION, "All x/y-values are assumed to be given in %s\n", uname[Ctrl->M.active[TALWANI3D_HOR]]);
+	GMT_Report (API, GMT_MSG_INFORMATION, "All z-values are assumed to be given in %s\n",   uname[Ctrl->M.active[TALWANI3D_VER]]);
+
 	/* Set up cake slice array and pointers */
-	
+
 	n_alloc1 = GMT_CHUNK;
-	cake = gmt_M_memory (GMT, NULL, n_alloc1, struct CAKE);
+	cake = gmt_M_memory (GMT, NULL, n_alloc1, struct TALWANI3D_CAKE);
 
 	/* Read the sliced model */
 	do {	/* Keep returning records until we reach EOF */
@@ -811,10 +811,10 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 					if (k == ndepths) {	/* New depth, must allocate another cake */
 						if (ndepths == n_alloc1) {
 							n_alloc1 <<= 1;
-							cake = gmt_M_memory (GMT, cake, n_alloc1, struct CAKE);
+							cake = gmt_M_memory (GMT, cake, n_alloc1, struct TALWANI3D_CAKE);
 						}
 						cake[k].depth = depth;
-						cake[k].first_slice = gmt_M_memory (GMT, NULL, 1, struct SLICE);
+						cake[k].first_slice = gmt_M_memory (GMT, NULL, 1, struct TALWANI3D_SLICE);
 						cake[k].first_slice->rho = rho;
 						cake[k].first_slice->x = x;
 						cake[k].first_slice->y = y;
@@ -824,7 +824,7 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 					else {	/* Hook onto existing list of slices at same depth */
 						sl = cake[k].first_slice;
 						while (sl->next) sl = sl->next;	/* Get to end of the slices */
-						sl->next = gmt_M_memory (GMT, NULL, 1, struct SLICE);
+						sl->next = gmt_M_memory (GMT, NULL, 1, struct TALWANI3D_SLICE);
 						sl->next->rho = rho;
 						sl->next->x = x;
 						sl->next->y = y;
@@ -837,7 +837,7 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 				/* Process the next segment header */
 				ns = sscanf (GMT->current.io.segment_header, "%lf %lf", &depth, &rho);
 				if (ns == 1 && !Ctrl->D.active) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Neither segment header nor -D specified density - must quit\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Neither segment header nor -D specified density - must quit\n");
 					gmt_M_free (GMT, cake);
 					Return (API->error);
 				}
@@ -855,11 +855,15 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 			assert (false);						/* Should never get here */
 		}
 		if (first_slice) {	/* Did not have the required header record */
-			GMT_Report (API, GMT_MSG_NORMAL, "No segment header with depth [and optional densithy contrast] - must quit\n");
+			GMT_Report (API, GMT_MSG_ERROR, "No segment header with depth [and optional densithy contrast] - must quit\n");
 			gmt_M_free (GMT, cake);
 			Return (API->error);
 		}
-		
+		if (In->data == NULL) {
+			gmt_quit_bad_record (API, In);
+			Return (API->error);
+		}
+
 		/* Clean data record to process */
 
 		in = In->data;	/* Only need to process numerical part here */
@@ -883,40 +887,40 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 			}
 		}
 	} while (true);
-	
+
 	if (GMT_End_IO (API, GMT_IN, 0) != GMT_NOERROR) {	/* Disables further data input */
 		gmt_M_free (GMT, cake);
 		Return (API->error);
 	}
-	
+
 	if (ndepths >= GMT_TALWANI3D_N_DEPTHS) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Model cannot have more than %d depth layer\n", GMT_TALWANI3D_N_DEPTHS);
-		GMT_Report (API, GMT_MSG_NORMAL, "You must increase GMT_TALWANI3D_N_DEPTHS and recompile\n");
+		GMT_Report (API, GMT_MSG_ERROR, "Model cannot have more than %d depth layer\n", GMT_TALWANI3D_N_DEPTHS);
+		GMT_Report (API, GMT_MSG_ERROR, "You must increase GMT_TALWANI3D_N_DEPTHS and recompile\n");
 		gmt_M_free (GMT, cake);
 		Return (GMT_RUNTIME_ERROR);
 	}
 
 	/* Finish allocation and sort on layers */
-	
-	cake = gmt_M_memory (GMT, cake, ndepths, struct CAKE);
-	qsort (cake, ndepths, sizeof (struct CAKE), comp_cakes);
 
-	if (n_duplicate) GMT_Report (API, GMT_MSG_VERBOSE, "Ignored %u duplicate vertices\n", n_duplicate);
+	cake = gmt_M_memory (GMT, cake, ndepths, struct TALWANI3D_CAKE);
+	qsort (cake, ndepths, sizeof (struct TALWANI3D_CAKE), talwani3d_comp_cakes);
+
+	if (n_duplicate) GMT_Report (API, GMT_MSG_WARNING, "Ignored %u duplicate vertices\n", n_duplicate);
 
 	/* Now we can write (if -V) to the screen the user's polygon model characteristics. */
-	
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "# of depths: %d\n", ndepths);
-	if (gmt_M_is_verbose (GMT, GMT_MSG_LONG_VERBOSE)) {	/* Give a listing of layers found */
+
+	GMT_Report (API, GMT_MSG_INFORMATION, "# of depths: %d\n", ndepths);
+	if (gmt_M_is_verbose (GMT, GMT_MSG_INFORMATION)) {	/* Give a listing of layers found */
 	 	for (k = 0; k < ndepths; k++) {
 	 		for (sl = cake[k].first_slice; sl; sl = sl->next)
-				GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Depth: %lg Rho: %lg N-vertx: %4d\n",
+				GMT_Report (API, GMT_MSG_INFORMATION, "Depth: %lg Rho: %lg N-vertx: %4d\n",
 	 				cake[k].depth, sl->rho, sl->n);
 	 	}
 	}
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Start calculating %s\n", kind[Ctrl->F.mode]);
+	GMT_Report (API, GMT_MSG_INFORMATION, "Start calculating %s\n", kind[Ctrl->F.mode]);
 
 	G0 = (Ctrl->F.lset) ? g_normal (Ctrl->F.lat) : g_normal (lat);
-	/* Set up depths array needed by get_one_output3D */
+	/* Set up depths array needed by talwani3d_get_one_output */
 	depths = gmt_M_memory (GMT, NULL, ndepths, double);
 	for (k = 0; k < ndepths; k++) depths[k] = cake[k].depth;	/* Used by the parabolic integrator */
 	if (Ctrl->N.active) {	/* Single loop over specified output locations */
@@ -947,7 +951,7 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 			gmt_M_free (GMT, depths);
 			Return (API->error);
 		}
-		if (D->n_segments > 1) gmt_set_segmentheader (GMT, GMT_OUT, true);	
+		if (D->n_segments > 1) gmt_set_segmentheader (GMT, GMT_OUT, true);
 		for (tbl = 0; tbl < D->n_tables; tbl++) {
 			for (seg = 0; seg < D->table[tbl]->n_segments; seg++) {
 				int64_t row;
@@ -962,7 +966,7 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 				 * with OpenMP due to race condiations that would mess up the output order */
 				for (row = 0; row < (int64_t)S->n_rows; row++) {	/* Calculate attraction at all output locations for this segment */
 					z_level = (S->n_columns == 3 && !Ctrl->Z.active) ? S->data[GMT_Z][row] : Ctrl->Z.level;	/* Default observation z level unless provided in input file */
-					GMT->hidden.mem_coord[GMT_X][row] = get_one_output3D (S->data[GMT_X][row] * scl, S->data[GMT_Y][row] * scl, z_level, cake, depths, ndepths, Ctrl->F.mode, flat_earth, G0);
+					GMT->hidden.mem_coord[GMT_X][row] = talwani3d_get_one_output (S->data[GMT_X][row] * scl, S->data[GMT_Y][row] * scl, z_level, cake, depths, ndepths, Ctrl->F.mode, flat_earth, G0);
 				}
 				/* This loop is not under OpenMP */
 				out[GMT_Z] = Ctrl->Z.level;	/* Default observation z level unless provided in input file */
@@ -997,17 +1001,17 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 			y_obs = gmt_M_grd_row_to_y (GMT, row, G->header);
 			if (!(flat_earth || Ctrl->M.active[TALWANI3D_HOR])) y_obs /= METERS_IN_A_KM;	/* Convert to km */
 #ifndef _OPENMP
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Finished row %5d\n", row);
+			GMT_Report (API, GMT_MSG_INFORMATION, "Finished row %5d\n", row);
 #endif
 			for (col = 0; col < (int)G->header->n_columns; col++) {
 				/* Loop over cols; always save the next level before we update the array at that col */
 				node = gmt_M_ijp (G->header, row, col);
 				z_level = (Ctrl->A.active) ? -G->data[node] : G->data[node];	/* Get observation z level and possibly flip direction */
-				G->data[node] = (gmt_grdfloat) get_one_output3D (x_obs[col], y_obs, z_level, cake, depths, ndepths, Ctrl->F.mode, flat_earth, G0);
+				G->data[node] = (gmt_grdfloat) talwani3d_get_one_output (x_obs[col], y_obs, z_level, cake, depths, ndepths, Ctrl->F.mode, flat_earth, G0);
 			}
 		}
 		gmt_M_free (GMT, x_obs);
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Create %s\n", Ctrl->G.file);
+		GMT_Report (API, GMT_MSG_INFORMATION, "Create %s\n", Ctrl->G.file);
 		sprintf (remark, "Calculated 3-D %s", kind[Ctrl->F.mode]);
 		if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_REMARK, remark, G)) {
 			gmt_M_free (GMT, depths);	gmt_M_free (GMT, cake);
@@ -1022,9 +1026,9 @@ int GMT_talwani3d (void *V_API, int mode, void *args) {
 			Return (API->error);
 		}
 	}
-		
+
 	/* Clean up memory */
-	
+
 	for (k = 0; k < ndepths; k++) {	/* Wind through the depthd and free up slices */
 		sl = cake[k].first_slice;
 		slnext = cake[k].first_slice->next;
