@@ -31,7 +31,7 @@
 #define THIS_MODULE_MODERN_NAME	"basemap"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Plot base maps and frames"
-#define THIS_MODULE_KEYS	">X},>DA@AD)"
+#define THIS_MODULE_KEYS	">X},>DA"
 #define THIS_MODULE_NEEDS	"JR"
 #define THIS_MODULE_OPTIONS "->BJKOPRUVXYfptxy" GMT_OPT("EZc")
 
