@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
  *
  *    Copyright (c) 1996-2012 by G. Patau
- *    Copyright (c) 2013-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *    Copyright (c) 2013-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *    Donated to the GMT project by G. Patau upon her retirement from IGPG
  *    Distributed under the Lesser GNU Public Licence
  *    See README file for copying and redistribution conditions.
@@ -28,59 +28,58 @@
 #define THIS_MODULE_PURPOSE	"Plot polarities on the lower hemisphere of the focal sphere"
 #define THIS_MODULE_KEYS	"<D{,>X}"
 #define THIS_MODULE_NEEDS	"Jd"
-#define THIS_MODULE_OPTIONS "-:>BHJKOPRUVXYdehit" GMT_OPT("c")
+#define THIS_MODULE_OPTIONS "-:>BHJKOPRUVXYdehiqt" GMT_OPT("c")
 
 #define DEFAULT_FONTSIZE	9.0	/* In points */
+#define DEFAULT_OFFSET		3.0	/* In points */
 
 /* Control structure for pspolar */
 
 struct PSPOLAR_CTRL {
-	struct C {	/* -C */
+	struct PSPOLAR_C {	/* -C */
 		bool active;
 		double lon, lat, size;
 		struct GMT_PEN pen;
 	} C;
-	struct D {	/* -D */
+	struct PSPOLAR_D {	/* -D */
 		bool active;
 		double lon, lat;
 	} D;
- 	struct E {	/* -E<fill> */
+ 	struct PSPOLAR_E {	/* -E<fill> */
 		bool active;
-		int outline;
 		struct GMT_FILL fill;
 		struct GMT_PEN pen;
 	} E;
-	struct F {	/* -F<fill> */
+	struct PSPOLAR_F {	/* -F<fill> */
 		bool active;
 		struct GMT_FILL fill;
 		struct GMT_PEN pen;
 	} F;
- 	struct G {	/* -G<fill> */
+ 	struct PSPOLAR_G {	/* -G<fill> */
 		bool active;
 		struct GMT_FILL fill;
 		struct GMT_PEN pen;
 	} G;
-	struct M {	/* -M<scale>[+m<magnitude>] */
+	struct PSPOLAR_M {	/* -M<scale>[+m<magnitude>] */
 		bool active;
 		double ech;
 	} M;
-	struct N {	/* -N */
+	struct PSPOLAR_N {	/* -N */
 		bool active;
 	} N;
-	struct Q {	/* Repeatable: -Q<mode>[<args>] for various symbol parameters */
+	struct PSPOLAR_Q {	/* Repeatable: -Q<mode>[<args>] for various symbol parameters */
 		bool active;
 	} Q;
-	struct H2 {	/* -Qh for Hypo71 */
+	struct PSPOLAR_H2 {	/* -Qh for Hypo71 */
 		bool active;
 	} H2;
-	struct S {	/* -r<fill> */
+	struct PSPOLAR_S {	/* -S<symbol><size>[c|i|p] */
 		bool active;
 		int symbol;
-		char type;
-		double scale, size;
+		double size;
 		struct GMT_FILL fill;
 	} S;
-	struct S2 {	/* -r<fill> */
+	struct PSPOLAR_S2 {	/* -Qs<half-size>[+v<size>[+<specs>] */
 		bool active;
 		bool scolor;
 		bool vector;
@@ -93,54 +92,56 @@ struct PSPOLAR_CTRL {
 		struct GMT_FILL fill;
 		struct GMT_SYMBOL S;
 	} S2;
-	struct T {
+	struct PSPOLAR_T { /* New syntax: -T+a<angle>+j<justify>+o<dx>/<dy>+f<font> */
 		bool active;
-		double angle, fontsize;
-		int form, justify;
-		struct GMT_PEN pen;
+		double angle;
+		int justify;
+		double offset[2];
+		struct GMT_FONT font;
+		int form; /* for back-compatibility only */
  	} T;
-	struct W {	/* -W<pen> */
+	struct PSPOLAR_W {	/* -W<pen> */
 		bool active;
 		struct GMT_PEN pen;
 	} W;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct PSPOLAR_CTRL *C;
 
 	C = gmt_M_memory (GMT, NULL, 1, struct PSPOLAR_CTRL);
 
 	/* Initialize values whose defaults are not 0/false/NULL */
 
-        C->C.pen = C->E.pen = C->F.pen = C->G.pen = GMT->current.setting.map_default_pen;
+	C->C.pen = C->E.pen = C->F.pen = C->G.pen = GMT->current.setting.map_default_pen;
 
 	C->C.size = GMT_DOT_SIZE;
-	gmt_init_fill (GMT, &C->E.fill, 250.0 / 255.0, 250.0 / 255.0, 250.0 / 255.0);
+	gmt_init_fill (GMT, &C->E.fill, gmt_M_is255(250), gmt_M_is255(250), gmt_M_is255(250));
 	gmt_init_fill (GMT, &C->F.fill, -1.0, -1.0, -1.0);
 	gmt_init_fill (GMT, &C->G.fill, 0.0, 0.0, 0.0);
 	gmt_init_fill (GMT, &C->S2.fill, -1.0, -1.0, -1.0);
-	C->T.justify = 5;
-	C->T.fontsize = 12.0;
+	C->T.justify = PSL_TC;
+	C->T.font.size = 12.0;
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	/* This displays the pspolar synopsis and optionally full usage information */
 
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s [<table>] %s %s -D<lon>/<lat>\n", name, GMT_J_OPT, GMT_Rgeo_OPT);
-	GMT_Message (API, GMT_TIME_NONE, "\t-M<size>[c|i|p][+m<mag>] -S<symbol><size>[c|i|p] [-A] [%s]\n", GMT_B_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t-M<size>[c|i|p][+m<mag>] -S<symbol><size>[c|i|p] [%s]\n", GMT_B_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[-C<lon>/<lat>[+p<pen>][+s<pointsize>]] [-E<fill>] [-F<fill>]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t[-G<fill>] %s[-N] %s%s[-Qe[<pen>]] [-Qf[<pen>]] [-Qg[<pen>]]\n", API->K_OPT, API->O_OPT, API->P_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[-Qh] [-Qs<half-size>[+v<size>[+<specs>]] [-Qt<pen>]\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t[-T[<labelinfo>]] [%s] [%s] [-W<pen>]\n", GMT_U_OPT, GMT_V_OPT);
-	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s] %s[%s] [%s]\n\t[%s] [%s] [%s] [%s]\n\n", GMT_X_OPT, GMT_Y_OPT, API->c_OPT, GMT_di_OPT, GMT_e_OPT, GMT_h_OPT, GMT_i_OPT, GMT_t_OPT, GMT_PAR_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t[-T[+a<angle>][+j<justify>][+f<font>][+o<dx>[/<dy>]]] [%s] [%s] [-W<pen>]\n", GMT_U_OPT, GMT_V_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s] %s[%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s] [%s]\n\n", GMT_X_OPT, GMT_Y_OPT, API->c_OPT, GMT_di_OPT, GMT_e_OPT, GMT_h_OPT, GMT_i_OPT, GMT_qi_OPT, GMT_t_OPT, GMT_PAR_OPT);
 
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
@@ -181,18 +182,18 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t     Azimuth of S polarity is in last column.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t     Specify a vector (with +v modifier) [Default is segment line.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t     Default definition of vector is +v0.3i+e+gblack if just +v is given.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t   t Set pen attributes to write station codes [default is current pen].\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t-T [<info about label printing>] to write station code.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t     <angle/form/justify/fontsize in points>\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t     [Default is 0.0/0/5/12].\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-T Write station code near the symbol.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   Append +a<angle> or +f<font> to change the angle or font of text string.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   Append +j<justify> or +o<dx>/<dy> to change the text justification or offset relative to the symbol.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   [Default is above the symbol, with font size of 12p].\n");
 	GMT_Option (API, "U,V");
-	GMT_Message (API, GMT_TIME_NONE,  "\t-W Set pen attributes [%s].\n", gmt_putpen (API->GMT, &API->GMT->current.setting.map_default_pen));
-	GMT_Option (API, "X,c,di,e,h,i,t,.");
+	GMT_Message (API, GMT_TIME_NONE, "\t-W Set pen attributes [%s].\n", gmt_putpen (API->GMT, &API->GMT->current.setting.map_default_pen));
+	GMT_Option (API, "X,c,di,e,h,i,qi,t,.");
 
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL unsigned int old_Q_parser (struct GMT_CTRL *GMT, char *arg, struct PSPOLAR_CTRL *Ctrl) {
+GMT_LOCAL unsigned int pspolar_old_Q_parser (struct GMT_CTRL *GMT, char *arg, struct PSPOLAR_CTRL *Ctrl) {
 	/* Deal with the old syntax: -Qs<half-size>/[V[<v_width/h_length/h_width/shape>]][G<r/g/b>][L] */
 	char *c = NULL, *text = strdup (arg);	/* Work on a copy */
 	unsigned int n_errors = 0;
@@ -236,7 +237,7 @@ GMT_LOCAL unsigned int old_Q_parser (struct GMT_CTRL *GMT, char *arg, struct PSP
 
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to pspolar and sets parameters in Ctrl.
 	 * Note Ctrl has already been initialized and non-zero default values set.
 	 * Any GMT common options will override values set previously by other commands.
@@ -254,7 +255,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 		switch (opt->option) {
 
 			case '<':	/* Input files */
-				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_DATASET, GMT_IN, GMT_FILE_REMOTE, &(opt->arg))) n_errors++;;
 				break;
 
 			/* Processes program-specific parameters */
@@ -275,17 +276,17 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 					gmt_pen_syntax (GMT, 'C', NULL, "Line connecting new and old point [Default current pen]", 0);
 					n_errors++;
 				}
-				if ((p = strstr (opt->arg, "+s"))) {	/* Found +s<size>[unit] */
+				if ((p = strstr (opt->arg, "+s"))) {	/* Found +s<size> */
 					char *q = strstr (p, "+p");
 					if (q) q[0] = '\0';	/* Chop off the +p modifier */
 					if ((Ctrl->C.size = gmt_M_to_inch (GMT, &p[2]))) {
-						GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -C option: Could not decode pointsize %s\n", &p[1]);
+						GMT_Report (API, GMT_MSG_ERROR, "Option -C: Could not decode pointsize %s\n", &p[1]);
 						n_errors++;
 					}
 					if (q) q[0] = '+';	/* Restore the +p modifier */
 				}
 				else if ((p = strchr (opt->arg, 'P')) && sscanf (&p[1], "%lf", &Ctrl->C.size)) {	/* Old syntax */
-					GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -C option: Could not decode pointsize %s\n", &p[1]);
+					GMT_Report (API, GMT_MSG_ERROR, "Option -C: Could not decode pointsize %s\n", &p[1]);
 					n_errors++;
 				}
 				break;
@@ -348,7 +349,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 						Ctrl->S2.size = gmt_M_to_inch (GMT, opt->arg);
 						if (p) p[0] = '/';	/* Restore the slash */
 						if (p && p[0] == '/' && (strchr (opt->arg, 'V') || strchr (opt->arg, 'G') || strchr (opt->arg, 'L')))	/* Clearly got the old syntax */
-							n_errors += old_Q_parser (GMT, &p[1], Ctrl);
+							n_errors += pspolar_old_Q_parser (GMT, &p[1], Ctrl);
 						else {	/* New syntax: -Qs[+v[<size>][+parameters]] */
 							char symbol = (gmt_M_is_geographic (GMT, GMT_IN)) ? '=' : 'v';	/* Type of vector */
 							if ((p = strstr (opt->arg, "+v"))) {	/* Got vector specification +v<size>[+<attributes>] */
@@ -370,7 +371,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 						}
 						break;
 					case 't':	/* Set color for station label */
-						if (gmt_getpen (GMT, &opt->arg[1], &Ctrl->T.pen)) {
+						if (gmt_getpen (GMT, &opt->arg[1], &Ctrl->T.font.pen)) {
 							gmt_pen_syntax (GMT, ' ', "Qt", "Station code symbol[Default current pen]", 0);
 							n_errors++;
 						}
@@ -392,10 +393,8 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 				Ctrl->N.active = true;
 				break;
 			case 'S':	/* Get symbol [and size] */
-				Ctrl->S.type = opt->arg[0];
-				Ctrl->S.size = gmt_M_to_inch (GMT, &opt->arg[1]);
 				Ctrl->S.active = true;
-				switch (Ctrl->S.type) {
+				switch (opt->arg[0]) {
 					case 'a':
 						Ctrl->S.symbol = PSL_STAR;
 						break;
@@ -425,14 +424,35 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 						break;
 					default:
 						n_errors++;
-						GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -S option: Unrecognized symbol type %c\n", Ctrl->S.type);
+						GMT_Report (API, GMT_MSG_ERROR, "Option -S: Unrecognized symbol type %c\n", opt->arg[0]);
 						break;
 				}
+				Ctrl->S.size = gmt_M_to_inch (GMT, &opt->arg[1]);
 				break;
 			case 'T':	/* Information about label printing */
 				Ctrl->T.active = true;
 				if (strlen (opt->arg)) {
-					sscanf (opt->arg, "%lf/%d/%d/%lf/", &Ctrl->T.angle, &Ctrl->T.form, &Ctrl->T.justify, &Ctrl->T.fontsize);
+					/* New syntax: -T+a<angle>+j<justify>+o<dx>/<dy>+f<font> */
+					if ((strstr (opt->arg, "+a")) || (strstr (opt->arg, "+f")) || strstr (opt->arg, "+o") || strstr (opt->arg, "+j")) {
+						char word[GMT_LEN64] = {""};
+						if (gmt_get_modifier (opt->arg, 'a', word))
+							Ctrl->T.angle = atof(word);
+						if (gmt_get_modifier (opt->arg, 'j', word) && strchr ("LCRBMT", word[0]) && strchr ("LCRBMT", word[1]))
+							Ctrl->T.justify = gmt_just_decode (GMT, word, Ctrl->T.justify);
+						if (gmt_get_modifier (opt->arg, 'f', word))
+							n_errors += gmt_getfont (GMT, word, &(Ctrl->T.font));
+						if (gmt_get_modifier (opt->arg, 'o', word)) {
+							if (gmt_get_pair (GMT, word, GMT_PAIR_DIM_DUP, Ctrl->T.offset) < 0) n_errors++;
+						} else {	/* Set default offset */
+							if (Ctrl->T.justify%4 != 2) /* Not center aligned */
+								Ctrl->T.offset[0] = DEFAULT_OFFSET * GMT->session.u2u[GMT_PT][GMT_INCH];
+							if (Ctrl->T.justify/4 != 1) /* Not middle aligned */
+								Ctrl->T.offset[1] = DEFAULT_OFFSET * GMT->session.u2u[GMT_PT][GMT_INCH];
+						}
+					} else {
+						/* Old syntax: -T<angle>/<form>/<justify>/<fontsize> */
+						sscanf (opt->arg, "%lf/%d/%d/%lf/", &Ctrl->T.angle, &Ctrl->T.form, &Ctrl->T.justify, &Ctrl->T.font.size);
+					}
 				}
 				break;
 			case 'W':	/* Set line attributes */
@@ -449,9 +469,9 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 		}
 	}
 
-	n_errors += gmt_M_check_condition (GMT, !GMT->common.R.active[RSET], "Syntax error: Must specify -R option\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->M.ech <= 0.0, "Syntax error: -M must specify a size\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->D.active + Ctrl->M.active + Ctrl->S.active < 3, "Syntax error: -D, -M, -S must be set together\n");
+	n_errors += gmt_M_check_condition (GMT, !GMT->common.R.active[RSET], "Must specify -R option\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->M.ech <= 0.0, "Option -M: must specify a size\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->D.active + Ctrl->M.active + Ctrl->S.active < 3, "-D, -M, -S must be set together\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
@@ -459,17 +479,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSPOLAR_CTRL *Ctrl, struct GMT
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_polar (void *V_API, int mode, void *args) {
-	/* This is the GMT6 modern mode name */
-	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
-	if (API->GMT->current.setting.run_mode == GMT_CLASSIC && !API->usage) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Shared GMT module not found: polar\n");
-		return (GMT_NOT_A_VALID_MODULE);
-	}
-	return GMT_pspolar (V_API, mode, args);
-}
-
-int GMT_pspolar (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_pspolar (void *V_API, int mode, void *args) {
 	int n = 0, error = 0;
 	bool old_is_world;
 
@@ -495,7 +505,7 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments; return if errors are encountered */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
@@ -516,7 +526,7 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 
 	GMT->current.map.is_world = true;
 
-        gmt_geo_to_xy (GMT, Ctrl->D.lon, Ctrl->D.lat, &plot_x0, &plot_y0);
+	gmt_geo_to_xy (GMT, Ctrl->D.lon, Ctrl->D.lat, &plot_x0, &plot_y0);
 	if (Ctrl->C.active) {
 		gmt_setpen (GMT, &Ctrl->C.pen);
 		gmt_geo_to_xy (GMT, Ctrl->C.lon, Ctrl->C.lat, &new_plot_x0, &new_plot_y0);
@@ -528,7 +538,7 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 	if (Ctrl->N.active) {
 		gmt_map_outside (GMT, Ctrl->D.lon, Ctrl->D.lat);
 		if (abs (GMT->current.map.this_x_status) > 1 || abs (GMT->current.map.this_y_status) > 1) {
-			GMT_Report (API, GMT_MSG_VERBOSE, "Point given by -D is outside map; no plotting occurs.");
+			GMT_Report (API, GMT_MSG_WARNING, "Point given by -D is outside map; no plotting occurs.");
 			Return (GMT_NOERROR);
 		};
 	}
@@ -566,7 +576,7 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 					azS = -1.0;
 			}
 			else { /* !Ctrl->S2.active */
-				sscanf (In->text, "%s %s %s %s %lf %lf %c", col[0], col[1], col[2], stacode, &azimut, &ih, col[3]);
+				sscanf (In->text, "%s %s %s %s %lf %lf %s", col[0], col[1], col[2], stacode, &azimut, &ih, col[3]);
 				pol = col[3][2];
 			}
 		}
@@ -586,9 +596,10 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 				plongement = -plongement;
 				azimut += 180.0;
 				symbol_size2 = Ctrl->S.size * 0.8;
-			}
+			} else
+				symbol_size2 = Ctrl->S.size;
 		}
-                else
+		else
 			symbol_size2 = Ctrl->S.size;
 		radius = sqrt (1.0 - sin (plongement));
 		if (radius >= 0.97) radius = 0.97;
@@ -599,36 +610,29 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 		if (Ctrl->S.symbol == PSL_CROSS || Ctrl->S.symbol == PSL_DOT) PSL_setcolor (PSL, GMT->session.no_rgb, PSL_IS_STROKE);
 
 		if (Ctrl->T.active) {
-			gmt_setpen (GMT, &Ctrl->T.pen);
-			switch (Ctrl->T.justify) {
-				case PSL_TR:
-					PSL_plottext (PSL, plot_x-symbol_size2-0.1, plot_y-symbol_size2-0.1, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_TR, Ctrl->T.form);
-					break;
-				case PSL_TC:
-					PSL_plottext (PSL, plot_x, plot_y-symbol_size2-0.1, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_TC, Ctrl->T.form);
-					break;
-				case PSL_TL:
-					PSL_plottext (PSL, plot_x+symbol_size2+0.1, plot_y-symbol_size2-0.1, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_TL, Ctrl->T.form);
-					break;
-				case PSL_MR:
-					PSL_plottext (PSL, plot_x-symbol_size2-0.1, plot_y, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_MR, Ctrl->T.form);
-					break;
-				case PSL_MC:
-					PSL_plottext (PSL, plot_x, plot_y, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_MC, Ctrl->T.form);
-					break;
-				case PSL_ML:
-					PSL_plottext (PSL, plot_x+symbol_size2+0.1, plot_y, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_ML, Ctrl->T.form);
-					break;
-				case PSL_BR:
-					PSL_plottext (PSL, plot_x-symbol_size2-0.1, plot_y+symbol_size2+0.1, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_BR, Ctrl->T.form);
-					break;
-				case PSL_BC:
-					PSL_plottext (PSL, plot_x, plot_y+symbol_size2+0.1, Ctrl->T.fontsize, col[3], Ctrl->T.angle, PSL_BC, Ctrl->T.form);
-					break;
-				case PSL_BL:
-					PSL_plottext (PSL, plot_x+symbol_size2+0.1, plot_y+symbol_size2+0.1, Ctrl->T.fontsize, stacode, Ctrl->T.angle, PSL_BL, Ctrl->T.form);
-					break;
-			}
+			int form;
+			int label_justify = 0;
+			double label_x, label_y;
+			double label_offset[2];
+
+			label_justify = gmt_flip_justify(GMT, Ctrl->T.justify);
+			label_offset[0] = label_offset[1] = GMT_TEXT_CLEARANCE * 0.01 * Ctrl->T.font.size / PSL_POINTS_PER_INCH;
+
+			label_x = plot_x + 0.5 * (Ctrl->T.justify%4 - label_justify%4) * Ctrl->S.size * 0.5;
+			label_y = plot_y + 0.5 * (Ctrl->T.justify/4 - label_justify/4) * Ctrl->S.size * 0.5;
+
+			/* Also deal with any justified offsets if given */
+			if (Ctrl->T.justify%4 == 1) /* Left aligned */
+				label_x -= Ctrl->T.offset[0];
+			else /* Right or center aligned */
+				label_x += Ctrl->T.offset[0];
+			if (Ctrl->T.justify/4 == 0) /* Bottom aligned */
+				label_y -= Ctrl->T.offset[1];
+			else /* Top or middle aligned */
+				label_y += Ctrl->T.offset[1];
+
+			form = gmt_setfont (GMT, &Ctrl->T.font);
+			PSL_plottext (PSL, label_x, label_y, Ctrl->T.font.size, stacode, Ctrl->T.angle, label_justify, form);
 		}
 		if (Ctrl->S.symbol == PSL_DOT) symbol_size2 = GMT_DOT_SIZE;
 
@@ -686,3 +690,13 @@ int GMT_pspolar (void *V_API, int mode, void *args) {
 
 	Return (GMT_NOERROR);
 }
+
+EXTERN_MSC int GMT_polar (void *V_API, int mode, void *args) {
+	/* This is the GMT6 modern mode name */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	if (API->GMT->current.setting.run_mode == GMT_CLASSIC && !API->usage) {
+		GMT_Report (API, GMT_MSG_ERROR, "Shared GMT module not found: polar\n");
+		return (GMT_NOT_A_VALID_MODULE);
+	}
+	return GMT_pspolar (V_API, mode, args);
+}
