@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
  *
- *  Copyright (c) 2016-2019 by Dongdong Tian
+ *  Copyright (c) 2016-2020 by Dongdong Tian
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; version 3 or any later version.
  *
- *  This program is distrdeibuted in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
@@ -84,7 +84,7 @@ struct PSSAC_CTRL {
 	struct PSSAC_Q {	/* -Q */
 		bool active;
 	} Q;
-	struct PSSAC_S {	/* -S[i]<scale>[<unit>] */
+	struct PSSAC_S {	/* -S[i]<scale> */
 		bool active;
 		double factor;
 		char unit;
@@ -113,7 +113,7 @@ struct SAC_LIST {
 };
 
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct PSSAC_CTRL *C;
 
 	C = gmt_M_memory (GMT, NULL, 1, struct PSSAC_CTRL);
@@ -124,21 +124,21 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct PSSAC_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct PSSAC_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_freepen (GMT, &C->W.pen);
 	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	/* This displays the pssac synopsis and optionally full usage information */
 
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s [<saclist>|<SACfiles>] %s %s\n", name, GMT_J_OPT, GMT_Rgeoz_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [-C[<t0>/<t1>]] [-D<dx>[/<dy>]] [-Ea|b|k|d|n[<n>]|u[<n>]] [-F[i][q][r]]\n", GMT_B_OPT);
-	GMT_Message (API, GMT_TIME_NONE, "\t[-G[p|n][+g<fill>][+t<t0>/<t1>][+z<zero>]] %s[-M<size>[<unit>]/<alpha>] %s%s[-Q]\n", API->K_OPT, API->O_OPT, API->P_OPT);
-	GMT_Message (API, GMT_TIME_NONE, "\t[-S[i]<scale>[<unit>]] [-T[+t<tmark>][+r<reduce_vel>][+s<shift>]] \n");
+	GMT_Message (API, GMT_TIME_NONE, "\t[-G[p|n][+g<fill>][+t<t0>/<t1>][+z<zero>]] %s[-M<size>/<alpha>] %s%s[-Q]\n", API->K_OPT, API->O_OPT, API->P_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t[-S[i]<scale>] [-T[+t<tmark>][+r<reduce_vel>][+s<shift>]] \n");
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s] [-W<pen>]\n", GMT_U_OPT, GMT_V_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s]\n\t%s[%s]\n\t[%s]\n\t[%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT, API->c_OPT, GMT_h_OPT, GMT_p_OPT, GMT_t_OPT, GMT_PAR_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\n");
@@ -151,14 +151,14 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   <filename> is the name of SAC file to plot.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   <X> and <Y> are the position of seismograms to plot on a map.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t      On linear plots, the default <X> is the begin time of SAC file, which will be adjusted if -T option is used, \n");
-	GMT_Message (API, GMT_TIME_NONE, "\t      the default <Y> is determined by **-E** option.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t      the default <Y> is determined by -E option.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t      On geographic plots, the default <X> and <Y> are station longitude and latitude specified in SAC header.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t      The <X> and <Y> given here will override the position determined by command line options.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   If <pen> is given, it will override the pen from -W option for current SAC file only.\n");
 	GMT_Option (API, "J-Z,R");
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
 	GMT_Option (API, "B-");
-	GMT_Message (API, GMT_TIME_NONE, "\t-C Read and plot seismograms in timewindow between <t0> and <t1> only. <t0> and <t1>* are relative to a reference time specified by -T.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-C Read and plot seismograms in timewindow between <t0> and <t1> only. <t0> and <t1> are relative to a reference time specified by -T.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   If -T option is not specified, use the reference time (kzdate and kztime) defined in SAC header instead.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Default to read and plot the whole trace. If only -C is used, t0 and t1 are determined from -R option\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-D Offset all traces by <dx>/<dy>. If <dy> is not given it is set equal to <dx>.\n");
@@ -183,7 +183,7 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   +z<zero>: define zero line. From <zero> to top is positive portion, from <zero> to bottom is negative portion.\n");
 	GMT_Option (API, "K");
 	GMT_Message (API, GMT_TIME_NONE, "\t-M Vertical scaling\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t   <size>: each trace will scaled to <size>[u]. The default unit is PROJ_LENGTH_UNIT.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   <size>: each trace will scaled to <size>. The default unit is PROJ_LENGTH_UNIT.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t      The scale factor is defined as yscale = size*(north-south)/(depmax-depmin)/map_height \n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   <size>/<alpha>: \n");
 	GMT_Message (API, GMT_TIME_NONE, "\t      <alpha> < 0, use the same scaling factor for all traces. The scaling factor will scale the first trace to <size>[<u>].\n");
@@ -191,9 +191,9 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t      <alpha> > 0, multiply all traces by size*r^alpha, r is the distance range in km.\n");
 	GMT_Option (API, "O,P");
 	GMT_Message (API, GMT_TIME_NONE, "\t-Q Plot traces vertically.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t-S Sets time scale in seconds per <unit> while plotting on geographic plots. \n");
-	GMT_Message (API, GMT_TIME_NONE, "\t   Append c, i, or p to indicate cm, inch or points as the unit. Use PROJ_LENGTH_UNIT if <unit> is omitted.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t   Use -Si<scale><unit> to give the reciprocal scale, i.e. cm per second or inch per second.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-S Sets time scale in seconds per unit while plotting on geographic plots. \n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   Append c, i, or p to indicate cm, inch or points as the unit. Use PROJ_LENGTH_UNIT if unit is omitted.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   Use -Si<scale> to give the reciprocal scale, i.e. cm per second or inch per second.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-T Time alignment. \n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   +t<tmark> align all trace along time mark. Choose <tmark> from -5(b), -4(e), -3(o), -2(a), 0-9(t0-t9).\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   +r<reduce_vel> reduce velocity in km/s.\n");
@@ -206,7 +206,7 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	return (EXIT_FAILURE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to pssac and sets parameters in Ctrl.
 	 * Note Ctrl has already been initialized and non-zero default values set.
 	 * Any GMT common options will override values set previously by other commands.
@@ -218,7 +218,6 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 	int j, k;
 	size_t n_alloc = 0, len;
 	char txt_a[GMT_LEN256] = {""}, txt_b[GMT_LEN256] = {""}, p[GMT_BUFSIZ] = {""};
-	char path[PATH_MAX] = {""};	/* Full path to sac file */
 	struct GMT_OPTION *opt = NULL;
 	struct GMTAPI_CTRL *API = GMT->parent;
 
@@ -227,15 +226,10 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 
 			case '<':	/* Collect input files */
 				Ctrl->In.active = true;
-				if (n_alloc <= Ctrl->In.n)  Ctrl->In.file = gmt_M_memory (GMT, Ctrl->In.file, n_alloc += GMT_SMALL_CHUNK, char *);
-				if (gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) {
-					if (gmt_getdatapath (GMT, opt->arg, path, R_OK) == NULL) {
-						GMT_Report (API, GMT_MSG_NORMAL, "Cannot find/open file %s.\n", opt->arg);
-						continue;
-					}
-					Ctrl->In.file[Ctrl->In.n++] = strdup (path);
-				} else
-					n_errors++;
+				if (n_alloc <= Ctrl->In.n) Ctrl->In.file = gmt_M_memory (GMT, Ctrl->In.file, n_alloc += GMT_SMALL_CHUNK, char *);
+				Ctrl->In.file[Ctrl->In.n] = strdup (opt->arg);
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_DATASET, GMT_IN, GMT_FILE_REMOTE, &(Ctrl->In.file[Ctrl->In.n]))) n_errors++;
+				Ctrl->In.n++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -249,7 +243,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 				break;
 			case 'D':
 				if ((j = sscanf (opt->arg, "%[^/]/%s", txt_a, txt_b)) < 1) {
-					GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -D option: Give x [and y] offsets\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Option -D: Give x [and y] offsets\n");
 					n_errors++;
 				}
 				else {
@@ -288,7 +282,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 						case 't':  /* +t<t0>/<t1> */
 							Ctrl->G.cut[k] = true;
 							if (sscanf (&p[1], "%f/%f", &Ctrl->G.t0[k], &Ctrl->G.t1[k]) != 2) {
-								GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -G+t<t0>/<t1> option.\n");
+								GMT_Report (API, GMT_MSG_ERROR, "Option -G: Give -G+t<t0>/<t1>.\n");
 								n_errors++;
 							}
 							break;
@@ -323,7 +317,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 					}
 				}
 				else {
-					GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -M option: -M<size>[/<alpha>]\n");
+					GMT_Report (API, GMT_MSG_ERROR, "Option -M: Expects -M<size>[/<alpha>]\n");
 					n_errors++;
 				}
 
@@ -340,7 +334,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 				if (strchr(GMT_DIM_UNITS, (int)opt->arg[len])) /* Recognized unit character */
 					Ctrl->S.unit = opt->arg[len];
 				else if (! (opt->arg[len] == '.' || isdigit ((int)opt->arg[len]))) {    /* Not decimal point or digit means trouble */
-					GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -S option: Unrecognized unit %c\n", opt->arg[len]);
+					GMT_Report (API, GMT_MSG_ERROR, "Option -S: Unrecognized unit %c\n", opt->arg[len]);
 					n_errors++;
 				}
 				if (j == 0) {
@@ -399,22 +393,22 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct GMT_O
 
 	/* Check that the options selected are mutually consistent */
 
-	n_errors += gmt_M_check_condition (GMT, !GMT->common.R.active[RSET], "Syntax error: Must specify -R option\n");
-	n_errors += gmt_M_check_condition (GMT, !GMT->common.J.active, "Syntax error: Must specify a map projection with the -J option\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->S.active && gmt_M_is_zero(Ctrl->S.factor), "Syntax error -S option: <scale> must be nonzero\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->T.reduce && gmt_M_is_zero(Ctrl->T.reduce_vel), "Syntax error -T option: <reduce_vel> must be nonzero\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->T.align && !(Ctrl->T.tmark >= -5 && Ctrl->T.tmark <= 9 && Ctrl->T.tmark != -1), "Syntax error -T option: <tmark> should be chosen from -5, -4, -3, -2, 0-9\n");
+	n_errors += gmt_M_check_condition (GMT, !GMT->common.R.active[RSET], "Must specify -R option\n");
+	n_errors += gmt_M_check_condition (GMT, !GMT->common.J.active, "Must specify a map projection with the -J option\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->S.active && gmt_M_is_zero(Ctrl->S.factor), "Option -S: <scale> must be nonzero\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->T.reduce && gmt_M_is_zero(Ctrl->T.reduce_vel), "Option -T: <reduce_vel> must be nonzero\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->T.align && !(Ctrl->T.tmark >= -5 && Ctrl->T.tmark <= 9 && Ctrl->T.tmark != -1), "Option -T: <tmark> should be chosen from -5, -4, -3, -2, 0-9\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
 }
 
-GMT_LOCAL double linear_interpolate_x (double x0, double y0, double x1, double y1, double y) {
+GMT_LOCAL double pssac_linear_interpolate_x (double x0, double y0, double x1, double y1, double y) {
 	if (doubleAlmostEqualZero(y0, y1)) return x0;
 	return (x1-x0)/(y1-y0)*(y-y0) + x0;
 }
 
 #if 0 /* Not used yet */
-GMT_LOCAL double linear_interpolate_y (double x0, double y0, double x1, double y1, double x) {
+GMT_LOCAL double pssac_linear_interpolate_y (double x0, double y0, double x1, double y1, double x) {
 	if (x<x0 || x>x1) return y1;  // no extrapolation
 	if (doubleAlmostEqualZero(x0, x1)) return y0;
 	return (y1-y0)/(x1-x0)*(x-x0) + y0;
@@ -424,7 +418,7 @@ GMT_LOCAL double linear_interpolate_y (double x0, double y0, double x1, double y
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-GMT_LOCAL void paint_phase(struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct PSL_CTRL *PSL, double *x, double *y, int n, double zero, double t0, double t1, int mode) {
+GMT_LOCAL void pssac_paint_phase(struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct PSL_CTRL *PSL, double *x, double *y, int n, double zero, double t0, double t1, int mode) {
 	/* mode=0: paint positive phase */
 	/* mode=1: paint negative phase */
 	int i, ii;
@@ -450,7 +444,7 @@ GMT_LOCAL void paint_phase(struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct
 			if (i == 0)
 				xx[ii] = x[i];
 			else
-				xx[ii] = linear_interpolate_x(x[i-1], y[i-1], x[i], y[i], yy[ii]);
+				xx[ii] = pssac_linear_interpolate_x(x[i-1], y[i-1], x[i], y[i], yy[ii]);
 			ii++;
 
 			while((i < n) && (x[i] <= t1) && ((mode == 0 && y[i] >= zero) || (mode == 1 && y[i] <= zero))) {
@@ -465,7 +459,7 @@ GMT_LOCAL void paint_phase(struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct
 			if (i == n || x[i] > t1)
 				xx[ii] = x[i-1];
 			else
-				xx[ii] = linear_interpolate_x(x[i], y[i], x[i-1], y[i-1], yy[ii]);
+				xx[ii] = pssac_linear_interpolate_x(x[i], y[i], x[i-1], y[i-1], yy[ii]);
 			ii++;
 
 			if (Ctrl->Q.active) {
@@ -485,7 +479,7 @@ GMT_LOCAL void paint_phase(struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct
 				yp = yy;
 				npts = ii;
 			}
-			gmt_setfill(GMT, &Ctrl->G.fill[mode], false);
+			gmt_setfill(GMT, &Ctrl->G.fill[mode], 0);
 
 			PSL_plotpolygon(PSL, xp, yp, npts);
 		}
@@ -494,7 +488,7 @@ GMT_LOCAL void paint_phase(struct GMT_CTRL *GMT, struct PSSAC_CTRL *Ctrl, struct
 	gmt_M_free (GMT, yy);
 }
 
-GMT_LOCAL void integral (double *y, double delta, int n) {
+GMT_LOCAL void pssac_integral (double *y, double delta, int n) {
 	int i;
 
 	y[0] = (y[0] + y[1]) * delta / 2.0;
@@ -502,7 +496,7 @@ GMT_LOCAL void integral (double *y, double delta, int n) {
 		y[i] = y[i-1] + (y[i] + y[i+1]) * delta / 2.0;
 }
 
-GMT_LOCAL void rmean (double *y, int n) {
+GMT_LOCAL void pssac_rmean (double *y, int n) {
 	int i;
 	double depmen = 0.0;
 	for (i = 0; i < n; i++) depmen += y[i];
@@ -511,12 +505,12 @@ GMT_LOCAL void rmean (double *y, int n) {
 	for (i = 0; i < n; i++) y[i] -= depmen;
 }
 
-GMT_LOCAL void sqr (double *y, int n) {
+GMT_LOCAL void pssac_sqr (double *y, int n) {
 	int i;
 	for (i = 0; i < n; i++) y[i] *= y[i];
 }
 
-GMT_LOCAL int init_sac_list (struct GMT_CTRL *GMT, char **files, unsigned int n_files, struct SAC_LIST **list) {
+GMT_LOCAL int pssac_init_list (struct GMT_CTRL *GMT, char **files, unsigned int n_files, struct SAC_LIST **list) {
 	unsigned int n = 0;
 	int nr;
 	char path[PATH_MAX] = {""};	/* Full path to sac file */
@@ -549,7 +543,7 @@ GMT_LOCAL int init_sac_list (struct GMT_CTRL *GMT, char **files, unsigned int n_
 			    continue;
 			}
 			if (In->text == NULL) {	/* Crazy safety valve but it should never get here*/
-				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Internal error: input pointer is NULL where it should not be, aborting\n");
+				GMT_Report (GMT->parent, GMT_MSG_ERROR, "Input pointer is NULL where it should not be, aborting\n");
 				for (n = 0; n < n_files; n++) free (L[n].file);
 				gmt_M_free (GMT, L);
 				return (GMT_PTR_IS_NULL);
@@ -558,7 +552,7 @@ GMT_LOCAL int init_sac_list (struct GMT_CTRL *GMT, char **files, unsigned int n_
 			if (gmt_is_a_blank_line (In->text)) continue;
 			nr = sscanf (In->text, "%s %lf %lf %s", file, &x, &y, pen);
 			if (nr < 1) {
-				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Read error for sac list file near row %d\n", n_files);
+				GMT_Report (GMT->parent, GMT_MSG_ERROR, "Read error for sac list file near row %d\n", n_files);
 				for (n = 0; n < n_files; n++) free (L[n].file);
 				gmt_M_free (GMT, L);
 				return (EXIT_FAILURE);
@@ -568,7 +562,7 @@ GMT_LOCAL int init_sac_list (struct GMT_CTRL *GMT, char **files, unsigned int n_
 			gmt_M_memset (&L[n_files], n_alloc - n_files, struct SAC_LIST); /* Set content of new space to NULL */
 
 			if (gmt_getdatapath (GMT, file, path, R_OK) == NULL) {
-				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Cannot find/open file %s.\n", file);
+				GMT_Report (GMT->parent, GMT_MSG_ERROR, "Cannot find/open file %s.\n", file);
 				continue;
 			}
 			L[n_files].file = strdup (path);
@@ -592,17 +586,7 @@ GMT_LOCAL int init_sac_list (struct GMT_CTRL *GMT, char **files, unsigned int n_
 	return n_files;
 }
 
-int GMT_sac (void *V_API, int mode, void *args) {
-	/* This is the GMT6 modern mode name */
-	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
-	if (API->GMT->current.setting.run_mode == GMT_CLASSIC && !API->usage) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Shared GMT module not found: sac\n");
-		return (GMT_NOT_A_VALID_MODULE);
-	}
-	return GMT_pssac (V_API, mode, args);
-}
-
-int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that implements the pssac task */
+EXTERN_MSC int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that implements the pssac task */
 	bool old_is_world, free_plot_pen = false, read_from_ascii, draw_line;
 	unsigned int n_files, *plot_pen = NULL;
 	int error = GMT_NOERROR, n, i, npts;
@@ -627,7 +611,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 
 	/* Parse the command-line arguments; return if errors are encountered */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
@@ -652,7 +636,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 
 	read_from_ascii = (Ctrl->In.n == 0) || (Ctrl->In.n == 1 && !issac(Ctrl->In.file[0]));
 	if (read_from_ascii) {      /* Got a ASCII file or read from stdin */
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Reading from saclist file or stdin\n");
+		GMT_Report (API, GMT_MSG_INFORMATION, "Reading from saclist file or stdin\n");
 		if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_TEXT, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {    /* Register data input */
 			Return (API->error);
 		}
@@ -660,29 +644,29 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 			Return (API->error);
 		}
 	}
-	n_files = init_sac_list (GMT, Ctrl->In.file, Ctrl->In.n, &L);
+	n_files = pssac_init_list (GMT, Ctrl->In.file, Ctrl->In.n, &L);
 
 	if (read_from_ascii && GMT_End_IO (API, GMT_IN, 0) != GMT_OK) { /* Disables further data input */
 		Return (API->error);
 	}
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Collecting %ld SAC files to plot.\n", n_files);
+	GMT_Report (API, GMT_MSG_INFORMATION, "Collecting %ld SAC files to plot.\n", n_files);
 
 	for (n = 0; n < (int)n_files; n++) {  /* Loop over all SAC files */
- 		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Plotting SAC file %d: %s\n", n, L[n].file);
+ 		GMT_Report (API, GMT_MSG_INFORMATION, "Plotting SAC file %d: %s\n", n, L[n].file);
 
 		/* -T: determine the reference time for all times in pssac */
 		tref = 0.0;
 		if (Ctrl->T.active) {
 			/* read SAC header only to determine the reference time */
  			if ((read_sac_head (L[n].file, &hd))) {  /* skip or not */
- 				GMT_Report (API, GMT_MSG_NORMAL, "=> %s: Unable to read, skipped.\n", L[n].file);
+ 				GMT_Report (API, GMT_MSG_ERROR, "=> %s: Unable to read, skipped.\n", L[n].file);
 				continue;
 			}
 			/* +t */
 			if (Ctrl->T.align) {
 				tmark_value = *((float *)&hd + TMARK + Ctrl->T.tmark);
 				if (floatAlmostEqualZero(tmark_value, SAC_FLOAT_UNDEF)) {
-					GMT_Report (API, GMT_MSG_NORMAL, "=> %s: tmark %d not defined in SAC header, skipped.\n", L[n].file, Ctrl->T.tmark);
+					GMT_Report (API, GMT_MSG_ERROR, "=> %s: tmark %d not defined in SAC header, skipped.\n", L[n].file, Ctrl->T.tmark);
 					continue;
 				}
 				tref += (double)tmark_value;
@@ -691,7 +675,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 			/* +r */
 			if (Ctrl->T.reduce) {
 				if (floatAlmostEqualZero(hd.dist, SAC_FLOAT_UNDEF)) {
-					GMT_Report (API, GMT_MSG_NORMAL, "=> %s: dist not defined in SAC header, skipped.\n", L[n].file);
+					GMT_Report (API, GMT_MSG_ERROR, "=> %s: dist not defined in SAC header, skipped.\n", L[n].file);
 					continue;
 				}
 				tref += fabs(hd.dist)/Ctrl->T.reduce_vel;
@@ -699,18 +683,18 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 			/* +s */
 			tref -= Ctrl->T.shift;
 		}
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: reference time is %g\n", L[n].file, tref);
+		GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: reference time is %g\n", L[n].file, tref);
 
 		/* read SAC data */
 		if (!Ctrl->C.active) {
 			if ((data = read_sac (L[n].file, &hd)) == NULL) {
-				GMT_Report (API, GMT_MSG_NORMAL, "=> %s: Unable to read, skipped.\n", L[n].file);
+				GMT_Report (API, GMT_MSG_ERROR, "=> %s: Unable to read, skipped.\n", L[n].file);
 				continue;
 			}
 		}
 		else {
 			if ((data = read_sac_pdw (L[n].file, &hd, 10, (float)(tref+Ctrl->C.t0), (float)(tref+Ctrl->C.t1) )) == NULL) {
-				GMT_Report (API, GMT_MSG_NORMAL, "=> %s: Unable to read, skipped.\n", L[n].file);
+				GMT_Report (API, GMT_MSG_ERROR, "=> %s: Unable to read, skipped.\n", L[n].file);
 				continue;
 			}
 		}
@@ -722,7 +706,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 		if (gmt_M_is_linear(GMT)) dt = hd.delta;
 		else if (Ctrl->S.active) dt = hd.delta * Ctrl->S.factor;
 		else {
-			GMT_Report (API, GMT_MSG_NORMAL, "-S option is needed in geographic plots.\n");
+			GMT_Report (API, GMT_MSG_ERROR, "-S option is needed in geographic plots.\n");
 			gmt_M_free(GMT, x);		gmt_M_free(GMT, y);		gmt_M_free (GMT, L);
 			gmt_M_free(GMT, data);
 			Return(EXIT_FAILURE);
@@ -736,9 +720,9 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 		/* -F: data preprocess */
 		for (i = 0; Ctrl->F.keys[i] != '\0'; i++) {
 			switch (Ctrl->F.keys[i]) {
-				case 'i': integral(y, hd.delta, hd.npts); hd.npts--; break;
-				case 'q':   sqr(y, hd.npts); break;
-				case 'r': rmean(y, hd.npts); break;
+				case 'i': pssac_integral(y, hd.delta, hd.npts); hd.npts--; break;
+				case 'q':   pssac_sqr(y, hd.npts); break;
+				case 'r': pssac_rmean(y, hd.npts); break;
 				default: break;
 			}
 		}
@@ -751,7 +735,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 			hd.depmen += (float)y[i];
 		}
 		hd.depmen = hd.depmen/hd.npts;
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: depmax=%g depmin=%g depmen=%g\n", L[n].file, hd.depmax, hd.depmin, hd.depmen);
+		GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: depmax=%g depmin=%g depmen=%g\n", L[n].file, hd.depmax, hd.depmin, hd.depmen);
 
 		/* -M: determine yscale for multiple traces */
 		if (Ctrl->M.active) {
@@ -764,7 +748,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 			hd.depmax *= (float)yscale;
 			hd.depmen *= (float)yscale;
 		}
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: yscale of trace: %g\n", L[n].file, yscale);
+		GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: yscale of trace: %g\n", L[n].file, yscale);
 
 		/* -Q: swap x and y */
 		if (Ctrl->Q.active) {
@@ -784,7 +768,7 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 				L[n].x = hd.stlo;
 				L[n].y = hd.stla;
 			}
-			GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: Geographic location: (%g, %g)\n", L[n].file, hd.stlo, hd.stla);
+			GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: Geographic location: (%g, %g)\n", L[n].file, hd.stlo, hd.stla);
 			gmt_geo_to_xy (GMT, L[n].x, L[n].y, &L[n].x, &L[n].y);
 		}
 
@@ -795,36 +779,35 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 		else {
 			unsigned int user = 0; /* default using user0 */
 			/* determine X0 */
-			if (!Ctrl->C.active) x0 = hd.b - tref;
-			else                 x0 = Ctrl->C.t0;
+			x0 = hd.b - tref;	/* the new begin time may not exactly match t1 */
 
 			/* determine Y0 */
 			if (Ctrl->E.active) {
 				switch (Ctrl->E.keys[0]) {
 					case 'a':
 						if (floatAlmostEqualZero(hd.az, SAC_FLOAT_UNDEF)) {
-							GMT_Report (API, GMT_MSG_NORMAL, "=> %s: az not defined in SAC header, skipped.\n", L[n].file);
+							GMT_Report (API, GMT_MSG_ERROR, "=> %s: az not defined in SAC header, skipped.\n", L[n].file);
 							continue;
 						}
 						y0 = hd.az;
 						break;
 					case 'b':
 						if (floatAlmostEqualZero(hd.baz, SAC_FLOAT_UNDEF)) {
-							GMT_Report (API, GMT_MSG_NORMAL, "=> %s: baz not defined in SAC header, skipped.\n", L[n].file);
+							GMT_Report (API, GMT_MSG_ERROR, "=> %s: baz not defined in SAC header, skipped.\n", L[n].file);
 							continue;
 						}
 						y0 = hd.baz;
 						break;
 					case 'd':
 						if (floatAlmostEqualZero(hd.gcarc, SAC_FLOAT_UNDEF)) {
-							GMT_Report (API, GMT_MSG_NORMAL, "=> %s: gcarc not defined in SAC header, skipped.\n", L[n].file);
+							GMT_Report (API, GMT_MSG_ERROR, "=> %s: gcarc not defined in SAC header, skipped.\n", L[n].file);
 							continue;
 						}
 						y0 = hd.gcarc;
 						break;
 					case 'k':
 						if (floatAlmostEqualZero(hd.dist, SAC_FLOAT_UNDEF)) {
-							GMT_Report (API, GMT_MSG_NORMAL, "=> %s: dist not defined in SAC header, skipped.\n", L[n].file);
+							GMT_Report (API, GMT_MSG_ERROR, "=> %s: dist not defined in SAC header, skipped.\n", L[n].file);
 							continue;
 						}
 						y0 = hd.dist;
@@ -837,12 +820,12 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 						if (Ctrl->E.keys[1] != '\0') user = atoi(&Ctrl->E.keys[1]);
 						y0 = *((float *) &hd + USERN + user);
 						if (floatAlmostEqualZero((float)y0, SAC_FLOAT_UNDEF)) {
-							GMT_Report (API, GMT_MSG_NORMAL, "=> %s: user%d not defined in SAC header, skipped.\n", user, L[n].file);
+							GMT_Report (API, GMT_MSG_ERROR, "=> %s: user%d not defined in SAC header, skipped.\n", user, L[n].file);
 							continue;
 						}
 						break;
 					default:
-						GMT_Report (API, GMT_MSG_NORMAL, "Wrong choice of profile type (d|k|a|b|n) \n");
+						GMT_Report (API, GMT_MSG_ERROR, "Wrong choice of profile type (d|k|a|b|n) \n");
 						gmt_M_free(GMT, x);		gmt_M_free(GMT, y);		gmt_M_free (GMT, L);
 						Return(EXIT_FAILURE);
 						break;
@@ -854,14 +837,14 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 			}
 		}
 
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: location of trace: (%g, %g)\n", L[n].file, x0, y0);
+		GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: location of trace: (%g, %g)\n", L[n].file, x0, y0);
 		for (i = 0; i < hd.npts; i++) {
 			x[i] += x0;
 			y[i] += y0;
 		}
 
 		/* report xmin, xmax, ymin and ymax */
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: after scaling and shifting : xmin=%g xmax=%g ymin=%g ymax=%g\n",
+		GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: after scaling and shifting : xmin=%g xmax=%g ymin=%g ymax=%g\n",
 		                                       L[n].file, x[0], x[hd.npts-1], hd.depmin, hd.depmax);
 
 		/* paint trace */
@@ -891,9 +874,9 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
  						}
  					}
 				}
-				GMT_Report (API, GMT_MSG_LONG_VERBOSE, "=> %s: Painting traces: zero=%g t0=%g t1=%g\n",
+				GMT_Report (API, GMT_MSG_INFORMATION, "=> %s: Painting traces: zero=%g t0=%g t1=%g\n",
 				                                  L[n].file, zero, Ctrl->G.t0[i], Ctrl->G.t1[i]);
-				paint_phase(GMT, Ctrl, PSL, x, y, hd.npts, zero, Ctrl->G.t0[i], Ctrl->G.t1[i], i);
+				pssac_paint_phase(GMT, Ctrl, PSL, x, y, hd.npts, zero, Ctrl->G.t0[i], Ctrl->G.t1[i], i);
 			}
 		}
 
@@ -948,3 +931,13 @@ int GMT_pssac (void *V_API, int mode, void *args) {	/* High-level function that
 
 	Return (GMT_OK);
 }
+
+EXTERN_MSC int GMT_sac (void *V_API, int mode, void *args) {
+	/* This is the GMT6 modern mode name */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	if (API->GMT->current.setting.run_mode == GMT_CLASSIC && !API->usage) {
+		GMT_Report (API, GMT_MSG_ERROR, "Shared GMT module not found: sac\n");
+		return (GMT_NOT_A_VALID_MODULE);
+	}
+	return GMT_pssac (V_API, mode, args);
+}
