@@ -327,8 +327,11 @@ EXTERN_MSC int GMT_grdpmodeler (void *V_API, int mode, void *args) {
 		}
 		spotter_setrot (GMT, &(p[0]));
 	}
-	else	/* Got a file or Gplates plate pair */
-		n_stages = spotter_init (GMT, Ctrl->E.rot.file, &p, 0, false, Ctrl->E.rot.invert, &Ctrl->N.t_upper);
+	else {	/* Got a file or Gplates plate pair */
+		if ((retval = spotter_init (GMT, Ctrl->E.rot.file, &p, 0, false, Ctrl->E.rot.invert, &Ctrl->N.t_upper)) < 0)
+			Return (-retval);
+		n_stages = (unsigned int)retval;
+	}
 	for (stage = 0; stage < n_stages; stage++) {
 		if (p[stage].omega < 0.0) {	/* Ensure all stages have positive rotation angles */
 			p[stage].omega = -p[stage].omega;
@@ -450,7 +453,8 @@ EXTERN_MSC int GMT_grdpmodeler (void *V_API, int mode, void *args) {
 				case PM_DIST:	/* Compute great-circle distance between node and point of origin at ridge */
 					if (!spotted) {
 						lon = grd_x[col] * D2R;	lat = grd_yc[row] * D2R;
-						(void)spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL);
+						if (spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL) < 0)
+							Return (GMT_RUNTIME_ERROR);
 						spotted = true;
 					}
 					value = GMT->current.proj.DIST_KM_PR_DEG * gmt_distance (GMT, grd_x[col], grd_yc[row], lon * R2D, lat * R2D);
@@ -468,7 +472,8 @@ EXTERN_MSC int GMT_grdpmodeler (void *V_API, int mode, void *args) {
 					case PM_DLON:	/* Compute latitude where this point was formed in the model */
 					if (!spotted) {
 						lon = grd_x[col] * D2R;	lat = grd_yc[row] * D2R;
-						(void)spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL);
+						if (spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL) < 0)
+							Return (GMT_RUNTIME_ERROR);
 						spotted = true;
 					}
 					value = grd_x[col] - lon * R2D;
@@ -477,7 +482,8 @@ EXTERN_MSC int GMT_grdpmodeler (void *V_API, int mode, void *args) {
 				case PM_DLAT:	/* Compute latitude where this point was formed in the model */
 					if (!spotted) {
 						lon = grd_x[col] * D2R;	lat = grd_yc[row] * D2R;
-						(void)spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL);
+						if (spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL) < 0)
+							Return (GMT_RUNTIME_ERROR);
 						spotted = true;
 					}
 					value = grd_y[row] - gmt_lat_swap (GMT, lat * R2D, GMT_LATSWAP_O2G);	/* Convert back to geodetic */
@@ -485,7 +491,8 @@ EXTERN_MSC int GMT_grdpmodeler (void *V_API, int mode, void *args) {
 				case PM_LON:	/* Compute latitude where this point was formed in the model */
 					if (!spotted) {
 						lon = grd_x[col] * D2R;	lat = grd_yc[row] * D2R;
-						(void)spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL);
+						if (spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL) < 0)
+							Return (GMT_RUNTIME_ERROR);
 						spotted = true;
 					}
 					value = lon * R2D;
@@ -493,7 +500,8 @@ EXTERN_MSC int GMT_grdpmodeler (void *V_API, int mode, void *args) {
 				case PM_LAT:	/* Compute latitude where this point was formed in the model */
 					if (!spotted) {
 						lon = grd_x[col] * D2R;	lat = grd_yc[row] * D2R;
-						(void)spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL);
+						if (spotter_backtrack (GMT, &lon, &lat, &age, 1U, p, n_stages, 0.0, 0.0, 0, NULL, NULL) < 0)
+							Return (GMT_RUNTIME_ERROR);
 						spotted = true;
 					}
 					value = gmt_lat_swap (GMT, lat * R2D, GMT_LATSWAP_O2G);			/* Convert back to geodetic */
