@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *   Copyright (c) 2016-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *   Copyright (c) 2016-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as published by
@@ -45,27 +45,27 @@
 
 struct ROTSMOOTHER_CTRL {	/* All control options for this program (except common args) */
 	/* active is true if the option has been activated */
-	struct A {	/* -A */
+	struct ROTSMOOTHER_A {	/* -A */
 		bool active;
 	} A;
-	struct C {	/* -C */
+	struct ROTSMOOTHER_C {	/* -C */
 		bool active;
 	} C;
-	struct N {	/* -N */
+	struct ROTSMOOTHER_N {	/* -N */
 		bool active;
 	} N;
-	struct S {	/* -S */
+	struct ROTSMOOTHER_S {	/* -S */
 		bool active;
 	} S;
-	struct T {	/* -T<time>, -T<start/stop/inc> or -T<tfile.txt> */
+	struct ROTSMOOTHER_T {	/* -T<time>, -T<start/stop/inc> or -T<tfile.txt> */
 		bool active;
 		unsigned int n_times;	/* Number of reconstruction times */
 		double *value;	/* Array with one or more reconstruction times */
 	} T;
-	struct W {	/* -W */
+	struct ROTSMOOTHER_W {	/* -W */
 		bool active;
 	} W;
-	struct Z {	/* -Z */
+	struct ROTSMOOTHER_Z {	/* -Z */
 		bool active;
 	} Z;
 };
@@ -77,13 +77,13 @@ struct ROTSMOOTHER_CTRL {	/* All control options for this program (except common
 #define K_WEIGHT	4
 #define N_ITEMS		5
 
-struct AGEROT {
+struct ROTSMOOTHER_AGEROT {
 	double wxyasn[N_ITEMS];
 	double P[3];	/* For Cartesian components */
 	double Q[4];	/* For quaternion components */
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct ROTSMOOTHER_CTRL *C;
 
 	C = gmt_M_memory (GMT, NULL, 1, struct ROTSMOOTHER_CTRL);
@@ -93,13 +93,13 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_M_free (GMT, C->T.value);
 	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s [<table>] [-A] [-C] [-N] [-S] [-T<time(s)>] [%s] [-W] [-Z] [%s] [%s]\n\t[%s] [%s] [%s]\n\t[%s] [%s] [%s] [%s]\n\n",
@@ -128,7 +128,7 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to backtracker and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -145,7 +145,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *Ctrl, struct
 		switch (opt->option) {
 
 			case '<':	/* Input files */
-				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (GMT_Get_FilePath (GMT->parent, GMT_IS_DATASET, GMT_IN, GMT_FILE_REMOTE, &(opt->arg))) n_errors++;;
 				break;
 
 			/* Supplemental parameters */
@@ -173,7 +173,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *Ctrl, struct
 					struct GMT_DATASET *T = NULL;
 					struct GMT_DATASEGMENT *S = NULL;
 					if ((T = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_NONE, GMT_READ_NORMAL, NULL, opt->arg, NULL)) == NULL) {
-						GMT_Report (API, GMT_MSG_NORMAL, "Error reading file %s\n", opt->arg);
+						GMT_Report (API, GMT_MSG_ERROR, "Failure while reading file %s\n", opt->arg);
 						n_errors++;
 						continue;
 					}
@@ -198,7 +198,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *Ctrl, struct
 					if ((c = strrchr (txt_c, '+')) && (c[1] == 'n' || c[1] == '\0'))	/* Gave number of points instead; calculate inc */
 						inc = (max - min) / (inc - 1.0);
 					if (inc <= 0.0) {
-						GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -T option: Age increment must be positive\n");
+						GMT_Report (API, GMT_MSG_ERROR, "Option -T: Age increment must be positive\n");
 						n_errors++;
 					}
 					else {
@@ -229,17 +229,17 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct ROTSMOOTHER_CTRL *Ctrl, struct
 	if (!Ctrl->A.active) n_in++;	/* Got time in input column 3 */
 	if (Ctrl->W.active) n_in++;		/* Got weights as extra column */
 	if (GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] == 0) GMT->common.b.ncol[GMT_IN] = n_in;
-	n_errors += gmt_M_check_condition (GMT, GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] < n_in, "Syntax error: Binary input data (-bi) must have at least %u columns\n", n_in);
-	n_errors += gmt_M_check_condition (GMT, (Ctrl->N.active + Ctrl->S.active + Ctrl->W.active) > 1, "Syntax error: Only one of -N, -S, -Z can be set.\n");
+	n_errors += gmt_M_check_condition (GMT, GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] < n_in, "Binary input data (-bi) must have at least %u columns\n", n_in);
+	n_errors += gmt_M_check_condition (GMT, (Ctrl->N.active + Ctrl->S.active + Ctrl->W.active) > 1, "Only one of -N, -S, -Z can be set.\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-GMT_LOCAL int compare_ages (const void *point_1v, const void *point_2v) {
-	struct AGEROT *point_1, *point_2;
+GMT_LOCAL int rotsmoother_compare_ages (const void *point_1v, const void *point_2v) {
+	struct ROTSMOOTHER_AGEROT *point_1, *point_2;
 
-	point_1 = (struct AGEROT *)point_1v;
-	point_2 = (struct AGEROT *)point_2v;
+	point_1 = (struct ROTSMOOTHER_AGEROT *)point_1v;
+	point_2 = (struct ROTSMOOTHER_AGEROT *)point_2v;
 	if (point_1->wxyasn[K_AGE] < point_2->wxyasn[K_AGE]) return (-1);
 	if (point_1->wxyasn[K_AGE] > point_2->wxyasn[K_AGE]) return (+1);
 	return (0);
@@ -248,7 +248,7 @@ GMT_LOCAL int compare_ages (const void *point_1v, const void *point_2v) {
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_rotsmoother (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_rotsmoother (void *V_API, int mode, void *args) {
 	bool stop;
 	uint64_t n_read = 0, rot, p, first = 0, last, n_use = 0, n_out = 0, n_total_use = 0, n_minimum, n_alloc = GMT_CHUNK;
 	int error = 0, n_fields;
@@ -262,7 +262,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 	double x_in_plane[3], y_in_plane[3], C[9], EigenValue[3], EigenVector[9], work1[3], work2[3];
 	double R[3][3], DR[3][3], Ri[3][3], E[3], this_h[3], xyz_mean_pole[3], xyz_mean_quat[4], z_unit_vector[3];
 	double mean_rot_age, std_rot_age, *H[3], mean_H[3], Ccopy[9], *mangle = NULL, this_lon, this_lat;
-	struct AGEROT *D = NULL;
+	struct ROTSMOOTHER_AGEROT *D = NULL;
 	struct GMT_RECORD *In = NULL, *Out = NULL;
 	struct ROTSMOOTHER_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
@@ -279,7 +279,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
@@ -291,7 +291,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 
 	/* Read the rotation data from file or stdin */
 
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Processing input table data\n");
+	GMT_Report (API, GMT_MSG_INFORMATION, "Processing input table data\n");
 
 	if (!Ctrl->A.active) n_in++;	/* Got time */
 	if (Ctrl->W.active) n_in++;		/* Got weights */
@@ -310,7 +310,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 	}
 	t_col = (Ctrl->A.active) ? GMT_Z : 3;	/* If no time we use angle as proxy for time */
 	w_col = t_col + 1;
-	D = (struct AGEROT *) gmt_M_memory (GMT, NULL, n_alloc, struct AGEROT);
+	D = (struct ROTSMOOTHER_AGEROT *) gmt_M_memory (GMT, NULL, n_alloc, struct ROTSMOOTHER_AGEROT);
 	Out = gmt_new_record (GMT, out, NULL);	/* Since we only need to worry about numerics in this module */
 
 	do {	/* Keep returning records until we reach EOF */
@@ -330,6 +330,11 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 				continue;
 			}
 		}
+		if (In->data == NULL) {
+			gmt_quit_bad_record (API, In);
+			Return (API->error);
+		}
+
 		in = In->data;	/* Only need to process numerical part here */
 
 		/* Convert to geocentric, load parameters  */
@@ -341,11 +346,11 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 		n_read++;
 		if (n_read == n_alloc) {	/* Need larger arrays */
 			n_alloc <<= 1;
-			D = gmt_M_memory (GMT, D, n_alloc, struct AGEROT);
+			D = gmt_M_memory (GMT, D, n_alloc, struct ROTSMOOTHER_AGEROT);
 		}
 	} while (true);
 
-	if (n_read < n_alloc) D = gmt_M_memory (GMT, D, n_read, struct AGEROT);
+	if (n_read < n_alloc) D = gmt_M_memory (GMT, D, n_read, struct ROTSMOOTHER_AGEROT);
 
 	if (GMT_End_IO (API, GMT_IN,  0) != GMT_NOERROR) {	/* Disables further data input */
 		gmt_M_free (GMT, D);
@@ -369,8 +374,8 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 		}
 	}
 
-	if (!Ctrl->A.active) GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Range of input ages   = %g/%g\n", min_rot_age, max_rot_age);
-	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Range of input angles = %g/%g\n", min_rot_angle, max_rot_angle);
+	if (!Ctrl->A.active) GMT_Report (API, GMT_MSG_INFORMATION, "Range of input ages   = %g/%g\n", min_rot_age, max_rot_age);
+	GMT_Report (API, GMT_MSG_INFORMATION, "Range of input angles = %g/%g\n", min_rot_angle, max_rot_angle);
 
 	if ((error = GMT_Set_Columns (API, GMT_OUT, n_cols, GMT_COL_FIX_NO_TEXT)) != GMT_NOERROR) {
 		gmt_M_free (GMT, D);
@@ -383,7 +388,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 
 	/* Sort the entire dataset on increasing ages */
 
-	qsort (D, n_read, sizeof (struct AGEROT), compare_ages);
+	qsort (D, n_read, sizeof (struct ROTSMOOTHER_AGEROT), rotsmoother_compare_ages);
 
 	if (GMT->common.h.add_colnames) {	/* Create meaningful column header */
 		static char *short_header = "lon\tlat\ttime\tangle";
@@ -415,7 +420,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 			if (D[rot].wxyasn[K_AGE] > t_hi) stop = true;
 		last = rot - 1;	/* Index to first rotation outside this time interval */
 		n_use = last - first;	/* Number of rotations in the interval */
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Found %d rots for the time interval %g <= t < %g\n", n_use, t_lo, t_hi);
+		GMT_Report (API, GMT_MSG_INFORMATION, "Found %d rots for the time interval %g <= t < %g\n", n_use, t_lo, t_hi);
 		if (n_use < n_minimum) continue;	/* Need at least 1 or 2 poles to do anything useful */
 
 		/* Now extimate the average rotation */
@@ -474,7 +479,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 		out[GMT_X] = lon_mean_pole;
 		out[GMT_Y] = gmt_lat_swap (GMT, lat_mean_pole, GMT_LATSWAP_O2G);	/* Convert back from geocentric to geodetic */
 		out[GMT_Z] = mean_rot_age;	out[3] = mean_rot_angle;
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Mean opening angle %8.4f vs median opening angle %8.4f\n", mean_rot_angle, med_angle);	/* Report mean and median angle for testing */
+		GMT_Report (API, GMT_MSG_INFORMATION, "Mean opening angle %8.4f vs median opening angle %8.4f\n", mean_rot_angle, med_angle);	/* Report mean and median angle for testing */
 		n_total_use += n_use;
 		n_out++;
 
@@ -525,7 +530,7 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 
 		gmt_M_memcpy (Ccopy, C, 9, double);	/* Duplicate since it will get trodden on */
 		if (gmt_jacobi (GMT, Ccopy, matrix_dim, matrix_dim, EigenValue, EigenVector, work1, work2, &nrots)) {	/* Solve eigen-system C = EigenVector * EigenValue * EigenVector^T */
-			GMT_Report (API, GMT_MSG_NORMAL, "Eigenvalue routine gmt_jacobi failed to converge in 50 sweeps.\n");
+			GMT_Report (API, GMT_MSG_ERROR, "Eigenvalue routine gmt_jacobi failed to converge in 50 sweeps.\n");
 		}
 
 		/* In addition to reporting the covariance, we will report the azimuth of the major axis and the
@@ -582,8 +587,8 @@ int GMT_rotsmoother (void *V_API, int mode, void *args) {
 	}
 
 	if (n_out == 0) {
-		GMT_Report (API, GMT_MSG_NORMAL, "No smoothed poles created - is filterwidth too small?\n");
-		if (n_total_use != n_read) GMT_Report (API, GMT_MSG_NORMAL, "Read %ld poles, used %7ld\n", n_read, n_total_use);
+		GMT_Report (API, GMT_MSG_ERROR, "No smoothed poles created - is filterwidth too small?\n");
+		if (n_total_use != n_read) GMT_Report (API, GMT_MSG_ERROR, "Read %ld poles, used %7ld\n", n_read, n_total_use);
 	}
 
 	/* Free up memory used for the array */
