@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@ int main () {
 
 	int status = 0;				/* Status code from GMT API */
 	char cmd[BUFSIZ] = {""};			/* Command string */
-	char string[GMT_STR16] = {""};		/* Encoded ID */
+	char string[GMT_VF_LEN] = {""};		/* Encoded ID */
 	struct GMTAPI_CTRL *API = NULL;		/* GMT API control structure */
 	struct GMT_POSTSCRIPT *PS = NULL;	/* Holds our plot */
 
@@ -37,13 +37,13 @@ int main () {
 	if ((API = GMT_Create_Session ("PSLTEST", GMT_NOTSET, GMT_SESSION_NORMAL, NULL)) == NULL) exit (EXIT_FAILURE);
 
 	/* 2. Create a virtual file to be the destination allocated and written to by pscoast */
-	if (GMT_Open_VirtualFile (API, GMT_IS_POSTSCRIPT, GMT_IS_NONE, GMT_OUT, NULL, string) != GMT_NOERROR) exit (EXIT_FAILURE);
+	if (GMT_Open_VirtualFile (API, GMT_IS_POSTSCRIPT, GMT_IS_NONE, GMT_OUT|GMT_IS_REFERENCE, NULL, string) != GMT_NOERROR) exit (EXIT_FAILURE);
 	sprintf (cmd, "-R0/20/0/20 -JM6i -P -Gred -K > %s", string);			/* Create command for pscoast */
 
 	/* 3. Run GMT cmd function, or give usage message if errors arise during parsing */
 	status = GMT_Call_Module (API, "pscoast", GMT_MODULE_CMD, cmd);	/* This allocates memory for the plot and returns it via ID */
 	if (status) {
-		GMT_Report (API, GMT_MSG_NORMAL, "GMT_pscoast returned error %d\n", status);
+		GMT_Report (API, GMT_MSG_ERROR, "GMT_pscoast returned error %d\n", status);
 		exit (EXIT_FAILURE);
 	}
 
@@ -51,7 +51,7 @@ int main () {
 	/* 4. Run GMT cmd function, or give usage message if errors arise during parsing */
 	status = GMT_Call_Module (API, "psbasemap", GMT_MODULE_CMD, cmd);	/* This appends to the same plot */
 	if (status) {
-		GMT_Report (API, GMT_MSG_NORMAL, "GMT_psbasemap returned error %d\n", status);
+		GMT_Report (API, GMT_MSG_ERROR, "GMT_psbasemap returned error %d\n", status);
 		exit (EXIT_FAILURE);
 	}
 
