@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------
  *
- *      Copyright (c) 1999-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *      Copyright (c) 1999-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -42,23 +42,23 @@
 /* Control structure for x2sys_binlist */
 
 struct X2SYS_BINLIST_CTRL {
-	struct D {	/* -D */
+	struct X2SYS_BINLIST_D {	/* -D */
 		bool active;
 	} D;
-	struct E {	/* -E */
+	struct X2SYS_BINLIST_E {	/* -E */
 		bool active;
 	} E;
-	struct T {	/* -T */
+	struct X2SYS_BINLIST_T {	/* -T */
 		bool active;
 		char *TAG;
 	} T;
 };
 
-struct BINCROSS {
+struct X2SYS_BINLIST_BINCROSS {
 	double x, y, d;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct X2SYS_BINLIST_CTRL *C;
 
 	C = gmt_M_memory (GMT, NULL, 1, struct X2SYS_BINLIST_CTRL);
@@ -68,13 +68,13 @@ GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a n
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_M_str_free (C->T.TAG);
 	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s <files> -T<TAG> [-D] [-E] [%s] [%s]\n\n", name, GMT_V_OPT, GMT_PAR_OPT);
@@ -87,11 +87,11 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t-D Calculate track-lengths per bin (see x2sys_init -j for method and -N for units).\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-E Bin tracks using equal-area bins (with -D only).\n");
 	GMT_Option (API, "V,.");
-	
+
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ctrl, struct GMT_OPTION *options) {
+static int parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ctrl, struct GMT_OPTION *options) {
 
 	/* This parses the options provided to grdcut and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
@@ -115,7 +115,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ctrl, stru
 				break;
 
 			/* Processes program-specific parameters */
-			
+
 			case 'D':
 				Ctrl->D.active = true;
 				break;
@@ -132,15 +132,15 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ctrl, stru
 		}
 	}
 
-	n_errors += gmt_M_check_condition (GMT, n_files[GMT_IN] == 0, "Syntax error: No track files given\n");
-	n_errors += gmt_M_check_condition (GMT, n_files[GMT_OUT] > 1, "Syntax error: More than one output file given\n");
-	n_errors += gmt_M_check_condition (GMT, Ctrl->E.active && !Ctrl->D.active, "Syntax error: -E requires -D\n");
-	n_errors += gmt_M_check_condition (GMT, !Ctrl->T.active || !Ctrl->T.TAG, "Syntax error: -T must be used to set the TAG\n");
-	
+	n_errors += gmt_M_check_condition (GMT, n_files[GMT_IN] == 0, "No track files given\n");
+	n_errors += gmt_M_check_condition (GMT, n_files[GMT_OUT] > 1, "More than one output file given\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->E.active && !Ctrl->D.active, "Option -E requires -D\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->T.active || !Ctrl->T.TAG, "Option -T must be used to set the TAG\n");
+
 	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-GMT_LOCAL int outside (double x, double y, struct X2SYS_BIX *B, int geo) {
+GMT_LOCAL int x2sysbinlist_outside (double x, double y, struct X2SYS_BIX *B, int geo) {
 	if (y < B->wesn[YLO] || y > B->wesn[YHI]) return (1);
 	if (geo) {	/* Geographic data with periodic longitudes */
 		while (x < B->wesn[XLO]) x += 360.0;
@@ -153,7 +153,7 @@ GMT_LOCAL int outside (double x, double y, struct X2SYS_BIX *B, int geo) {
 	return (0);	/* Inside */
 }
 
-GMT_LOCAL unsigned int get_data_flag (double *data[], uint64_t j, struct X2SYS_INFO *s) {
+GMT_LOCAL unsigned int x2sysbinlist_get_data_flag (double *data[], uint64_t j, struct X2SYS_INFO *s) {
 	unsigned int i, bit, flag;
 	for (i = flag = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) {
 		if (gmt_M_is_dnan (data[i][j])) continue;	/* NaN, so no data here */
@@ -162,8 +162,8 @@ GMT_LOCAL unsigned int get_data_flag (double *data[], uint64_t j, struct X2SYS_I
 	return (flag);
 }
 
-GMT_LOCAL int comp_bincross (const void *p1, const void *p2) {
-	const struct BINCROSS *a = p1, *b = p2;
+GMT_LOCAL int x2sysbinlist_comp_bincross (const void *p1, const void *p2) {
+	const struct X2SYS_BINLIST_BINCROSS *a = p1, *b = p2;
 
 	if (a->d < b->d) return (-1);
 	if (a->d > b->d) return (+1);
@@ -173,7 +173,7 @@ GMT_LOCAL int comp_bincross (const void *p1, const void *p2) {
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 	char **trk_name = NULL, record[GMT_BUFSIZ] = {""};
 
 	uint64_t this_bin_index, index, last_bin_index, row, col, trk, n_tracks;
@@ -186,7 +186,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 	int error = 0;
 	bool gap, cmdline_files, last_not_set;
 	size_t nx, nx_alloc = GMT_SMALL_CHUNK;
-	
+
 	unsigned int nav_flag;
 
 	double **data = NULL, *dist_km = NULL, *dist_bin = NULL, dist_scale, x, y, dx, del_x, del_y, y_max = 90.0;
@@ -196,7 +196,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 	struct X2SYS_INFO *s = NULL;
 	struct X2SYS_FILE_INFO p;		/* File information */
 	struct X2SYS_BIX B;
-	struct BINCROSS *X = NULL;
+	struct X2SYS_BINLIST_BINCROSS *X = NULL;
 	struct X2SYS_BINLIST_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
@@ -212,7 +212,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
@@ -220,18 +220,19 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 	/*---------------------------- This is the x2sys_binlist main code ----------------------------*/
 
 	if ((error = x2sys_get_tracknames (GMT, options, &trk_name, &cmdline_files)) <= 0) {
-		GMT_Report (API, GMT_MSG_NORMAL, "No datafiles given!\n");
-		Return (GMT_RUNTIME_ERROR);		
+		GMT_Report (API, GMT_MSG_ERROR, "No datafiles given!\n");
+		Return (GMT_RUNTIME_ERROR);
 	}
 	n_tracks = (uint64_t)error;
-	
-	x2sys_err_fail (GMT, x2sys_set_system (GMT, Ctrl->T.TAG, &s, &B, &GMT->current.io), Ctrl->T.TAG);
+
+	if (x2sys_err_fail (GMT, x2sys_set_system (GMT, Ctrl->T.TAG, &s, &B, &GMT->current.io), Ctrl->T.TAG))
+		Return (GMT_RUNTIME_ERROR);
 
 	if (Ctrl->E.active && !s->geographic) {
-		GMT_Report (API, GMT_MSG_NORMAL, "-E requires geographic data; your TAG implies Cartesian\n");
+		GMT_Report (API, GMT_MSG_ERROR, "-E requires geographic data; your TAG implies Cartesian\n");
 		x2sys_end (GMT, s);
 		x2sys_free_list (GMT, trk_name, n_tracks);
-		Return (GMT_RUNTIME_ERROR);		
+		Return (GMT_RUNTIME_ERROR);
 	}
 
 	if (s->geographic) {
@@ -244,8 +245,8 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 	gmt_set_column (GMT, GMT_OUT, 3, GMT_IS_FLOAT);
 	if (Ctrl->D.active) gmt_set_column (GMT, GMT_OUT, 4, GMT_IS_FLOAT);
 	/* Ensure we write integers for the next two columns */
-	GMT->current.io.o_format[2] = GMT->current.io.o_format[3] = strdup ("%g"); 
-	
+	GMT->current.io.o_format[2] = GMT->current.io.o_format[3] = strdup ("%g");
+
 	MGD77_Set_Unit (GMT, s->unit[X2SYS_DIST_SELECTION], &dist_scale, -1);	/* Gets scale which multiplies meters to chosen distance unit */
 
 	if (Ctrl->E.active) {
@@ -254,14 +255,14 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 		/* Do the equal area map projection so W = 360 and H = 180 */
 		if (!(doubleAlmostEqual (B.wesn[XHI] - B.wesn[XLO], 360.0)
 					&& doubleAlmostEqualZero (B.wesn[YHI] - B.wesn[YLO], 180.0))) {
-			GMT_Report (API, GMT_MSG_NORMAL, "-E requires a global region (-Rg or -Rd)");
+			GMT_Report (API, GMT_MSG_ERROR, "-E requires a global region (-Rg or -Rd)");
 			x2sys_free_list (GMT, trk_name, n_tracks);
 			x2sys_end (GMT, s);
 			Return (GMT_RUNTIME_ERROR);
 		}
 		GMT->current.setting.proj_ellipsoid = gmt_get_ellipsoid (GMT, "Sphere");	/* Make sure we use a spherical projection */
 		mid = 0.5 * (B.wesn[XHI] + B.wesn[XLO]);	/* Central longitude to use */
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE,
+		GMT_Report (API, GMT_MSG_INFORMATION,
 		            "To undo equal-area projection, use -R%g/%g/%g/%g -JY%g/%s/360i\n",
 		            B.wesn[XLO], B.wesn[XHI], B.wesn[YLO], B.wesn[YHI], mid, EA_LAT);
 		sprintf (proj, "Y%g/%s/360", mid, EA_LAT);
@@ -275,16 +276,17 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 		gmt_geo_to_xy (GMT, B.wesn[XHI], B.wesn[YHI], &B.wesn[XHI], &B.wesn[YHI]);
 		y_max = B.wesn[YHI];
 	}
-	
+
 	x2sys_bix_init (GMT, &B, true);
 	nav_flag = (1 << s->x_col) + (1 << s->y_col);	/* For bins just cut by track but no points inside the bin */
 	jump_180 = irint (180.0 / B.inc[GMT_X]);
 	jump_360 = irint (360.0 / B.inc[GMT_X]);
 
-	X = gmt_M_memory (GMT, NULL, nx_alloc, struct BINCROSS);
-	
+	X = gmt_M_memory (GMT, NULL, nx_alloc, struct X2SYS_BINLIST_BINCROSS);
+
 	if (Ctrl->D.active) {
-		gmt_init_distaz (GMT, s->unit[X2SYS_DIST_SELECTION][0], s->dist_flag, GMT_MAP_DIST);
+		if (gmt_init_distaz (GMT, s->unit[X2SYS_DIST_SELECTION][0], s->dist_flag, GMT_MAP_DIST) == GMT_NOT_A_VALID_TYPE)
+			Return (GMT_NOT_A_VALID_TYPE);
 		dist_bin = gmt_M_memory (GMT, NULL, B.nm_bin, double);
 	}
 
@@ -324,52 +326,57 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 
 	for (trk = 0; trk < n_tracks; trk++) {
 
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Reading file %s ", trk_name[trk]);
+		GMT_Report (API, GMT_MSG_INFORMATION, "Reading file %s ", trk_name[trk]);
+
+		if (x2sys_err_fail (GMT, (s->read_file) (GMT, trk_name[trk], &data, s, &p, &GMT->current.io, &row), trk_name[trk]))
+			Return (GMT_RUNTIME_ERROR);
+		GMT_Report (API, GMT_MSG_INFORMATION, "[%s]\n", s->path);
 
-		x2sys_err_fail (GMT, (s->read_file) (GMT, trk_name[trk], &data, s, &p, &GMT->current.io, &row), trk_name[trk]);
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "[%s]\n", s->path);
-		
 		if (p.n_rows == 0) {
-			GMT_Report (API, GMT_MSG_VERBOSE, "No data records found - skipping %s\n", trk_name[trk]);
+			GMT_Report (API, GMT_MSG_WARNING, "No data records found - skipping %s\n", trk_name[trk]);
 			x2sys_free_data (GMT, data, s->n_fields, &p);
 			continue;
 		}
-		
+
 		if (Ctrl->E.active) {	/* Project coordinates */
 			for (row = 0; row < p.n_rows; row++)
 				gmt_geo_to_xy (GMT, data[s->x_col][row], data[s->y_col][row], &data[s->x_col][row], &data[s->y_col][row]);
 		}
-		
+
 		/* Reset bin flags */
 
 		gmt_M_memset (B.binflag, B.nm_bin, unsigned int);
 		if (Ctrl->D.active) {
 			int signed_flag = s->dist_flag;
 			gmt_M_memset (dist_bin, B.nm_bin, double);
-			if ((dist_km = gmt_dist_array_2 (GMT, data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -signed_flag)) == NULL)
-				gmt_M_err_fail (GMT, GMT_MAP_BAD_DIST_FLAG, "");	/* -ve gives increments */
+			if ((dist_km = gmt_dist_array_2 (GMT, data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -signed_flag)) == NULL) {
+				error = gmt_M_err_fail (GMT, GMT_MAP_BAD_DIST_FLAG, "");	/* -ve gives increments */
+				Return (error);
+			}
 		}
 
 		last_bin_index = UINT_MAX;
 		last_not_set = true;
 		last_bin_col = last_bin_row = -1;
 		for (row = 0; row < p.n_rows; row++) {
-			if (outside (data[s->x_col][row], data[s->y_col][row], &B, s->geographic)) continue;
-			x2sys_err_fail (GMT, x2sys_bix_get_index (GMT, data[s->x_col][row], data[s->y_col][row], &this_bin_col,
-			                                          &this_bin_row, &B, &this_bin_index), "");
+			if (x2sysbinlist_outside (data[s->x_col][row], data[s->y_col][row], &B, s->geographic)) continue;
+			if (x2sys_err_fail (GMT, x2sys_bix_get_index (GMT, data[s->x_col][row], data[s->y_col][row], &this_bin_col,
+			                                          &this_bin_row, &B, &this_bin_index), ""))
+				Return (GMT_RUNTIME_ERROR);
+
 
 			/* While this may be the same bin as the last bin, the data available may have changed so we keep
 			 * turning the data flags on again and again. */
-			 
-			B.binflag[this_bin_index] |= get_data_flag (data, row, s);
+
+			B.binflag[this_bin_index] |= x2sysbinlist_get_data_flag (data, row, s);
 
 			if (!Ctrl->D.active) continue;	/* Not worried about trackline lengths */
-			
+
 			if (last_not_set) {	/* Initialize last bin to this bin the first time */
 				last_bin_index = this_bin_index;
 				last_not_set = false;
 			}
-			
+
 			if (row > 0) { /* Can check for gaps starting with 1st to 2nd point */
 				gap = false;
 				if (s->t_col >= 0) {	/* There is a time column in the data*/
@@ -380,7 +387,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 				}
 				else if ((dist_km[row] - dist_km[row-1]) > B.dist_gap) /* There is no time column, must test for gaps based on distance */
 					gap = true;
-				
+
 				if (gap) {
 					last_bin_index = this_bin_index;	/* Update the last point's index info */
 					last_bin_col = this_bin_col;
@@ -408,11 +415,11 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 					end_col = MAX (last_bin_col, this_bin_col);
 					dx = data[s->x_col][row] - data[s->x_col][row-1];
 				}
-				
+
 				/* Find all the bin-line intersections */
-				
+
 				/* Add the start and stop coordinates to the xc/yc arrays so we can get mid-points of the intervals */
-				
+
 				X[0].x = data[s->x_col][row-1];	X[0].y = data[s->y_col][row-1];	X[0].d = 0.0;
 				X[1].x = data[s->x_col][row];	X[1].y = data[s->y_col][row];	X[1].d = hypot (dx, data[s->y_col][row] - data[s->y_col][row-1]);
 				nx = 2;
@@ -425,7 +432,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 					nx++;
 					if (nx == nx_alloc) {
 						nx_alloc <<= 1;
-						X = gmt_M_memory (GMT, X, nx_alloc, struct BINCROSS);
+						X = gmt_M_memory (GMT, X, nx_alloc, struct X2SYS_BINLIST_BINCROSS);
 					}
 				}
 				for (bcol = start_col; bcol <= end_col; bcol++) {	/* If we go in here we think dx is non-zero (we do a last-ditch dx check just in case) */
@@ -442,14 +449,14 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 					nx++;
 					if (nx == nx_alloc) {
 						nx_alloc <<= 1;
-						X = gmt_M_memory (GMT, X, nx_alloc, struct BINCROSS);
+						X = gmt_M_memory (GMT, X, nx_alloc, struct X2SYS_BINLIST_BINCROSS);
 					}
 				}
-				
+
 				/* Here we have 1 or more intersections */
-				
-				qsort (X, nx, sizeof (struct BINCROSS), comp_bincross);
-				
+
+				qsort (X, nx, sizeof (struct X2SYS_BINLIST_BINCROSS), x2sysbinlist_comp_bincross);
+
 				for (curr_x_pt = 1, prev_x_pt = 0; curr_x_pt < nx; curr_x_pt++, prev_x_pt++) {	/* Process the intervals, getting mid-points and using that to get bin */
 					dx = X[curr_x_pt].x - X[prev_x_pt].x;
 					if (s->geographic && dx < -180.0)
@@ -460,7 +467,8 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 						x = 0.5 * (X[curr_x_pt].x + X[prev_x_pt].x);
 					y = 0.5 * (X[curr_x_pt].y + X[prev_x_pt].y);
 					if (s->geographic && fabs (y) > y_max) y = copysign (y_max, y);
-					x2sys_err_fail (GMT, x2sys_bix_get_index (GMT, x, y, &ii_notused, &jj_notused, &B, &index), "");
+					if (x2sys_err_fail (GMT, x2sys_bix_get_index (GMT, x, y, &ii_notused, &jj_notused, &B, &index), ""))
+								Return (GMT_RUNTIME_ERROR);
 					dist_bin[index] += gmt_distance (GMT, X[curr_x_pt].x, X[curr_x_pt].y, X[prev_x_pt].x, X[prev_x_pt].y);
 					B.binflag[index] |= nav_flag;		/* Only update nav flags we have not been here already */
 				}
@@ -490,7 +498,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 
 		if (Ctrl->D.active) gmt_M_free (GMT, dist_km);
 	}
-	
+
 	error = GMT_NOERROR;
 	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) 	/* Disables further data output */
 		error = API->error;
