@@ -246,7 +246,8 @@ EXTERN_MSC int GMT_x2sys_put (void *V_API, int mode, void *args) {
 
 	/* Open TAG file and set the operational parameters */
 
-	x2sys_err_fail (GMT, x2sys_set_system (GMT, Ctrl->T.TAG, &s, &B, &GMT->current.io), Ctrl->T.TAG);
+	if (x2sys_err_fail (GMT, x2sys_set_system (GMT, Ctrl->T.TAG, &s, &B, &GMT->current.io), Ctrl->T.TAG))
+		Return (GMT_RUNTIME_ERROR);
 
 	for (i = max_flag = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) max_flag |= bit;
 
@@ -254,12 +255,14 @@ EXTERN_MSC int GMT_x2sys_put (void *V_API, int mode, void *args) {
 
 	/* Read existing track-information from <ID>_tracks.d file */
 
-	 x2sys_err_fail (GMT, x2sys_bix_read_tracks (GMT, s, &B, 0, &last_id), "");
+	 if (x2sys_err_fail (GMT, x2sys_bix_read_tracks (GMT, s, &B, 0, &last_id), ""))
+		Return (GMT_RUNTIME_ERROR);
 	 last_id--;	/* Since last_id as returned is the number of IDs */
 
 	/* Read geographical track-info from <ID>_index.b file */
 
-	x2sys_err_fail (GMT, x2sys_bix_read_index (GMT, s, &B, Ctrl->S.active), "");
+	if (x2sys_err_fail (GMT, x2sys_bix_read_index (GMT, s, &B, Ctrl->S.active), ""))
+		Return (GMT_RUNTIME_ERROR);
 
 	/* Ok, now we can start reading new info */
 
